<?php

namespace Modules\CouncilManagement\Http\Livewire\Approval;

use App\Enums\ApplicationStatus;
use App\Models\AccountVerificationApplication;
use App\Models\AccountVerificationApplications;
use App\Models\BillingAccounts;
use App\Models\User;
use App\Traits\IsTable;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;
use Livewire\WithPagination;

class AccountPending extends Component
{
    use IsTable, WithPagination,LivewireAlert;

    public function  mount(){
        $this->columns=[
            'Date'=>'created_at'
        ];
    }

    private function getAccount ($accountNo) {
        return BillingAccounts::where('account_no', $accountNo)->firstOrFail();
    }

    private function getUser ($id) {
        return User::where('id', $id)->firstOrFail();
    }

    public function render()
    {
        $results =AccountVerificationApplication::where('council_id', Auth::user()->council_id)
                ->where('status', 'pending'/*ApplicationStatus::Pending*/)
                ->where('account_no', 'like', '%' . $this->search . '%')
                ->orderBy($this->columns[$this->orderBy], $this->orderDirection)->paginate($this->paginationCount);

        return view('councilmanagement::livewire.approval.account-pending',[
            'results'=>$results
        ]);
    }

    public function declineApplication($id){
//        $application = AccountVerificationApplication::where('id', $id)->firstOrFail();
//        $application->status = ApplicationStatus::Rejected();
//        $application->save();
        $this->alert('warning', 'Account application Declined', [
            'position' => 'top-end'
        ]);
    }

    public function approveApplication ($id) {
        DB::beginTransaction();
        try {
            $application = AccountVerificationApplication::where('id', $id)->firstOrFail();
            $application->status = ApplicationStatus::Approved();
            $application->save();

            $account = $this->getAccount($application->account_no);
            $account->has_user = true;
            $account->user_id = $application->user_id;
            $account->status = 'verified';
            $account->save();

            $user = $this->getUser($application->user_id);
            $user->is_verified = true;
            $user->save();
            DB::commit();
            $this->alert('success', 'Account application Accepted', [
                'position' => 'top-end'
            ]);
        }catch (\Exception $e){
            dd($e);
            DB::rollBack();
            $this->alert('warning', 'Failed to approve account', [
                'position' => 'top-end'
            ]);
        }

    }
}
