<?php

namespace Modules\CouncilManagement\Http\Livewire\Crm;

use App\Models\LoggedQuery;
use App\Traits\IsTable;
use Illuminate\Support\Facades\Auth;
use Livewire\Component;
use Livewire\WithPagination;

class QueriesTable extends Component
{
    use WithPagination, IsTable, WithPagination;

    public $type;

    public function mount()
    {
        $this->columns = [
            "First Name" => "first_name",
            "Last Name" => "last_name",
            "Address" => "address",
            "Email" => "email",
            "Phone Number" => "phone_number",
            'Date' => 'created_at'
        ];
    }

    public function render()
    {
        $results = LoggedQuery::where("type", $this->type)
            ->where(function ($query) {
                $query->orwhere('query_id', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('state', 'LIKE', '%' . $this->search . '%')
                    ->orWhere('first_name', 'LIKE', '%' . $this->search . '%')
                    ->orWhere('last_name', 'LIKE', '%' . $this->search . '%')
                    ->orWhere('address', 'LIKE', '%' . $this->search . '%')
                    ->orWhere('email', 'LIKE', '%' . $this->search . '%')
                    ->orWhere('phone_number', 'LIKE', '%' . $this->search . '%')
                    ->orWhere('reporting_channel', 'LIKE', '%' . $this->search . '%')
                    ->orWhere('description', 'LIKE', '%' . $this->search . '%')
                    ->orWhereHas('category', function ($query) {
                        $query->where('name', 'LIKE', '%' . $this->search . '%');
                    });
            })
            ->orderBy($this->columns[$this->orderBy], $this->orderDirection)
            ->paginate($this->paginationCount);

        return view('councilmanagement::livewire.crm.queries-table', [
            'results' => $results
        ]);
    }
}
