<?php

namespace Modules\SystemSettings\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\CompanyDetail;
use App\Models\CouncilPayNowKeys;
use App\Models\User;
use App\Models\UserRole;
use http\Exception\BadConversionException;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use Modules\SystemSettings\Entities\Council;
use PHPUnit\Exception;

class CouncilManagementController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Renderable
     */
//    public function __construct()
//    {
//        $this->middleware=['auth','isAdmin'];
//    }
    public function addCouncil(Request $request): \Illuminate\Http\RedirectResponse
    {
//    dd($request->all());
//     dd($request->all());
        $validated = $request->validate(
            [
                'companyName'=>'required',
                'email'=>'required|email',
                'Address'=>'required|min:10',
                'province'=>'required',
                'companyCode'=>'required',
                'companyPrefix'=>'required',
                'contactNumber'=>'required',
                'companyType'=>'required',
                'vatNumber'=>'required',
                'creditorsNumber'=>'required'
            ]);


        try{
            DB::beginTransaction();
            if(Council::where('council',$request->council)->first() ||
                Council::where('email',$request->email)->first() ||
                Council::where('code',$request->code)->first()
            ){
                return back()->with('error', 'Council already exists');
            }

            $company = new Council();
            $company->council= $validated['companyName'];
            $company->code= $validated['companyCode'];
            $company->prefix= $validated['companyPrefix'];
            $company->province_id= $validated['province'];
            $company->telephone1= $validated['contactNumber'];
            $company->telephone2= $request->input('alternativeNumber');
            $company->type= $validated['companyType'];
            $company->vat_number= $validated['vatNumber'];
            $company->creditors_number= $validated['creditorsNumber'];
            $company->email= $validated['email'];
            $company->address= $validated['Address'];
            $company->status= true;

            if(request()->hasFile('logo')){
                $path =  Storage::disk('local')->put('Company logo',$request->file('logo'));
                $company->logo=$path;
//                $validated['logo'] = $path;
            }
            $company->save();

            DB::commit();
            return back()->with('success','Company saved successfully');

        }

        catch(\Exception $exception){
            DB::rollBack();
//            return back()->with('error','Company Details save failed,help has been contacted');
             return back()->with('error',$exception->getMessage());
        }

    }

//    public function addCouncil(Request $request)
//    {
//        DB::beginTransaction();
//        try {
//            if(Council::where('council',$request->council)->first() ||
//                Council::where('email',$request->email)->first() ||
//                Council::where('code',$request->code)->first()
//            ){
//                return back()->with('error', 'Council already exists');
//            }else{
//                $council = new Council();
//                $council->council= $request->council;
//                $council->province_id= $request->province;
//                $council->email= $request->email;
//                $council->address= $request->address;
//                $council->code= $request->code;
//                $council->status= true;
//                $council->telephone= $request->telephone;
//                $council->prefix_code= $request->prefix_code;
//                $council->save();
//                DB::commit();
//                return back()->with('suucess','Successfully added a council');
//            }
//        }catch (Exception $e){
//            DB::rollback();
//            return back()->with('error','Failed to add council');
//        }
//    }

    public function addAccounts(Request $request)
    {
        DB::beginTransaction();
        try {
            if(CouncilPayNowKeys::where('council_id',$request->council_id)->first()){
                CouncilPayNowKeys::where('council_id',$request->council_id)->update(

                    [
                        'council_id'=>$request->council_id,
                        'integration_key'=>$request->intergration_key,
                        'integration_secrete'=>$request->intergration_secrete,
                        'ecocash'=>$request->netone_number,
                        'telecash'=>$request->telecash_number,
                        'onemoney'=>$request->netone_number,
                    ],
                );
            }else{
                $intergration=CouncilPayNowKeys::create(

                    [
                        'council_id'=>$request->council_id,
                        'integration_key'=>$request->intergration_key,
                        'integration_secrete'=>$request->intergration_secrete,
                        'ecocash'=>$request->netone_number,
                        'telecash'=>$request->telecash_number,
                        'onemoney'=>$request->netone_number,
                    ],
                );
                $intergration->save();
            }
            DB::commit();
            return back()->with('success','Successfully added intergration');
        }catch (Exception $e){
            DB::rollback();
            return back()->with('error','Failed to add intergration');
        }
    }

    public function addCouncilUser(Request $request)
    {
        DB::beginTransaction();
        try {
            $user = new User();
            $user->first_names = $request->first_names;
            $user->surnames = $request->surname;
            $user->email = $request->email;
            $user->council_id = $request->council_id;
            $user->telephone = $request->telephone;
            $user->telephone_alt = $request->telephone_alt;
            $user->sex = 'male';
            $user->nationality = 'Zimbabwean';
            $user->marital_status = 'Council';
            $user->birth_date = '1980-01-01';
            $user->id_number = $request->telephone;
            $user->address = 'null';
            $user->password = Hash::make(strtolower($request->first_names[0].$request->surname));
            $user->save();

            $user->permissions()->create(UserRole::$council);
            Council::where('id',$request->council_id)->update(['hasUser'=>true]);
            DB::commit();
            return back()->with('success','Added council user');
        }catch (Exception $e){
            DB::rollBack();
            return back()->with('error','Failed to create account');
        }
    }

}
