<?php

namespace Modules\UserManagement\Http\Controllers;

use App\BusinessLogic\AccountVerificationApplications;
use App\BusinessLogic\UploadHandler;
use App\Http\Requests\OwnershipRequest;
use App\Models\AccountPortalPayment;
use App\Models\FinancialCurrency;
use App\Traits\PaynowPayment;
use Carbon\Carbon;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;

class AccountsController extends Controller
{
    use PaynowPayment;

    public function accountOwnershipRequest(OwnershipRequest $request)
    {
        $identification_document = UploadHandler::handleUpload(request()->file('identification'));
        $recent_payment = UploadHandler::handleUpload(request()->file('recent_payment'));
        $offer_letter = UploadHandler::handleUpload(request()->file('offer_letter'));

        try {
            $verification = new AccountVerificationApplications($request->all());
            $application = $verification->makeApplication();

            $verification->submitAttachment('Identification Document', $application->id, $identification_document, request()->file('identification')->getClientOriginalExtension());
            $verification->submitAttachment('Recent Payment', $application->id, $recent_payment, request()->file('recent_payment')->getClientOriginalExtension());
            $verification->submitAttachment('Offer Letter', $application->id, $offer_letter, request()->file('offer_letter')->getClientOriginalExtension());

            return back()->with('success', 'Application submitted');
        } catch (\Exception $ex) {
            return back()->with('error', $ex);
        }
    }

    public function downloadFile(Request $request)
    {
        return Storage::download($request->path);
    }

    public function processApplication(Request $request)
    {
        switch ($request->action) {
            case 'reject':
                $this->declineApplication($request->id);
                return redirect('/admin/applications/pending')->with('success', 'Application declined');
            case 'approve':
                $this->approveApplication($request->id);
                return redirect('/admin/applications/pending')->with('success', 'Application approved');
            default:
                return back()->with('error', 'Action not identified');
        }
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function getAccountsData(Request $request)
    {
        return view('usermanagement::create');
    }


    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
        return view('usermanagement::show');
    }

    public function accountPayment(Request $request)
    {
        $currencies = FinancialCurrency::where('code', 'ZWL')->first();
        $validation = $request->validate([
            "payer_name" => "required",
            "phone_number" => "required",
            "amount" => "required",
            "account_number" => "required"
        ]);

        $type = $this->checkNumber($validation['phone_number']);
        if ($this->not_number) {
            return back()->with('error', 'Please Enter Eco-cash Number Or A Net-one Number');
        } else {
            $createPayment = $this->payment();
            $payment = $createPayment->createPayment('Account Payment', Auth::user()->email);
            $payment->add('Account Payment', $validation['amount']);
            $response = $createPayment->sendMobile($payment, $validation['phone_number'], $type);

            if ($response->success()) {
                $pollUrl = $response->pollUrl();
                $transaction = $createPayment->pollTransaction($pollUrl)->data();

                try {
                    AccountPortalPayment::create(
                        [
                            "account_no" => $validation["account_number"],
                            "payer_name" => $validation["payer_name"],
                            "pay_now_reference" => $transaction["paynowreference"],
                            "reference" =>$transaction["reference"],
                            "amount" => $transaction["amount"],
                            "rate" => $currencies->rate,
                            "pay_now_status" => $transaction["status"],
                            "sync_status" => "awaiting sync",
                            "poll_url" => $transaction["pollurl"],
                            "hash" => $transaction["hash"],
                            "date_paid" => Carbon::now(),
                            "user_id" => Auth::user()->id,
                            "employee_id" => portalAssistant()
                        ]);
                    return redirect()->route("user-add-account")->with("success","payment recorded successfully");
                } catch (\Exception $e) {
                    return back()->error("error", "error in creating payment transaction");
                }
            }
        }
    }
}
