<?php

namespace Modules\UserManagement\Http\Controllers;

use App\Models\ApplicationInspection;
use App\Models\CompanyDetail;
use App\Models\FinancialCurrency;
use App\Models\Licence;
use App\Models\LicenceApplication;
use App\Models\LicenceApplicationSpecific;
use App\Models\LicenceClearance;
use App\Models\LicenceInvoice;
use App\Models\LicenceInvoiceLine;
use App\Models\LicenceStageSetting;
use App\Models\LicenceTarriff;
use App\Models\LicenceType;
use App\Models\PortalPayment;
use App\Models\PremiseDetail;
use App\Models\PremiseSpace;
use App\Models\RegistrablePremise;
use App\Models\ShopLicenceClass;
use App\Models\TrackLocalApp;
use App\Traits\PaynowPayment;
use Barryvdh\DomPDF\PDF;
use Carbon\Carbon;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Redirect;
use Modules\SystemSettings\Entities\Council;
use Modules\UserManagement\Entities\MyBusiness;
use Modules\UserManagement\Entities\MyBusinessLicenceType;
use Paynow\Payments\Paynow;

class BusinessLicenceController extends Controller
{
    use PaynowPayment;

    /**
     * Display a listing of the resource.
     * @return Renderable
     */
    public function newBusiness(Request $request)
    {

        DB::beginTransaction();
        try {
            if (MyBusiness::where('trading_name', $request->trading_name)->first()) {
                return back()->with('error', 'Businesss aready exist');
            } else {
                $business = new MyBusiness;
                $business->trading_name = $request->trading_name;
                $business->business_name = $request->business_name;
                $business->address = $request->address;
                $business->status = true;
                $business->description = $request->description;
                $business->mobile_number = $request->mobile_number;
                $business->user_id = Auth::user()->id;
                $business->council_id = Auth::user()->council_id;
                $business->save();

                foreach ($request->business as $type) {
                    $joinTable = new MyBusinessLicenceType;
                    $joinTable->business_id = $business->id;
                    $joinTable->licence_id = $type['type'];
                    $joinTable->save();
                }
                DB::commit();
                return back()->with('success', 'Successfully added a business');
            }
        } catch (\Exception $e) {
            DB::rollBack();
            return back()->with('error', 'Faid to add business');
        }
        return view('usermanagement::index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function addLicence($id, Request $request)
    {
        try {
            foreach ($request->business as $type) {
                $joinTable = new MyBusinessLicenceType;
                $joinTable->business_id = $id;
                $joinTable->licence_id = $type['type'];
                $joinTable->save();
            }
            return back()->with('success', 'Successfully added a licence to business');
        } catch (\Exception $e) {
            return back()->with('error', 'Faid to add a licence business');
        }
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Renderable
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
        return view('usermanagement::show');
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Renderable
     */
//    public function previewAppication()
//    {
//        return view('usermanagement.');
//    }

    public function addApplication(Request $request)
    {
//        dd($request->all());
        try {
            DB::beginTransaction();
//            $currency = request('currency');
//            $rate = $currency == 'rtgs' ? request('exchangeRate') : 1;
            $rate = 1;
            $currency = "usd";

            if (request('shopCheckbox')) {
                $shop = new LicenceApplication();
                $shop->sync_status = 'not synced';
                $shop->licence_type_id = 1;
                $shop->user_id = Auth::user()->id;
                $shop->council_id = Auth::user()->council_id;
                $shop->applicant_name = ucwords(strtolower(request('applicant_fullName')));
                $shop->applicant_number = request('applicantNumber');
                $shop->applicant_id = request('applicantId');
                $shop->applicant_address = ucwords(strtolower(request('applicantAddress')));
                $shop->location_id = request('locationId');
                $shop->district_id = request('districtId');
                $shop->owner_applicant = request('isOwner') == 'true' ? 1 : 0;
                $shop->business_owner_name = request('isOwner') == 'true' ? ucwords(strtolower(request('owner_name_shop'))) : ucwords(strtolower(request('applicant_fullName')));
                $shop->business_owner_email = request('isOwner') == 'true' ? strtolower(request('owner_email_shop')) : Auth::user()->email;
                $shop->business_owner_number = request('isOwner') == 'true' ? request('owner_mobile_shop') : request('applicantNumber');
                $shop->business_owner_address = request('isOwner') == 'true' ? ucwords(strtolower(request('owner_address_shop'))) : ucwords(strtolower(request('applicantAddress')));
                $shop->business_name = ucwords(strtolower(request('business_name_shop')));
                $shop->business_address = ucwords(strtolower(request('businessAddressShop')));
                $shop->trading_as = ucwords(strtolower(request('trading_as_shop')));
                $shop->stand_number = request('shop_room_no_shop');
                $shop->status = "CLERK";
                $shop->stage = "SET CYCLE";
                $shop->employee_id = portalAssistant();
                $shop->vat_number = request('applicantVatNo');
                $shop->bp_number = request('applicantBpNo');
                $shop->save();

                $shop->update(['ref' => $shop->id . mt_rand(1000000000, 9999999999)]);
                $premise = PremiseDetail::where('physical_address', request('businessAddressShop'))->first();

                if (!$premise) {
                    $premise = new PremiseDetail();
                    $premise->premise_owner = ucwords(strtolower('N/A'));
                    $premise->account_no = 'N/A';
                    $premise->stand = ucwords(strtolower('N/A'));
                    $premise->physical_address = ucwords(strtolower(request('businessAddressShop')));
                    $premise->location = ucwords(strtolower(request('locationId')));
                    $premise->contact = 'N/A';
                    $premise->email = 'N/A';
                    $premise->save();
                }
                $room = new PremiseSpace();
                $room->premise_id = $premise->id;
                $room->room = ucwords(strtolower(request('shop_room_no_shop')));
                $room->type = ucwords(strtolower('room'));
                $room->space = 1;
                $room->notes = ucwords(strtolower(request('shop_room_no_shop')));
                $room->status = "VACANT";
                $room->save();
                $shop->update(['premise_space_id' => $room->id]);


                LicenceClearance::create([
                    'licence_application_id' => $shop->id,
                    'premise_detail_id' => $premise->id,
                    'cleared' => 'Pending'
                ]);

                $shop_tariff = LicenceTarriff::where('licence_type_id', 1)->first();

                $invoice = LicenceInvoice::create([
                    'licence_type_id' => $shop->licence_type_id,
                    'licence_application_id' => $shop->id,
                    'user_id' => Auth::user()->id,
                    'council_id' => Auth::user()->council_id,
                    'employee_id' => portalAssistant(),
                    'type' => "Application",
                    'status' => 'Pending',
                    'currency' => $currency,
                    'rate' => $rate,
                    'customer_name' => $shop->applicant_name,
                    'customer_address' => $shop->applicant_address,
                    'customer_id' => $shop->applicant_id,
                    'customer_phone' => $shop->applicant_number,
//                    'ref' => "1-" . $shop->id . "-" . $shop->district_id
                ]);
                $invoice->update(['ref' => $this->generateInvoiceNumber($invoice, 'Application')]);

                $main_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $shop->licence_type_id,
                    'licence_application_id' => $shop->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => $shop->licenceType->title . ' Application fee',
                    'status' => 'Active',
                    'unit_price' => $shop_tariff->application_fee,
                    'quantity' => 1,
                    'is_vat' => 'no',
                    'is_discount' => 'no',
                    'total' => $shop_tariff->application_fee,
                ]);

                $vat_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $shop->licence_type_id,
                    'licence_application_id' => $shop->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => "vat @ 14.5 %",
                    'status' => 'Active',
                    'unit_price' => $shop->licenceType->tax * $shop_tariff->application_fee,
                    'quantity' => 1,
                    'is_vat' => 'yes',
                    'total' => $shop->licenceType->tax * $shop_tariff->application_fee,
                ]);

                if ($rate == 1)
                    $discount_line = LicenceInvoiceLine::create([
                        'licence_type_id' => $shop->licence_type_id,
                        'licence_application_id' => $shop->id,
                        'licence_invoice_id' => $invoice->id,
                        'description' => "discount " . ($shop->licenceType->discount * 100) . "%",
                        'status' => 'Active',
                        'unit_price' => -($shop->licenceType->discount * (($shop->licenceType->tax * $shop_tariff->application_fee) + $shop_tariff->application_fee)),
                        'quantity' => 1,
                        'is_discount' => 'yes',
                        'total' => -($shop->licenceType->discount * (($shop->licenceType->tax * $shop_tariff->application_fee) + $shop_tariff->application_fee)),
                    ]);

                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = $shop->id;
                $subscription->start_date = Carbon::parse('first day of January');
                $subscription->end_date = Carbon::parse('last day of December');
                $subscription->validity = 'Annual';
                $subscription->term = 'January - December';
                $subscription->status = "PENDING";
                $subscription->notes = ucwords(strtolower('yearly'));
                $subscription->save();

                $appp = LicenceApplication::find($shop->id);

                $appp->update(['stage' => "APPLICATION PAYMENT", 'sync_status' => 'not synced']);


                LicenceApplicationSpecific::where('status', 'EXPIRED')->where('application_id', request('application_id'))->delete();

//                if ($shop->business_owner_number != null) {
//                    $message = 'Hello ' . $shop->business_owner_name . ' ' . ' Your'. ' '. $shop->licence->title .' ' .'application for'. ' ' . $shop->business_name.' '. ' is being processed';
//                    $phone [] = $shop->business_owner_number;
//                    sendSmsFunction($phone, $message);
//                }

                if (!request('saloonCheckbox') && !request('hawkerPedestrianCheckbox') && !request('tradingCheckbox')
                    && !request('cycleCheckbox') && !request('dogCheckbox') && !request('liquorCheckbox')) {
                    DB::commit();
                    return redirect()->route('application-preview', $shop->id)->with('success', 'Details saved successfully');
                }

//                 return view('businesslicencemanagement::invoice_latest',['invoice'=>$invoice]);


            }
            if (request('hawkerPedestrianCheckbox')) {
                $hawker = new LicenceApplication();
                $hawker->licence_type_id = 4;
                $hawker->sync_status = 'not synced';
                $hawker->user_id = Auth::user()->id;
                $hawker->council_id = Auth::user()->council_id;
                $hawker->applicant_name = ucwords(strtolower(request('applicant_fullName')));
                $hawker->applicant_number = request('applicantNumber');
                $hawker->applicant_id = request('applicantId');
                $hawker->applicant_address = ucwords(strtolower(request('applicantAddress')));
                $hawker->location_id = request('locationId');
                $hawker->district_id = request('districtId');
                $hawker->owner_applicant = request('isOwner') == 'true' ? 1 : 0;
                $hawker->vehicle_type = ucwords(strtolower(request('vehicle_type')));
                $hawker->licence_tariff_id = request('hawker_tariff_id');
                $hawker->status = "CLERK";
                $hawker->stage = "PAYMENT";
                $hawker->employee_id = portalAssistant();
                $hawker->vat_number = request('applicantVatNo');
                $hawker->bp_number = request('applicantBpNo');
                $hawker->goods_sold = request('goods_sold');
                $hawker->save();

                $hawker->update(['ref' => $hawker->id . mt_rand(1000000000, 9999999999)]);
                $invoice = LicenceInvoice::create([
                    'licence_type_id' => $hawker->licence_type_id,
                    'licence_application_id' => $hawker->id,
                    'user_id' => Auth::user()->id,
                    'council_id' => Auth::user()->council_id,
                    'employee_id' => portalAssistant(),
                    'type' => "Licence",
                    'status' => 'Pending',
                    'currency' => $currency,
                    'rate' => $rate,
                    'customer_name' => $hawker->applicant_name,
                    'customer_address' => $hawker->applicant_address,
                    'customer_id' => $hawker->applicant_id,
                    'customer_phone' => $hawker->applicant_number,
//                    'ref' => "4-" . $hawker->id . "-" . $hawker->district_id
                ]);

                $invoice->update(['ref' => $this->generateInvoiceNumber($invoice, 'Licence')]);

                $main_line = LicenceInvoiceLine::create([
                    'licence_tariff_id' => $hawker->licence_tariff_id,
                    'licence_application_id' => $hawker->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => $hawker->tariff->title . " " . $hawker->tariff->description,
                    'status' => 'Active',
                    'unit_price' => $hawker->tariff->price,
                    'quantity' => 1,
                    'is_vat' => 'no',
                    'is_discount' => 'no',
                    'total' => $hawker->tariff->price,
                ]);

                $vat_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $hawker->licence_type_id,
                    'licence_application_id' => $hawker->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => "vat @ 14.5 %",
                    'status' => 'Active',
                    'unit_price' => $hawker->licenceType->tax * $hawker->tariff->price,
                    'quantity' => 1,
                    'is_vat' => 'yes',
                    'total' => $hawker->licenceType->tax * $hawker->tariff->price,
                ]);
                if ($rate == 1)
                    $discount_line = LicenceInvoiceLine::create([
                        'licence_type_id' => $hawker->licence_type_id,
                        'licence_application_id' => $hawker->id,
                        'licence_invoice_id' => $invoice->id,
                        'description' => "discount " . ($hawker->licenceType->discount * 100) . "%",
                        'status' => 'Active',
                        'unit_price' => -($hawker->licenceType->discount * (($hawker->licenceType->tax * $hawker->tariff->price) + $hawker->tariff->price)),
                        'quantity' => 1,
                        'is_discount' => 'yes',
                        'total' => -($hawker->licenceType->discount * (($hawker->licenceType->tax * $hawker->tariff->price) + $hawker->tariff->price)),
                    ]);


//                if ($hawker->business_owner_number != null) {
//                    $message = 'Hello ' . $hawker->applicant_name . ' ' . ' Your'. ' '. $hawker->licence->title .' ' .'application is being processed';
//                    $phone [] = $hawker->business_owner_number;
//                    sendSmsFunction($phone, $message);
//                }

                if (!request('saloonCheckbox') && !request('shopCheckbox') && !request('tradingCheckbox')
                    && !request('cycleCheckbox') && !request('dogCheckbox') && !request('liquorCheckbox')) {
                    DB::commit();
                    return redirect()->route('application-preview', $hawker->id)->with('success', 'Details saved successfully');
                }

            }
            if (request('cycleCheckbox')) {
                $cycle = new LicenceApplication();
                $cycle->licence_type_id = 6;
                $cycle->sync_status = 'not synced';
                $cycle->user_id = Auth::user()->id;
                $cycle->council_id = Auth::user()->council_id;
                $cycle->applicant_name = ucwords(strtolower(request('applicant_fullName')));
                $cycle->applicant_number = request('applicantNumber');
                $cycle->applicant_id = request('applicantId');
                $cycle->applicant_address = ucwords(strtolower(request('applicantAddress')));
                $cycle->location_id = request('locationId');
                $cycle->district_id = request('districtId');
                $cycle->owner_applicant = request('isOwner') == 'true' ? 1 : 0;
                $cycle->vehicle_type = request('vehicleType');
                $cycle->licence_tariff_id = request('cycle_tariff_id');
                $cycle->bicycle = ucwords(strtolower(request('bicycle')));
                $cycle->maker_number = request('makenumber');
                $cycle->badge_number = request('badgenumber');
                $cycle->status = "CLERK";
                $cycle->stage = "PAYMENT";
                $cycle->employee_id = portalAssistant();
                $cycle->vat_number = request('applicantVatNo');
                $cycle->bp_number = request('applicantBpNo');
                $cycle->save();

                $cycle->update(['ref' => $cycle->id . mt_rand(1000000000, 9999999999)]);
                $invoice = LicenceInvoice::create([
                    'licence_type_id' => $cycle->licence_type_id,
                    'licence_application_id' => $cycle->id,
                    'user_id' => Auth::user()->id,
                    'council_id' => Auth::user()->council_id,
                    'type' => "Licence",
                    'employee_id' => portalAssistant(),
                    'status' => 'Pending',
                    'currency' => $currency,
                    'rate' => $rate,
                    'customer_name' => $cycle->applicant_name,
                    'customer_address' => $cycle->applicant_address,
                    'customer_id' => $cycle->applicant_id,
                    'customer_phone' => $cycle->applicant_number,
//                    'ref' => "4-" . $cycle->id . "-" . $cycle->district_id
                ]);

                $invoice->update(['ref' => $this->generateInvoiceNumber($invoice, 'Licence')]);

                $main_line = LicenceInvoiceLine::create([
                    'licence_tariff_id' => $cycle->licence_tariff_id,
                    'licence_application_id' => $cycle->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => $cycle->tariff->title . " " . $cycle->tariff->description,
                    'status' => 'Active',
                    'unit_price' => $cycle->tariff->price,
                    'quantity' => 1,
                    'is_vat' => 'no',
                    'is_discount' => 'no',
                    'total' => $cycle->tariff->price,
                ]);

                $vat_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $cycle->licence_type_id,
                    'licence_application_id' => $cycle->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => "vat @ 14.5 %",
                    'status' => 'Active',
                    'unit_price' => $cycle->licenceType->tax * $cycle->tariff->price,
                    'quantity' => 1,
                    'is_vat' => 'yes',
                    'total' => $cycle->licenceType->tax * $cycle->tariff->price,
                ]);
                if ($rate == 1)
                    $discount_line = LicenceInvoiceLine::create([
                        'licence_type_id' => $cycle->licence_type_id,
                        'licence_application_id' => $cycle->id,
                        'licence_invoice_id' => $invoice->id,
                        'description' => "discount " . ($cycle->licenceType->discount * 100) . "%",
                        'status' => 'Active',
                        'unit_price' => -($cycle->licenceType->discount * (($cycle->licenceType->tax * $cycle->tariff->price) + $cycle->tariff->price)),
                        'quantity' => 1,
                        'is_discount' => 'yes',
                        'total' => -($cycle->licenceType->discount * (($cycle->licenceType->tax * $cycle->tariff->price) + $cycle->tariff->price)),
                    ]);


//                if ($cycle->business_owner_number != null) {
//                    $message = 'Hello ' . $cycle->applicant_name . ' ' . ' Your'. ' '. $cycle->licence->title .' ' .'application for'. ' ' . $cycle->business_name .' '.'is being processed';
//                    $phone [] = $cycle->business_owner_number;
//                    sendSmsFunction($phone, $message);
//                }

                if (!request('saloonCheckbox') && !request('shopCheckbox') && !request('tradingCheckbox')
                    && !request('hawkerPedestrianCheckbox') && !request('dogCheckbox') && !request('liquorCheckbox')) {
                    DB::commit();
                    return redirect()->route('application-preview', $cycle->id)->with('success', 'Details saved successfully');
                }


            }
            if (request('dogCheckbox')) {
                $dog = new LicenceApplication();
                $dog->licence_type_id = 5;
                $dog->sync_status = 'not synced';
                $dog->user_id = Auth::user()->id;
                $dog->council_id = Auth::user()->council_id;
                $dog->applicant_name = ucwords(strtolower(request('applicant_fullName')));
                $dog->applicant_number = request('applicantNumber');
                $dog->applicant_id = request('applicantId');
                $dog->applicant_address = ucwords(strtolower(request('applicantAddress')));
                $dog->location_id = request('locationId');
                $dog->district_id = request('districtId');
                $dog->owner_applicant = request('isOwner') == 'true' ? 1 : 0;
                $dog->licence_tariff_id = request('dog_tariff_id');
                $dog->breed = ucwords(strtolower(request('breed')));
                $dog->sex = ucwords(strtolower(request('sex')));
                $dog->colour = ucwords(strtolower(request('dog-color')));
                $dog->dog_name = ucwords(strtolower(request('dog_name')));
                $dog->status = "CLERK";
                $dog->stage = "PAYMENT";
                $dog->employee_id = portalAssistant();
                $dog->vat_number = request('applicantVatNo');
                $dog->bp_number = request('applicantBpNo');
                $dog->save();

                $dog->update(['ref' => $dog->id . mt_rand(100000, 999999)]);

                $invoice = LicenceInvoice::create([
                    'licence_type_id' => $dog->licence_type_id,
                    'licence_application_id' => (int)$dog->ref,
                    'employee_id' => portalAssistant(),
                    'user_id' => Auth::user()->id,
                    'council_id' => Auth::user()->council_id,
                    'type' => "Licence",
                    'status' => 'Pending',
                    'currency' => $currency,
                    'rate' => $rate,
                    'customer_name' => $dog->applicant_name,
                    'customer_address' => $dog->applicant_address,
                    'customer_id' => $dog->applicant_id,
                    'customer_phone' => $dog->applicant_number,
//                    'ref' => "4-" . $dog->id . "-" . $dog->district_id
                ]);

                $invoice->update(['ref' => $this->generateInvoiceNumber($invoice, 'Licence')]);

                $dogs = $request->dog;

                $loop_count = 0;
                foreach ($dogs as $dg) {
                    if ($loop_count == 0) {
                        $dog->update($dg);
                    } else {
                        $new_dog = $dog->replicate();
                        $new_dog->push();
                        $new_dog->update($dg);
                    }
                    $loop_count++;
                }

                $created_applications = LicenceApplication::where('ref', $dog->ref)
                    ->get()
                    ->pluck('licence_tariff_id')
                    ->toArray();

                $tariffs_quantities = array_count_values($created_applications);
                foreach ($tariffs_quantities as $tariff => $quantity) {
                    $tariff = LicenceTarriff::find($tariff);
                    $main_line = LicenceInvoiceLine::create([
                        'licence_tariff_id' => $tariff->id,
                        'licence_application_id' => $dog->ref,
                        'licence_invoice_id' => $invoice->id,
                        'description' => $tariff->title . " " . $tariff->description,
                        'status' => 'Active',
                        'unit_price' => $tariff->price,
                        'quantity' => $quantity,
                        'total' => $tariff->price * $quantity,
                    ]);
                }
                $total = $dog->activeLicenceInvoice->total;

                $vat_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $dog->licence_type_id,
                    'licence_application_id' => $dog->ref,
                    'licence_invoice_id' => $invoice->id,
                    'description' => "vat @ 14.5 %",
                    'status' => 'Active',
                    'unit_price' => $dog->licenceType->tax * $dog->tariff->price,
                    'quantity' => 1,
                    'is_vat' => 'yes',
                    'total' => $dog->licenceType->tax * $dog->tariff->price,
                ]);

                if ($rate == 1)
                    $discount_line = LicenceInvoiceLine::create([
                        'licence_type_id' => $dog->licence_type_id,
                        'licence_application_id' => $dog->ref,
                        'licence_invoice_id' => $invoice->id,
                        'description' => "discount " . ($dog->licenceType->discount * 100) . "%",
                        'status' => 'Active',
                        'unit_price' => -($dog->licenceType->discount * (($dog->licenceType->tax * $dog->tariff->price) + $dog->tariff->price)),
                        'quantity' => 1,
                        'is_discount' => 'yes',
                        'total' => -($dog->licenceType->discount * (($dog->licenceType->tax * $dog->tariff->price) + $dog->tariff->price)),
                    ]);


//                if ($dog->business_owner_number != null) {
//                    $message = 'Hello ' . $dog->applicant_name . ' ' . 'Your'. ' '. $dog->licence->title .' ' .'application for' . ' ' . $dog->dog_name. ' '. 'is being processed';
//                    $phone [] = $dog->business_owner_number;
//                    sendSmsFunction($phone, $message);
//                }

                if (!request('saloonCheckbox') && !request('shopCheckbox') && !request('tradingCheckbox')
                    && !request('hawkerPedestrianCheckbox') && !request('cycleCheckbox') && !request('liquorCheckbox')) {
                    DB::commit();
                    return redirect()->route('application-preview', $dog->id)->with('success', 'Details saved successfully');
                }

            }
            if (request('tradingCheckbox')) {
                $trading = new LicenceApplication();
                $trading->licence_type_id = 2;
                $trading->sync_status = 'not synced';
                $trading->user_id = Auth::user()->id;
                $trading->council_id = Auth::user()->council_id;
                $trading->applicant_name = ucwords(strtolower(request('applicant_fullName')));
                $trading->applicant_number = request('applicantNumber');
                $trading->applicant_id = request('applicantId');
                $trading->applicant_address = ucwords(strtolower(request('applicantAddress')));
                $trading->location_id = request('locationId');
                $trading->district_id = request('districtId');
                $trading->owner_applicant = request('isOwner') == 'true' ? 1 : 0;
                $trading->business_owner_name = request('isOwner') == 'true' ? ucwords(strtolower(request('tradingBusinessOwnerName'))) : Auth::user()->full_name;
                $trading->business_owner_number = request('isOwner') == 'true' ? ucwords(strtolower(request('tradingBusinessOwnerNumber'))) : Auth::user()->telephone;
                $trading->business_owner_email = request('isOwner') == 'true' ? strtolower(request('tradingBusinessOwnerEmail')) : Auth::user()->email;
                $trading->business_owner_address = request('isOwner') == 'true' ? ucwords(strtolower(request('tradingBusinessOwnerAddress'))) : Auth::user()->address;
                $trading->business_name = ucwords(strtolower(request('tradingBusinessName')));
                $trading->business_address = ucwords(strtolower(request('businessAddressTrading')));
                $trading->trading_as = ucwords(strtolower(request('tradingBusinessTradeAs')));
                $trading->licence_tariff_id = request('trading_tariff');
                $trading->stand_number = request('tradingRoomNo');
                $trading->status = "CLERK";
                $trading->stage = "SET CYCLE";
                $trading->employee_id = portalAssistant();
                $trading->vat_number = request('applicantVatNo');
                $trading->bp_number = request('applicantBpNo');
                $trading->save();

                $trading->update(['ref' => $trading->id . mt_rand(1000000000, 9999999999)]);
                $premise = PremiseDetail::where('physical_address', request('businessAddressTrading'))->first();

                if (!$premise) {
                    $premise = new PremiseDetail();
                    $premise->premise_owner = ucwords(strtolower('N/A'));
                    $premise->account_no = 'N/A';
                    $premise->stand = ucwords(strtolower('N/A'));
                    $premise->physical_address = ucwords(strtolower(request('businessAddressTrading')));
                    $premise->location = ucwords(strtolower(request('locationId')));
                    $premise->contact = 'N/A';
                    $premise->email = 'N/A';
                    $premise->save();
                }
                $room = new PremiseSpace();
                $room->premise_id = $premise->id;
                $room->room = ucwords(strtolower(request('tradingRoomNo')));
                $room->type = ucwords(strtolower('room'));
                $room->space = 1;
                $room->notes = ucwords(strtolower(request('tradingRoomNo')));
                $room->status = "VACANT";
                $room->save();
                $trading->update(['premise_space_id' => $room->id]);

                LicenceClearance::create([
                    'licence_application_id' => $trading->id,
                    'premise_detail_id' => $premise->id,
                    'cleared' => 'Pending'
                ]);


                $invoice = LicenceInvoice::create([
                    'licence_type_id' => $trading->licence_type_id,
                    'licence_application_id' => $trading->id,
                    'employee_id' => portalAssistant(),
                    'user_id' => Auth::user()->id,
                    'council_id' => Auth::user()->council_id,
                    'type' => "Application",
                    'status' => 'Pending',
                    'currency' => $currency,
                    'rate' => $rate,
                    'customer_name' => $trading->applicant_name,
                    'customer_address' => $trading->applicant_address,
                    'customer_id' => $trading->applicant_id,
                    'customer_phone' => $trading->applicant_number,
//                    'ref' => "2-" . $trading->id . "-" . $trading->district_id
                ]);

                $invoice->update(['ref' => $this->generateInvoiceNumber($invoice, 'Application')]);

                $main_line = LicenceInvoiceLine::create([
                    'licence_tariff_id' => $trading->licence_tariff_id,
                    'licence_application_id' => $trading->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => $trading->tariff->title . " " . $trading->tariff->description . ' Application fee',
                    'status' => 'Active',
                    'unit_price' => $trading->tariff->application_fee,
                    'quantity' => 1,
                    'is_vat' => 'no',
                    'is_discount' => 'no',
                    'total' => $trading->tariff->application_fee,
                ]);

                $vat_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $trading->licence_type_id,
                    'licence_application_id' => $trading->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => "vat @ 14.5 %",
                    'status' => 'Active',
                    'unit_price' => $trading->licenceType->tax * $trading->tariff->application_fee,
                    'quantity' => 1,
                    'is_vat' => 'yes',
                    'total' => $trading->licenceType->tax * $trading->tariff->application_fee,
                ]);
                if ($rate == 1)

                    $discount_line = LicenceInvoiceLine::create([
                        'licence_type_id' => $trading->licence_type_id,
                        'licence_application_id' => $trading->id,
                        'licence_invoice_id' => $invoice->id,
                        'description' => "discount " . ($trading->licenceType->discount * 100) . "%",
                        'status' => 'Active',
                        'unit_price' => -($trading->licenceType->discount * (($trading->licenceType->tax * $trading->tariff->application_fee) + $trading->tariff->application_fee)),
                        'quantity' => 1,
                        'is_discount' => 'yes',
                        'total' => -($trading->licenceType->discount * (($trading->licenceType->tax * $trading->tariff->application_fee) + $trading->tariff->application_fee)),
                    ]);

                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = $trading->id;
                $subscription->start_date = Carbon::parse('first day of January');
                $subscription->end_date = Carbon::parse('last day of December');
                $subscription->validity = 'Annual';
                $subscription->term = 'January - December';
                $subscription->status = "PENDING";
                $subscription->notes = ucwords(strtolower('yearly'));
                $subscription->save();

                $appp = LicenceApplication::find($trading->id);

                $appp->update(['stage' => "APPLICATION PAYMENT", 'sync_status' => 'not synced']);


                LicenceApplicationSpecific::where('status', 'EXPIRED')->where('application_id', request('application_id'))->delete();

//                if ($trading->business_owner_number != null) {
//                    $message = 'Hello ' . $trading->business_owner_name . ' ' . ' Your'. ' '. $trading->licence->title .' ' .'application for'. ' ' . $trading->business_name.' '. ' is being processed';
//                    $phone [] = $trading->business_owner_number;
//                    sendSmsFunction($phone, $message);
//                }


                if (!request('saloonCheckbox') && !request('shopCheckbox') && !request('dogCheckbox')
                    && !request('hawkerPedestrianCheckbox') && !request('cycleCheckbox') && !request('liquorCheckbox')) {
                    DB::commit();
                    return redirect()->route('application-preview', $trading->id)->with('success', 'Details saved successfully');
                }
            }
            if (request('liquorCheckbox')) {
                $liquor = new LicenceApplication();
                $liquor->licence_type_id = 7;
                $liquor->sync_status = 'not synced';
                $liquor->user_id = Auth::user()->id;
                $liquor->council_id = Auth::user()->council_id;
                $liquor->applicant_name = ucwords(strtolower(request('applicant_fullName')));
                $liquor->applicant_number = request('applicantNumber');
                $liquor->applicant_id = request('applicantId');
                $liquor->applicant_address = ucwords(strtolower(request('applicantAddress')));
                $liquor->location_id = request('locationId');
                $liquor->district_id = request('districtId');
                $liquor->owner_applicant = request('isOwner') == 'true' ? 1 : 0;
                $liquor->business_owner_name = request('isOwner') == 'true' ? ucwords(strtolower(request('LiquorBusinessOwnerName'))) : Auth::user()->full_name;
                $liquor->business_owner_number = request('isOwner') == 'true' ? ucwords(strtolower(request('liquorBusinessOwnerNumber'))) : Auth::user()->telephone;
                $liquor->business_owner_email = request('isOwner') == 'true' ? strtolower(request('liquorBusinessOwnerEmail')) : Auth::user()->email;
                $liquor->business_owner_address = request('isOwner') == 'true' ? ucwords(strtolower(request('liquorBusinessOwnerAddress'))) : Auth::user()->address;
                $liquor->business_name = ucwords(strtolower(request('liquorBusinessName')));
                $liquor->business_address = ucwords(strtolower(request('businessAddressLiquor')));
                $liquor->trading_as = ucwords(strtolower(request('liquorBusinessTradeAs')));
//                $liquor->licence_tariff_id = request('liquor_fee');
                $liquor->stand_number = request('liquorRoomNo');
                $liquor->status = "CLERK";
                $liquor->stage = "SET CYCLE";
                $liquor->employee_id = portalAssistant();
                $liquor->vat_number = request('applicantVatNo');
                $liquor->bp_number = request('applicantBpNo');
                $liquor->save();

                $liquor->update(['ref' => $liquor->id . mt_rand(1000000000, 9999999999)]);

                $premise = PremiseDetail::where('physical_address', request('businessAddressLiquor'))->first();

                if (!$premise) {
                    $premise = new PremiseDetail();
                    $premise->premise_owner = ucwords(strtolower('N/A'));
                    $premise->account_no = 'N/A';
                    $premise->stand = ucwords(strtolower('N/A'));
                    $premise->physical_address = ucwords(strtolower(request('businessAddressLiquor')));
                    $premise->location = ucwords(strtolower(request('locationId')));
                    $premise->contact = 'N/A';
                    $premise->email = 'N/A';
                    $premise->save();
                }
                $room = new PremiseSpace();
                $room->premise_id = $premise->id;
                $room->room = ucwords(strtolower(request('liquorRoomNo')));
                $room->type = ucwords(strtolower('room'));
                $room->space = 1;
                $room->notes = ucwords(strtolower(request('liquorRoomNo')));
                $room->status = "VACANT";
                $room->save();
                $liquor->update(['premise_space_id' => $room->id]);

                LicenceClearance::create([
                    'licence_application_id' => $liquor->id,
                    'premise_detail_id' => $premise->id,
                    'cleared' => 'Pending'
                ]);


                $invoice = LicenceInvoice::create([
                    'licence_type_id' => $liquor->licence_type_id,
                    'licence_application_id' => $liquor->id,
                    'employee_id' => portalAssistant(),
                    'user_id' => Auth::user()->id,
                    'council_id' => Auth::user()->council_id,
                    'type' => "Application",
                    'status' => 'Pending',
                    'currency' => $currency,
                    'rate' => $rate,
                    'customer_name' => $liquor->applicant_name,
                    'customer_address' => $liquor->applicant_address,
                    'customer_id' => $liquor->applicant_id,
                    'customer_phone' => $liquor->applicant_number,
//                    'ref' => "4-" . $liquor->id . "-" . $liquor->district_id
                ]);

                $invoice->update(['ref' => $this->generateInvoiceNumber($invoice, 'Application')]);

                $main_line = LicenceInvoiceLine::create([
//                    'licence_tariff_id'=>$liquor->licence_tariff_id,
                    'licence_application_id' => $liquor->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => $liquor->licenceType->title . 'Application fee',
                    'status' => 'Active',
                    'unit_price' => $liquor->licenceType->inspection_fee,
                    'quantity' => 1,
                    'is_vat' => 'no',
                    'is_discount' => 'no',
                    'total' => $liquor->licenceType->inspection_fee,
                ]);

                $vat_line = LicenceInvoiceLine::create([
//                    'licence_tariff_id'=>$liquor->licence_tariff_id,
                    'licence_application_id' => $liquor->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => "vat @ 14.5 %",
                    'status' => 'Active',
                    'unit_price' => $liquor->licenceType->tax * $liquor->licenceType->inspection_fee,
                    'quantity' => 1,
                    'is_vat' => 'yes',
                    'total' => $liquor->licenceType->tax * $liquor->licenceType->inspection_fee,
                ]);
                if ($rate == 1)
                    $discount_line = LicenceInvoiceLine::create([
                        'licence_type_id' => $liquor->licence_type_id,
                        'licence_application_id' => $liquor->id,
                        'licence_invoice_id' => $invoice->id,
                        'description' => "discount " . ($liquor->licenceType->discount * 100) . "%",
                        'status' => 'Active',
                        'unit_price' => -($liquor->licenceType->discount * (($liquor->licenceType->tax * $liquor->licenceType->inspection_fee) + $liquor->licenceType->inspection_fee)),
                        'quantity' => 1,
                        'is_discount' => 'yes',
                        'total' => -($liquor->licenceType->discount * (($liquor->licenceType->tax * $liquor->licenceType->inspection_fee) + $liquor->licenceType->inspection_fee)),
                    ]);

                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = $liquor->id;
                $subscription->start_date = Carbon::parse('first day of January');
                $subscription->end_date = Carbon::parse('last day of December');
                $subscription->validity = 'Annual';
                $subscription->term = 'January - December';
                $subscription->status = "PENDING";
                $subscription->notes = ucwords(strtolower('yearly'));
                $subscription->save();

                $appp = LicenceApplication::find($liquor->id);

                $appp->update(['stage' => "APPLICATION PAYMENT", 'sync_status' => 'not synced']);


                LicenceApplicationSpecific::where('status', 'EXPIRED')->where('application_id', request('application_id'))->delete();

//                if ($liquor->business_owner_number != null) {
//                    $message = 'Hello ' . $liquor->business_owner_name . ' ' . ' Your'. ' '. $liquor->licence->title .' ' .'application for'. ' ' . $liquor->business_name.' '. ' is being processed';
//                    $phone [] = $liquor->business_owner_number;
//                    sendSmsFunction($phone, $message);
//                }

                if (!request('saloonCheckbox') && !request('shopCheckbox') && !request('dogCheckbox')
                    && !request('hawkerPedestrianCheckbox') && !request('cycleCheckbox') && !request('tradingCheckbox')) {
                    DB::commit();
                    return redirect()->route('application-preview', $liquor->id)->with('success', 'Details saved successfully');
                }

            }
            if (request('saloonCheckbox')) {
                $saloon = new LicenceApplication();
                $saloon->licence_type_id = 3;
                $saloon->sync_status = 'not synced';
                $saloon->user_id = Auth::user()->id;
                $saloon->council_id = Auth::user()->council_id;
                $saloon->applicant_name = ucwords(strtolower(request('applicant_fullName')));
                $saloon->applicant_number = request('applicantNumber');
                $saloon->applicant_id = request('applicantId');
                $saloon->applicant_address = ucwords(strtolower(request('applicantAddress')));
                $saloon->location_id = request('locationId');
                $saloon->district_id = request('districtId');
                $saloon->owner_applicant = request('isOwner') == 'true' ? 1 : 0;
                $saloon->business_owner_name = request('isOwner') == 'true' ? ucwords(strtolower(request('saloonBusinessOwnerName'))) : Auth::user()->full_name;
                $saloon->business_owner_number = request('isOwner') == 'true' ? request('saloonBusinessOwnerNumber') : Auth::user()->telephone;
                $saloon->business_owner_email = request('isOwner') == 'true' ? strtolower(request('saloonBusinessOwnerEmail')) : Auth::user()->email;
                $saloon->business_owner_address = request('isOwner') == 'true' ? ucwords(strtolower(request('saloonBusinessOwnerAddress'))) : Auth::user()->address;
                $saloon->business_name = ucwords(strtolower(request('saloonBusinessName')));
                $saloon->business_address = ucwords(strtolower(request('businessAddresssaloon')));
                $saloon->trading_as = ucwords(strtolower(request('saloonBusinessTradeAs')));
                $saloon->stand_number = request('saloonRoomNo');
                $saloon->status = "CLERK";
                $saloon->stage = "SET CYCLE";
                $saloon->employee_id = portalAssistant();
                $saloon->vat_number = request('applicantVatNo');
                $saloon->bp_number = request('applicantBpNo');
                $saloon->save();

                $saloon->update(['ref' => $saloon->id . mt_rand(1000000000, 9999999999)]);

                $premise = PremiseDetail::where('physical_address', request('businessAddresssaloon'))->first();

                if (!$premise) {
                    $premise = new PremiseDetail();
                    $premise->premise_owner = ucwords(strtolower('N/A'));
                    $premise->account_no = 'N/A';
                    $premise->stand = ucwords(strtolower('N/A'));
                    $premise->physical_address = ucwords(strtolower(request('businessAddresssaloon')));
                    $premise->location = ucwords(strtolower(request('locationId')));
                    $premise->contact = 'N/A';
                    $premise->email = 'N/A';
                    $premise->save();
                }
                $room = new PremiseSpace();
                $room->premise_id = $premise->id;
                $room->room = ucwords(strtolower(request('saloonRoomNo')));
                $room->type = ucwords(strtolower('room'));
                $room->space = 1;
                $room->notes = ucwords(strtolower(request('saloonRoomNo')));
                $room->status = "VACANT";
                $room->save();
                $saloon->update(['premise_space_id' => $room->id]);
                LicenceClearance::create([
                    'licence_application_id' => $saloon->id,
                    'premise_detail_id' => $premise->id,
                    'cleared' => 'Pending'
                ]);

                $saloon_tariff = LicenceTarriff::where('licence_type_id', 3)->first();

                $invoice = LicenceInvoice::create([
                    'licence_type_id' => $saloon->licence_type_id,
                    'licence_application_id' => $saloon->id,
                    'employee_id' => portalAssistant(),
                    'user_id' => Auth::user()->id,
                    'council_id' => Auth::user()->council_id,
                    'type' => "Application",
                    'status' => 'Pending',
                    'currency' => $currency,
                    'rate' => $rate,
                    'customer_name' => $saloon->applicant_name,
                    'customer_address' => $saloon->applicant_address,
                    'customer_id' => $saloon->applicant_id,
                    'customer_phone' => $saloon->applicant_number,
//                    'ref' => "4-" . $saloon->id . "-" . $saloon->district_id
                ]);

                $invoice->update(['ref' => $this->generateInvoiceNumber($invoice, 'Application')]);

                $main_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $saloon->licence_type_id,
                    'licence_application_id' => $saloon->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => $saloon->licenceType->title . 'Application fee',
                    'status' => 'Active',
                    'unit_price' => $saloon_tariff->health_fee,
                    'quantity' => 1,
                    'is_vat' => 'no',
                    'is_discount' => 'no',
                    'total' => $saloon_tariff->health_fee,
                ]);

                $vat_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $saloon->licence_type_id,
                    'licence_application_id' => $saloon->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => "vat @ 14.5 %",
                    'status' => 'Active',
                    'unit_price' => $saloon->licenceType->tax * $saloon_tariff->health_fee,
                    'quantity' => 1,
                    'is_vat' => 'yes',
                    'total' => $saloon->licenceType->tax * $saloon_tariff->health_fee,
                ]);
                if ($rate == 1)
                    $discount_line = LicenceInvoiceLine::create([
                        'licence_type_id' => $saloon->licence_type_id,
                        'licence_application_id' => $saloon->id,
                        'licence_invoice_id' => $invoice->id,
                        'description' => "discount " . ($saloon->licenceType->discount * 100) . "%",
                        'status' => 'Active',
                        'unit_price' => -($saloon->licenceType->discount * (($saloon->licenceType->tax * $saloon_tariff->health_fee) + $saloon_tariff->health_fee)),
                        'quantity' => 1,
                        'is_discount' => 'yes',
                        'total' => -($saloon->licenceType->discount * (($saloon->licenceType->tax * $saloon_tariff->health_fee) + $saloon_tariff->health_fee)),
                    ]);


                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = $saloon->id;
                $subscription->start_date = Carbon::parse('first day of January');
                $subscription->end_date = Carbon::parse('last day of December');
                $subscription->validity = 'Annual';
                $subscription->term = 'January - December';
                $subscription->status = "PENDING";
                $subscription->notes = ucwords(strtolower('yearly'));
                $subscription->save();

                $appp = LicenceApplication::find($saloon->id);

                $appp->update(['stage' => "APPLICATION PAYMENT", 'sync_status' => 'not synced']);


                LicenceApplicationSpecific::where('status', 'EXPIRED')->where('application_id', request('application_id'))->delete();
//                if ($saloon->business_owner_number != null) {
//                    $message = 'Hello ' . $saloon->business_owner_name . ' ' . ' Your'. ' '. $saloon->licence->title .' ' .'application for'. ' ' . $saloon->business_name.' '. 'is being processed';
//                    $phone [] = $saloon->business_owner_number;
//                    sendSmsFunction($phone, $message);
//                }

                if (!request('liquorCheckbox') && !request('shopCheckbox') && !request('dogCheckbox')
                    && !request('hawkerPedestrianCheckbox') && !request('cycleCheckbox') && !request('tradingCheckbox')) {
                    DB::commit();
                    return redirect()->route('application-preview', $saloon->id)->with('success', 'Details saved successfully');
                }
            }

            DB::commit();
            return redirect()->route('user-my-business-licence')->with('success', 'Details saved successfully');
        } catch (Exception $e) {
            DB::rollback();
            return back()->with('error', 'Failed to save details');
            dd($e);
        }
    }

    public function generateInvoiceNumber(LicenceInvoice $invoice, $invoice_type): string
    {
//         get and trim dates
        $today = Carbon::now();
        $year = $today->format('y');
        $licence_type = $invoice->licence_type_id;
        $number = LicenceInvoice::whereYear('created_at', Carbon::now())->where('licence_type_id', $licence_type)->where('type', $invoice_type)->count();
        $length = strlen($number);
        if ($invoice_type == 'Application') {
            $invoice_number = $year . 'P1' . $licence_type;
        } else {
            $invoice_number = $year . 'P2' . $licence_type;
        }

        if ($length == 4) {
            $invoice_number .= $number;
        } elseif ($length == 3) {
            $invoice_number .= '0' . $number;
        } elseif ($length == 2) {
            $invoice_number .= '00' . $number;
        } elseif ($length == 1) {
            $invoice_number .= '000' . $number;
        } else {
            $invoice_number .= $number;

        }
        return $invoice_number;
    }

    public function applyCycleSelection(Request $request): \Illuminate\Http\RedirectResponse
    {
//        dd($request->all());

        if (request('validity') == 'Quarterly') {

            if (request('term') == "January - March") {
                if (Carbon::parse('last day of March') < date('Y-m-d')) {
                    return back()->with('danger', 'Invalid Term: You have a selected a period that has already passed');
                }
                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = request('application_id');
                $subscription->start_date = Carbon::parse('first day of January');
                $subscription->end_date = Carbon::parse('last day of March');
                $subscription->validity = '1st Quarter';
                $subscription->term = request('term');
                $subscription->status = "PENDING";
                $subscription->notes = ucwords(strtolower(request('notes')));

                $subscription->save();

            } elseif (request('term') == 'April - June') {

                if (Carbon::parse('last day of June') < date('Y-m-d')) {
                    return back()->with('danger', 'Invalid Term: You have a selected a period that has already passed');
                }
                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = request('application_id');
                $subscription->start_date = Carbon::parse('first day of April');
                $subscription->end_date = Carbon::parse('last day of June');
                $subscription->validity = '2nd Quarter';
                $subscription->term = request('term');
                $subscription->status = "PENDING";
                $subscription->notes = ucwords(strtolower(request('notes')));

                $subscription->save();

            } elseif (request('term') == 'July - September') {
                if (Carbon::parse('last day of September') < date('Y-m-d')) {
                    return back()->with('danger', 'Invalid Term: You have a selected a period that has already passed');
                }
                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = request('application_id');
                $subscription->start_date = Carbon::parse('first day of July');
                $subscription->end_date = Carbon::parse('last day of September');
                $subscription->validity = '3rd Quarter';
                $subscription->term = request('term');
                $subscription->status = "PENDING";
                $subscription->notes = ucwords(strtolower(request('notes')));

                $subscription->save();
            } elseif (request('term') == "October - December") {

                if (Carbon::parse('last day of December') < date('Y-m-d')) {
                    return back()->with('danger', 'Invalid Term: You have a selected a period that has already passed');
                }
                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = request('application_id');
                $subscription->start_date = Carbon::parse('first day of October');
                $subscription->end_date = Carbon::parse('last day of December');
                $subscription->validity = '4th Quarter';
                $subscription->term = request('term');
                $subscription->status = "PENDING";
                $subscription->notes = ucwords(strtolower(request('notes')));

                $subscription->save();
            } else {
                return back()->with('danger', 'Invalid Term: You have a selected a period that has already passed');
            }

        } elseif (request('validity') == 'Bi-Annually') {
            if (request('term') == "January - June") {
                if (Carbon::parse('last day of June') < date('Y-m-d')) {
                    return back()->with('danger', 'Invalid Term: You have a selected a period that has already passed');
                }
                $subscription = new LicenceApplicationSpecific();
                $subscription->application_id = request('application_id');
                $subscription->start_date = Carbon::parse('first day of January');
                $subscription->end_date = Carbon::parse('last day of June');
                $subscription->validity = '1st Half';
                $subscription->term = request('term');
                $subscription->status = "PENDING";
                $subscription->notes = request('notes');

                $subscription->save();

            } elseif (request('term') == 'July - December') {

                if (Carbon::parse('last day of December') < date('Y-m-d')) {
                    return back()->with('danger', 'Invalid Term: You have a selected a period that has already passed');
                }
                $subscription = new LicenceApplicationSpecific();


                $subscription->application_id = request('application_id');
                $subscription->start_date = Carbon::parse('first day of July');
                $subscription->end_date = Carbon::parse('last day of December');
                $subscription->validity = '2nd Half';
                $subscription->term = request('term');
                $subscription->status = "PENDING";
                $subscription->notes = request('notes');

                $subscription->save();

            }
        } elseif (request('validity') == 'Yearly') {


            $subscription = new LicenceApplicationSpecific();

            $subscription->application_id = request('application_id');
            $subscription->start_date = Carbon::parse('first day of January');
            $subscription->end_date = Carbon::parse('last day of December');
            $subscription->validity = 'Annual';
            $subscription->term = request('term');
            $subscription->status = "PENDING";
            $subscription->notes = ucwords(strtolower(request('notes')));
            $subscription->save();
        }

        $appp = LicenceApplication::find(request('application_id'));

        $appp->update(['stage' => "APPLICATION PAYMENT", 'sync_status' => 'not synced']);


        LicenceApplicationSpecific::where('status', 'EXPIRED')->where('application_id', request('application_id'))->delete();
        return back()->with('success', 'Details successfully saved');
    }

    public function CreatePayment(Request $request)
    {
        $validation = $request->validate([
            'applicant_id' => 'required|integer',
            'phone_number' => 'required|string',
            'type' => 'required|string',
            'payer_name' => 'required|string',
            'amount' => 'required|numeric|min:100',
            'email' => 'email'
        ]);

        $currencies = FinancialCurrency::where('code', 'ZWL')->first();
        $app = LicenceApplication::find($validation['applicant_id']);

        if($app->licence_type_id == 5){
            $invoice = LicenceInvoice::where('status', 'Pending')->where('licence_application_id', $app->ref)->first();
        }else{
            $invoice = LicenceInvoice::where('status', 'Pending')->where('licence_application_id', $app->id)->first();
        }

        $user_email = $validation['email'];
        $amount = $validation['amount'];
        $phone = $validation['phone_number'];

        //demo paynow keys
//        c0d38bd3-ca5b-413d-b4eb-50640b62e7a1
//        14894

        //        city of mutare paynow
//        15097
//        cee0972f-46a3-4e5d-a2d6-b442d95b037f

        $type = $this->checkNumber($phone);

        if ($this->not_number) {
            return back()->with('error', 'Please Enter Eco-cash Number Or A Net-one Number');
        } else {
            $createPayment = $this->payment();
            $payment = $createPayment->createPayment('BusinessLicence Application', $user_email);
            $payment->add('Licence Application', $amount);
            $response = $createPayment->sendMobile($payment, $phone, $type);

            if ($response->success()) {
                // Get the poll url (used to check the status of a transaction). You might want to save this in your DB
                $pollUrl = $response->pollUrl();
                $transaction = $createPayment->pollTransaction($pollUrl)->data();
                $instrutions = $response->instructions();
                try {
                    DB::beginTransaction();
                    $status = $createPayment->pollTransaction($pollUrl);
                    $payment = new PortalPayment();
                    $payment->reference = $validation['type'];
                    $payment->pay_now_reference = $transaction['paynowreference'];
                    $payment->amount = ($transaction['amount'] / $currencies->rate);
                    $payment->status = $transaction['status'];
                    $payment->poll_url = $transaction['pollurl'];
                    $payment->hash = $transaction['hash'];
                    $payment->user_id = Auth::user()->id;
                    $payment->council_id = Auth::user()->council_id;
                    $payment->application_id = $request->applicant_id;
                    $payment->platform = 'portal';
                    $payment->invoice_id = $invoice->id;
                    $payment->employee_id = portalAssistant();
                    $payment->rate = $currencies->rate;
                    $payment->save();

                    DB::commit();
                    return Redirect::route('application-preview', $request->applicant_id)->with('success', 'payment request has been sent successfully');

                } catch (\Exception $e) {
                    DB::rollback();
                    return back()->with('error', $e->getMessage());
                }

            } else {
                return back()->with('error', 'failed to process transaction');
            }
        }
    }

    public function previewLicence(Request $request)
    {
//        return $request->all();
        $id = $request->app_id;

        try {
            $applicant = LicenceApplication::where('id', $id)->first();
            $licence = Licence::where('licence_application_id', $applicant->id)
                ->where('status', 'Issued')->first();
            $company = Council::where('id', Auth::user()->council_id)->first();
            $collection = null;

            $lo = LicenceStageSetting::where('stage', 'lo')->get()->first()->stage_approver;
            $hd = LicenceStageSetting::where('stage', 'hd')->get()->first()->stage_approver;

            $licence->update(['collected_on' => carbon::now(), 'issued_by' => 1639]);
            $applicant->update(['stage' => 'COLLECTED', 'sync_status' => 'not synced']);
            $collection = "true";

            $license = Licence::where('licence_application_id', $id)->whereIn('status', ['Issued', 'Pending'])->first();

            if ($license->licence_type_id == 1) {

                if ($license->type == 'Permanent')
                    return view('usermanagement::business-licence.licences.shop-permanent', ['licence' => $license, 'collected' => $collection, 'lo' => $lo, 'hd' => $hd, 'application' => $applicant, 'company' => $company]);

                return view('usermanagement::business-licence.licences.shop', ['licence' => $license, 'collected' => $collection, 'lo' => $lo, 'hd' => $hd, 'application' => $applicant, 'company' => $company]);
            } elseif ($license->licence_type_id == 2) {
                return view('usermanagement::business-licence.licences.trading', ['licence' => $license, 'collected' => $collection, 'lo' => $lo, 'hd' => $hd, 'application' => $applicant, 'company' => $company]);
            } elseif ($license->licence_type_id == 3) {
                return view('usermanagement::business-licence.licences.registration', ['licence' => $license, 'collected' => $collection, 'lo' => $lo, 'hd' => $hd, 'application' => $applicant, 'company' => $company]);
            } elseif ($license->licence_type_id == 4) {
                return view('usermanagement::business-licence.licences.hawkers', ['licence' => $license, 'collected' => $collection, 'lo' => $lo, 'hd' => $hd, 'application' => $applicant, 'company' => $company]);
            } elseif ($license->licence_type_id == 5) {
                return view('usermanagement::business-licence.licences.dog', ['application' => $applicant, 'collected' => $collection, 'lo' => $lo, 'hd' => $hd, 'company' => $company]);
            } elseif ($license->licence_type_id == 6) {
                return view('usermanagement::business-licence.licences.cycle', ['application' => $applicant, 'collected' => $collection, 'lo' => $lo, 'hd' => $hd, 'company' => $company]);
            }

        } catch (\Exception $e) {
            return back()->with('danger', 'Failed to retrieve license information');
        }

    }

    public function licenceFee(Request $request)
    {
        $currencies = FinancialCurrency::where('code', 'ZWL')->first();
        $currency = request('currency');
        $rate = $currency == 'rtgs' ? $currencies->rate : 1;

        $invoice = LicenceInvoice::find($request->inv);
//        if ($invoice->licence_tariff_id != null) {
//            $tariff = LicenceTarriff::find($invoice->licence_tariff_id);
//        }

        try {
            DB::beginTransaction();
            $invoice->update(
                [
                    'currency' => $currency,
                    'rate' => $rate ?? 1,
                ]
            );

            DB::commit();
            return Redirect::route('application-licence-invoices', ['id' => $invoice->application->id]);
        } catch (\Exception $e) {
            DB::rollback();
            return back()->with('error', $e->getMessage());
        }

    }

    public function downloadLicence()
    {
        return back();
        $pdf = PDF::loadView();
        return $pdf->download('licence.pdf');
    }

    public function trackApplicationLocal(Request $request)
    {
//        return $request;
        if (request('track_application') == 'yes') {
            $app_id = Licence::where('ref', request('licence_ref'))->exists();
            if ($app_id) {
                return back()->with('error', 'The Licence Is Already Belonging To Another Account Please Visit Council To Verify Your Licence');
            } else {
                TrackLocalApp::create(
                    [
                        'user_id' => Auth::user()->id,
                        'licence_ref_no' => request('licence_ref'),
                        'local_app_id' => NULL,
                        'status' => 'not linked'
                    ]
                );
                return back()->with('success', 'Your Request Was Successfully Logged, Please Bear With Us While Verifying Your Licence, This May Take Close To 5 minutes');
            }
        } elseif (request('track_application') == 'no') {
            TrackLocalApp::create(
                [
                    'user_id' => Auth::user()->id,
                    'local_app_id' => request('applicant_id'),
                    'licence_ref_no' => NULL,
                    'status' => 'not linked'
                ]
            );
            return back()->with('success', 'Your Request Was Successfully Logged, Please Bear With Us While Linking Your Applications , This May Take Close To 5 minutes');
        } else {
            return back()->with('error', 'Oops !!! ,Something went wrong with your request');
        }
    }

}
