<?php

namespace Modules\UserManagement\Http\Controllers;

use App\Models\CrmQueryUpload;
use App\Models\CrmSuggestion;
use App\Models\LoggedQuery;
use Carbon\Carbon;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Redirect;

class QueryController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return \Illuminate\Http\RedirectResponse
     */
    public function newQuery(Request $request)
    {
        $validated = $request->validate([
            "locationId" => 'required|integer',
            "client_type" => 'required|integer',
            "stand_number" => 'required',
            "query_type" => 'required|integer',
            "notes" => 'required',
            "type" => 'required'
        ]);
//        return $validated;
        try {
            DB::beginTransaction();
            $query = new LoggedQuery();
            $query->user_id = Auth::user()->id;
            $query->council_id = Auth::user()->council_id;
            $query->first_name = Auth::user()->first_names;
            $query->last_name = Auth::user()->surnames;
            $query->stand_number = $validated['stand_number'];
            $query->address = Auth::user()->address;
            $query->email = Auth::user()->email;
            $query->phone_number = Auth::user()->telephone;
            $query->reporting_channel = 'Portal';
            $query->crm_query_category_id = $validated['query_type'];
            $query->crm_client_type_id = $validated['client_type'];
            $query->description = $validated['notes'];
            $query->status = 'Pending';
            $query->type = $validated['type'];
            $query->logged_by_id = portalAssistant();
            $query->location_id = $validated['locationId'];
            $query->sync_status = "awaiting sync";
            $query->save();

            DB::commit();
            return back()->with('success', 'successfully logged query , Processing for your query takes close to 5minutes');
        } catch (\Exception $exception) {
            DB::rollBack();
            return back()->with('error', $exception->getMessage());

        }

    }

    public function addSuggestion(Request $request)
    {
//        return $request->all();
        $validated = $request->validate(
            [
                "subject" => "required|integer",
                "message" => "required"
            ]
        );
        try{
            DB::beginTransaction();
            $suggestion = new CrmSuggestion();
            $suggestion->type = 'Suggestion';
            $suggestion->user_id = Auth::user()->id;
            $suggestion->council_id = Auth::user()->council_id;
            $suggestion->sync_status = "awaiting sync";
            $suggestion->first_name = Auth::user()->first_names;
            $suggestion->last_name = Auth::user()->surnames;
            $suggestion->phone_number =Auth::user()->telephone;
            $suggestion->subject = $validated['subject'];
            $suggestion->description = $validated['message'];
            $suggestion->department_id = $validated['subject'];
            $suggestion->reporting_channel = 'Portal';
            $suggestion->save();

            DB::commit();
            return back()->with('success', 'Your suggestion has been received with Thanks');
        }catch(\Exception $e){
            DB::rollBack();
            return back()->with('error', $e->getMessage());
        }
    }
}
