<?php

namespace Modules\UserManagement\Http\Controllers;

use App\Models\BillingAccountType;
use App\Models\CrmClientType;
use App\Models\CrmQueryCategory;
use App\Models\CrmRealCategory;
use App\Models\Employee;
use App\Models\FinancialCurrency;
use App\Models\HousingFee;
use App\Models\LicenceApplication;
use App\Models\LicenceDistrict;
use App\Models\LicenceInvoice;
use App\Models\LicencePayment;
use App\Models\LicenceTarriff;
use App\Models\LicenceType;
use App\Models\Location;
use App\Models\LoggedQuery;
use App\Models\Market;
use App\Models\MarketType;
use App\Models\PremiseDetail;
use App\Models\RegistrablePremise;
use App\Models\Sector;
use App\Models\ShopLicenceClass;
use App\Models\User;
use App\Models\WaitingListApplicantDetail;
use App\Models\WaitingListMarketApplicant;
use Carbon\Carbon;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use View;

class UserManagementController extends Controller
{
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            foreach (LoggedQuery::all() as $c) {
                $c->user_id = Auth::user()->id;
                $c->save();
            }
            View::share('locations', Location::where('council_id', Auth::user()->council_id)
                ->get());

            View::share('category', CrmQueryCategory::where('council_id', Auth::user()->council_id)
                ->get());

            View::share('types_of_clients', CrmClientType::where('council_id', Auth::user()->council_id)
                ->get());
            return $next($request);
        });
    }

    /**
     * Display a listing of the resource.
     * @return Renderable
     */
    public function index()
    {
        return view('usermanagement::dashboard.index');
    }

    public function addAccount()
    {
        return view('usermanagement::accounts.index');
    }

    public function accountPayment($id)
    {
        return view('usermanagement::accounts.payment-history');
    }

    public function verifiedAccounts()
    {
        return view('usermanagement::accounts.verified-accounts');
    }

    public function pendingApprovals()
    {
        return view('usermanagement::approvals.my-pending-approvals');
    }

    public function allBusinessLicence()
    {
        return view('usermanagement::business-licence.licencing');
    }

    public function AllMyQueries()
    {
        $data = [
            'locations' => Location::all(),
            'queryCategories' => CrmQueryCategory::where('status', 'active')->get(),
            'queryClientTypes' => CrmClientType::where('status', 'Active')->get(),
        ];
        return view('usermanagement::crm.index', $data);
    }

    public function paymentActivity()
    {
        return view('usermanagement::payments.index');
    }

    public function downloadFile()
    {
    }

    public function makePaymentFromDashboard()
    {
    }

    public function myPlans()
    {
    }

    public function newPlan()
    {
    }

    public function newBusinessLicence(Request $request)
    {
//        $applications = LicenceApplication::invoicesToLocal()->get();
//        foreach ($applications as $app) {
//            foreach ($app->anyPendingInvoice as $invoice) {
//                if ($invoice->status == "Pending")
//                    $invoice->update(["currency" => "usd", "rate" => 1]);
//            }
//        }
//        return LicenceApplication::invoicesToLocal()
//            ->with(['dogInvoices', 'invoices', 'licences.classes', 'licences.registrablePremises', 'cycle', 'timeline', 'clearance'])
//            ->get();
//        return "simz";
        if ($request->ajax()) {
            $accounts = LicenceTarriff::select([DB::raw("CONCAT(licence_tarriffs.title,'  | ',licence_tarriffs.description) as text"), DB::raw('id'), DB::raw('price'), DB::raw('application_fee')])
                ->where('licence_type_id', 2)
                ->where(function ($q) use ($request) {
                    $q->orwhere('title', 'LIKE', '%' . $request->input('q', '') . '%')
                        ->orwhere('description', 'LIKE', '%' . $request->input('q', '') . '%')
                        ->orwhere('notes', 'LIKE', '%' . $request->input('q', '') . '%');
                })
                ->get();
            return ['results' => $accounts];
        }
        $data = [
            'types' => LicenceType::all(),
            'locations' => Location::all(),
            'premises' => PremiseDetail::all(),
            'districts' => LicenceDistrict::all(),
            'reg' => LicenceType::find(3),
            'trading_tariff' => LicenceTarriff::where('licence_type_id', 2)->get(),
            'hawker_tariffs' => LicenceTarriff::where('licence_type_id', 4)->get(),
            'dog_tariffs' => LicenceTarriff::where('licence_type_id', 5)->get(),
            'cycle_tariffs' => LicenceTarriff::where('licence_type_id', 6)->get(),
            'liquor_tariffs' => LicenceTarriff::where('licence_type_id', 7)->get(),
            'shop_tariff' => LicenceTarriff::where('licence_type_id', 1)->first()
        ];
//        dd($data['hawker_tariffs']);
        return view('usermanagement::business-licence.new-business-licence', $data);
    }

    public function allBusinessLiscence()
    {
        return view('usermanagement::business.business-license');
    }

    public function newBuildingInspection()
    {
        return view('usermanagement::building-inspection.index');
    }

    public function allBuildingInspection()
    {
        return view('usermanagement::building-inspection.all-my-inspection');
    }

    public function allPaymentPlans()
    {
        return view('usermanagement::payment-plan.payment-plan');
    }

    public function newPaymentPlans()
    {
        return view('usermanagement::payment-plan.index');
    }

    public function addNewWaitingList()
    {
        $acc = BillingAccountType::where("name", "HIGH DENSITY")->first();
        $low = BillingAccountType::where("name", "LOW DENSITY")->first();

        $data = [
            "low_density" => HousingFee::where("type_id", $low->id)->first()->reg_fee,
            "high_density" => HousingFee::where("type_id", $acc->id)->first()->reg_fee,
        ];
        return view('usermanagement::waiting-list.waiting-list', $data);
    }

    public function addNewMarket()
    {
        return view('usermanagement::waiting-list.new-market');
    }

    public function myWaitingListings()
    {
        return view('usermanagement::waiting-list.my-waiting-list');
    }

    public function viewWaitingList(WaitingListApplicantDetail $id)
    {
//        return $id->applicationInvoicePending;
        return view('usermanagement::waiting-list.waiting-list-action', ['id' => $id]);
    }

    public function applicationForm(WaitingListApplicantDetail $id)
    {
//        return $id;
        return view('usermanagement::waiting-list.application-form', ['applicant' => $id]);
    }

    public function renewApplicant(WaitingListApplicantDetail $id)
    {
        $dbDate = \Carbon\Carbon::parse($id->application_details->application_date);
        $numberOfYears = Carbon::now()->diffInYears($dbDate);
        if ($numberOfYears == 0) {
            $numberOfYears = 1;
        }
        $totalfee = BillingAccountType::where('name', $id->application_details->type)->first();
        $fee = ($totalfee->fee->reg_fee * $numberOfYears);

        $expsetting = DB::table('area_settings')
            ->select('area_settings.expiry')
            ->get();
        foreach ($expsetting as $set) {
            $exp = $set->expiry;
            if ($exp == "After 12 Months") {
                $expDate = Carbon::now()->addMonths(12);
            } elseif ($exp == "At Year End") {
                $expDate = Carbon::parse('last day of December');
            }
        }
        $rate = FinancialCurrency::where('code', 'ZWL')->first();
        return view('usermanagement::waiting-list.renewal', ['applicant' => $id, "rate" => $rate, "exp" => $expDate, "fee_renewal" => $fee]);
    }

    public function previewApplication($id)
    {
        $application = LicenceApplication::where('id', $id)->first();
        $invoice = LicenceInvoice::where('status', 'Pending')->where('licence_application_id', $application->id)->first();
        $application->activeLicenceInvoice()->count();
        $uploads = [];
        $attachments = [];

        if ($application->activeLicenceInvoice()->count() > 0) {
            $payments = LicencePayment::where('invoice_number', $application->activeLicenceInvoice->id)->get();
        } elseif ($application->activeOldInvoice()->count() > 0) {
            $payments = LicencePayment::where('invoice_number', $application->activeOldInvoice->id)->get();
        } else {
            $payments = [];
        }

        $locations = DB::table('locations')->get();
        $done_inspections = $application->inspection()->count() > 0 ? $application->inspection : null;
        $details = $application->cycle()->count() > 0 ? $application->cycle : null;
        $allspaces = $application->space()->count() > 0 ? $application->space->premise->spaces : [];
//        $inspections = LicenceRequirement::where('licence_type_id', $application->licence_type_id)->get();
        $tariffs = LicenceTarriff::where('licence_type_id', 1)->get();
        $liquor_tariffs = LicenceTarriff::where('licence_type_id', 7)->get();
        $reg_tariffs = LicenceTarriff::where('licence_type_id', 3)->get();

        $cycle_tariffs = LicenceTarriff::where('licence_type_id', 6)->get();
        $hawker_tariffs = LicenceTarriff::where('licence_type_id', 4)->get();
        $district = LicenceDistrict::all();
        $licenceTariffs = LicenceTarriff::whereIn('licence_type_id', [1, 2, 3, 7])->get();
//        $licenceQuotations = LicenceQuotation::where('licence_application_id', $id)->orderBy('created_at', 'desc')->get();
        $reg = LicenceType::where('id', 3)->first();
        $reg_premises = RegistrablePremise::all();
//        $company = \App\CompanyDetail::find(1);

        if ($application->licence_type_id == 5 || $application->licence_type_id == 6 || $application->licence_type_id == 4) {
            $data = [
                'district' => $district,
                'hawker_tariffs' => $hawker_tariffs,
                'cycle_tariffs' => $cycle_tariffs,
                'details' => $details,
                'uploads' => $uploads,
                'application' => $application,
                'id' => $id,
                'locations' => $locations,
                'attachments' => $attachments,
                'payments' => $payments,

            ];

            return view('usermanagement::business-licence.preview-other', $data);
        }

        return view('usermanagement::business-licence.preview', [
            'reg' => $reg, 'reg_tariffs' => $reg_tariffs,
            'liquor_tariffs' => $liquor_tariffs, 'done_inspections' => $done_inspections,
            'details' => $details, 'uploads' => $uploads,
            'allspaces' => $allspaces, 'application' => $application, 'id' => $id,
            'locations' => $locations, 'attachments' => $attachments, 'tariffs' => $tariffs,
            'payments' => $payments, 'licenceTariffs' => $licenceTariffs, 'reg_premises' => $reg_premises
        ]);

    }
//    public function previewApplication(Request $request) {
////        dd($request->all());
//        $id = $request->id;
//        $application = LicenceApplication::where('id', $id)->first();
//        $data =[
//            'application' => LicenceApplication::where('id', $id)->first(),
//            'id' => $id,
//            'details' => $application->cycle()->count() > 0 ? $application->cycle : null
//        ];
////        dd($data['details']);
//       return view('usermanagement::business-licence.preview' ,$data);
//    }
    public function generateInvoices(Request $request)
    {
        $id = $request->id;

        $app = LicenceApplication::find($id);

        if ($app->activeLicenceInvoice()->count() > 0) {
            $invoice = $app->activeLicenceInvoice;
        } else {
            $invoice = LicenceInvoice::where('status', 'Pending')->where('licence_application_id', $id)->first();
        }

//        $data["email"] = Auth::user()->email;
//        $data["title"] = 'Business Licence :' . $invoice->type . ' Invoice Break Down';
//
//        try {
//            Mail::send('usermanagement::reports.email', ['invoice' => $invoice, 'id' => $id], function ($message) use ($data) {
//                $message->to($data["email"], $data["email"])
//                    ->subject($data["title"]);
//            });
//        } catch (\Exception $e) {
//            return abort('404', $e->getMessage());
//        }
        return view('usermanagement::business-licence.invoice', ['invoice' => $invoice, 'id' => $id]);
    }

//    crm
    public function viewQuery(LoggedQuery $id)
    {
        return view('usermanagement::crm.read', ['query' => $id]);
    }

    public function marketAction(WaitingListMarketApplicant $id)
    {
        return view('usermanagement::waiting-list.market-action', ['market' => $id]);
    }

    public function marketRenew(WaitingListMarketApplicant $id)
    {
//        return $id;
        $market_fee = HousingFee::where("type_id", 14)->pluck("renewal_fee")->first();
        return view('usermanagement::waiting-list.market-renew',
            [
                'market' => $id,
                "market_fee" => $market_fee
            ]);
    }
}
