<?php

namespace Modules\UserManagement\Http\Controllers;

use App\BusinessLogic\Payment;
use App\Http\Controllers\Controller;
use App\Models\AreaSetting;
use App\Models\BillingAccountCategory;
use App\Models\BillingAccounts;
use App\Models\BillingAccountType;
use App\Models\Employee;
use App\Models\FinancialCurrency;
use App\Models\HousingFee;
use App\Models\Market;
use App\Models\MarketType;
use App\Models\Sector;
use App\Models\WaitingListApplicantDependants;
use App\Models\WaitingListApplicantDetail;
use App\Models\WaitingListApplicantEmployment;
use App\Models\WaitingListApplicantNextOfKin;
use App\Models\WaitingListApplicantSpouse;
use App\Models\WaitingListApplicationDetail;
use App\Models\WaitingListAreaSetting;
use App\Models\WaitingListInvoice;
use App\Models\WaitingListMarketApplicant;
use App\Models\WaitingListPortalPayment;
use App\Models\WaitingListTrackLocal;
use App\Traits\PaynowPayment;
use Carbon\Carbon;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Paynow\Payments\Paynow;

class WaitingListController extends Controller
{
    use PaynowPayment;

    protected $applicant, $marketApplicant, $invoice_id;

    public function __construct()
    {
        $this->applicant = null;
        $this->marketApplicant = null;
        $this->invoice_id = null;
    }

    public function config(Request $request)
    {
        $data = $request->all();
        try {
            DB::beginTransaction();
            foreach ($data['sector'] as $sector) {
                try {
                    Sector::updateOrCreate([
                        'id' => $sector['id'],
                    ], [
                        'score' => $sector['score'],
                        'sector' => $sector['sector'],
                    ]);
                } catch (\Exception $e) {
                    DB::rollBack();
                    return response()->json([$e->getMessage()]);
                }
            }
            foreach ($data['areaSettings'] as $settings) {
                try {
                    AreaSetting::updateOrCreate(
                        [
                            "id" => $settings['id'],
                        ],
                        [
                            'criteria' => $settings['criteria'],
                            'areaname' => $settings['areaname'],
                            'expiry' => $settings['expiry'],
                            'deactivation' => $settings['deactivation'],
                            'council_id' => 1
                        ]
                    );
                } catch (\Exception $e) {
                    DB::rollBack();
                    return response()->json([$e->getMessage()]);
                }

            }
            foreach ($data['fees'] as $fee) {
                try {
                    HousingFee::updateOrCreate(
                        [
                            "id" => $fee['id'],
                        ],
                        [
                            "title" => $fee['title'],
                            "status" => $fee['status'],
                            "tax" => $fee['tax'],
                            "reg_fee" => $fee['reg_fee'],
                            "discount" => $fee['discount'],
                            "type_id" => $fee['type_id'],
                            "renewal_fee" => $fee['renewal_fee'],
                        ]
                    );
                } catch (\Exception $e) {
                    DB::rollBack();
                    return response()->json([$e->getMessage()]);
                }

            }
            foreach ($data['account_types'] as $type) {
                try {
                    BillingAccountType::updateOrCreate(
                        [
                            "id" => $type['id'],
                        ],
                        [
                            "name" => $type['name'],
                            "account_category_id" => $type['account_category_id'],
                            "waiting_list_counter" => $type['waiting_list_counter'],
                            "description" => $type['description'],
                        ]
                    );
                } catch (\Exception $e) {
                    DB::rollBack();
                    return response()->json([$e->getMessage()]);
                }

            }
            foreach ($data['markets'] as $market) {
                Market::updateOrCreate(
                    [
                        "id" => $market['id'],
                    ],
                    [
                        "name" => $market['name'],
                        "council_id" => 1,
                        "status" => $market['status'],
                        "location_id" => $market['location_id'],
                        "description" => $market['description'],
                    ]);
            }
            foreach ($data['types'] as $type) {
                MarketType::updateOrCreate(
                    [
                        "id" => $type['id'],
                    ],
                    [
                        "name" => $type['name'],
                        "document" => $type['document'],
                        "council_id" => 1,
                        "description" => $market['description'],
                    ]
                );
            }
            DB::commit();
            return response()->json(['success' => 'successfully']);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json([
                'success' => "error",
                "err" => $e->getMessage()
            ]);
        }

    }

    public function addWaitingListMember(Request $request)
    {
        $settings = AreaSetting::find(1);

        if ($settings->expiry == "After 12 Months") {

            $expiry = Carbon::now()->addMonths(12);

        } else {

            $expiry = Carbon::parse('last day of December');

        }
//        return $request->all();
        DB::beginTransaction();
        try {

            $disability = $request->input('disability') == "disabled" ? true : false;

            try {
                $applicant = new WaitingListApplicantDetail();
                $applicant->user_id = Auth::user()->id;
                $applicant->council_id = Auth::user()->council_id;
                $applicant->sync_status = "awaiting sync";
                $applicant->firstname = $request->input('firstname');
                $applicant->lastname = $request->input('lastname');
                $applicant->gender = $request->input('sex');
                $applicant->resident = $request->input('resident');
                $applicant->waiting_list_number = "NOT SET";
                $applicant->residential_address = $request->input('residential_address');
                $applicant->national_no = $request->input('natid');
                $applicant->dob = $request->input('dob');
                $applicant->nationality = $request->input('nationality');
                $applicant->physical_address = $request->address;
                $applicant->region = $request->input('region');
                $applicant->city = $request->input('city');
                $applicant->marital_status = $request->input('marital');
                $applicant->disability = $disability;
                $applicant->email = $request->input('email');
                $applicant->contact = $request->input('phonenumber');
                $applicant->yor = $request->input('ageofres');
                $applicant->verify = "awaiting verification";
                $applicant->save();
            } catch (\Exception $e) {
                DB::rollBack();
                return $e->getMessage();
            }

            /* Creating Dependants */
            try {
                $dependant_name = $request->input('depname');
                $dependant_gender = $request->input('dep_gender');
                $dependant_relation = $request->input('dep_relationship');
                $dependant_dob = $request->input('dep_dob');
                $dependant_id = $request->input('depnational_id');

                if (count($dependant_name) > 0) {
                    for ($i = 0; $i < count($dependant_name); $i++) {
                        $dep = new WaitingListApplicantDependants();
                        $dep->waiting_list_applicant_detail_id = $applicant->id;
                        $dep->full_name = $dependant_name[$i];
                        $dep->gender = $dependant_gender[$i];
                        $dep->national_id = $dependant_id[$i];
                        $dep->relationship = $dependant_relation[$i];
                        $dep->date_of_birth =  $dependant_dob[$i];
                        $dep->save();
                    }
                }
//                $all_dependants = request('dependant');
//                if (request('dependant')) {
//                    foreach ($all_dependants as $value) {
//
//                        $dep = new WaitingListApplicantDependants();
//                        $dep->waiting_list_applicant_detail_id = $applicant->id;
//                        $dep->full_name = $value['depname'];
//                        $dep->gender = $value['depsex'];
//                        $dep->national_id = $value['depnatid'];
//                        $dep->relationship = $value['deprelationship'];
//                        $dep->date_of_birth = $value['depdob'];
//                        $dep->save();
//
//                    }
//                }
            } catch (\Exception $e) {

                DB::rollback();
                return $e->getMessage();

            }

            $employment = new WaitingListApplicantEmployment();
            $employment->applicant_id = $applicant->id;
            $employment->occupation = $request->input('occupation');
            $employment->company = $request->input('company_name');
            $employment->sector = $request->input('employment_sector');
            $employment->date_engaged = $request->input('years_of_engagement');
            $employment->business_address = $request->input('business_address');
            $employment->income = $request->input('monthly_income');
            $employment->business_contact = $request->input('business_telephone');
            $employment->income_type = $request->input('currency');
            $employment->save();

            if ($request->input('marital') === 'Married') {
                $spouse = new WaitingListApplicantSpouse();
                $spouse->applicant_id = $applicant->id;
                $spouse->Marriage_certificate_number = request('marriageno');
                $spouse->Date_issued = request('issuedate');
                $spouse->firstname = request('sfirstname');
                $spouse->lastname = request('slastname');
                $spouse->dob = request('sdob');
                $spouse->national_id = request('snatid');
                $spouse->nationality = request('snationality');
                $spouse->occupation = request('soccupation');
                $spouse->contact = request('sphonenumber');
                $spouse->business_address = request('saddress');
                $spouse->doe = request('sdoe');
                $spouse->income = request('sincome');
                $spouse->save();

            }

            $kin = new WaitingListApplicantNextOfKin();
            $kin->applicant_id = $applicant->id;
            $kin->full_name = $request->input('next_of_kin_name');
            $kin->gender = $request->input('next_of_kin_sex');
            $kin->relationship = $request->input('next_of_kin_relationship');
            $kin->contact = $request->input('next_of_kin_phone_number');
            $kin->national_id = $request->input('nok_national_id');
            $kin->dob = $request->input('nok_date_of_birth');
            $kin->physical_address = $request->input('nok_address');
            $kin->save();

            try {
                $detail = new WaitingListApplicationDetail();
                $detail->applicant_id = $applicant->id;
                $detail->category = request('standcatergory');
                $detail->type = request('standtype');
                $detail->development = "NULL";
                $detail->application_date = request('appdate');
                $detail->expiry_date = $expiry;
                $detail->usd_receipt_no = "NULL";
                $detail->rtgs_receipt_no = "NULL";
                $detail->approved_by = Employee::find(portalAssistant())->name();
                $detail->save();
            } catch (\Exception $e) {
                DB::rollBack();
                return $e->getMessage();
            }

            try {
                WaitingListInvoice::create(
                    [
                        "applicant_id" => $applicant->id,
                        "market_id" => null,
                        "platform" => "Portal",
                        "type" => "Application",
                        "status" => "Pending",
                        "currency" => "RTGS",
                        "rate" => rate(),
                        "amount" => BillingAccountType::where('name', $applicant->application_details->type)->first()->fee->reg_fee,
                    ]
                );
            } catch (\Exception $e) {
                DB::rollBack();
                return $e->getMessage();
            }

            DB::commit();
            return redirect()->route('view-waiting-list', $applicant->id)->with('success', 'Please Bear With While Verifying Your Application');

        } catch (\Exception $e) {
            //if there is an error/exception in the above code before commit, it'll rollback
            DB::rollBack();
            $error_code = $e->errorInfo[1];
            if ($error_code == 1062) {
                return back()->with('error', 'Duplicate Receipt Number');
            } else {
                return back()->with('error', 'failed to save member check form for errors');
            }
        }

    }

    public function createPayment(Request $request)
    {
//        return $request->all();
        $amount = $request->amount;
        $phone = $request->phone_number;
        $id = $request->id;
        if ($request->payment_type == "market") {
            $this->marketApplicant = WaitingListMarketApplicant::find($id);
            if ($this->marketApplicant->applicationMarketInvoicePending()->count() > 0) {
                $this->invoice_id = $this->marketApplicant->applicationMarketInvoicePending;
            } else {
                $this->invoice_id = $this->marketApplicant->applicationMarketRenewal;
            }
        }
        if ($request->payment_type == "residential") {
            $this->applicant = WaitingListApplicantDetail::find($id);
            if ($this->applicant->applicationInvoicePending()->count() > 0) {
                $this->invoice_id = $this->applicant->applicationInvoicePending;
            } else {
                $this->invoice_id = $this->applicant->applicationRenewal;
            }
        }
//        return $this->invoice_id;
//        $amount = $invoice_id->amount * $invoice_id->rate;
        $type = $this->checkNumber($phone);
        if ($this->not_number) {
            return back()->with('error', 'Please Enter Eco-cash Number Or A Net-one Number');
        } else {
            $createPayment = $this->payment();
            $payment = $createPayment->createPayment('WaitingList Payment', Auth::user()->email);
            $payment->add('WaitingList Application', $amount);
            $response = $createPayment->sendMobile($payment, $phone, $type);
            if ($response->success()) {
                $pollUrl = $response->pollUrl();
                $transaction = $createPayment->pollTransaction($pollUrl)->data();
//                dd($transaction);
                DB::beginTransaction();
                try {
                    $this->waitingPayment($transaction, $this->marketApplicant, $this->applicant, $this->invoice_id);
                    return back()->with('success', 'Payment Has Been Processed Successfully');
                } catch (\Exception $e) {
                    DB::rollBack();
                    return back()->with('error', $e->getMessage());
                }
            }
        }
    }

    public function renewalWaitingList(Request $request)
    {
//        return $request->all();
        $amount = explode(" ", $request->rtgs_amount_renewal);
        $applicant = WaitingListApplicantDetail::find($request->app_id);
        try {
            DB::beginTransaction();
            $inv = WaitingListInvoice::create(
                [
                    "applicant_id" => $request->app_id,
                    "market_id" => null,
                    "type" => "Renewal",
                    "status" => "Pending",
                    "currency" => "RTGS",
                    "rate" => rate(),
                    "amount" => $amount['0'],
                    "platform" => "Portal"
                ]
            );
            DB::commit();
            return redirect()->route('view-waiting-list', $applicant->id)->with('success', 'Please Bear With While Verifying Your Application');
        } catch (\Exception $e) {
            DB::rollBack();
            return $e->getMessage();
        }
    }

    /**
     * @param array $transaction
     * @param $applicant
     * @param $invoice_id
     * @return void
     */
    private function waitingPayment(array $transaction, $marketApplicant, $applicant, $invoice_id): void
    {
        WaitingListPortalPayment::create(
            [
                "reference" => $transaction['reference'],
                "paynow_reference" => $transaction['paynowreference'],
                "amount" => $transaction['amount'],
                "status" => $transaction['status'],
                "poll_url" => $transaction['pollurl'],
                "hash" => $transaction['hash'],
                "date" => Carbon::now(),
                "application_id" => $applicant == null ? null : $applicant->id,
                "market_applicant" => $marketApplicant == null ? null : $marketApplicant->id,
                "employee_id" => portalAssistant(),
                "invoice_id" => $invoice_id->id,
                "rate" => $invoice_id->rate,
                "user_id" => Auth::user()->id,
                "platform" => "Portal"
            ]
        );
        DB::commit();
    }

    public function addMarketUser(Request $request)
    {
//        return $request->all();
        DB::beginTransaction();
        try {
            $settings = AreaSetting::find(1);
            if ($settings->expiry == "After 12 Months") {
                $expiry = Carbon::now()->addMonths(12);
            } else {
                $expiry = Carbon::parse('last day of December');
            }

            $applicant = new WaitingListMarketApplicant();
            $applicant->user_id = Auth::user()->id;
            $applicant->council_id = Auth::user()->council_id;
            $applicant->sync_status = "awaiting sync";
            $applicant->firstname = request('firstname');
            $applicant->lastname = request('lastname');
            $applicant->sex = request('sex');
            $applicant->national_id = request('natid');
            $applicant->dob = request('dob');
            $applicant->nationality = request('nationality');
            $applicant->region = request('region');
            $applicant->city = request('city');
            $applicant->physical_address = request('address');
            $applicant->contact = request('phonenumber');
            $applicant->email = request('email');
            $applicant->application_date = request('application_date');
            $applicant->waiting_list_number = "NOT SET";
            $applicant->verify = "awaiting verification";
            $applicant->expiry_date = $expiry;
            $applicant->market_type_id = $request->input('market_type');
            $applicant->market_id = $request->input('market');
            $applicant->save();

            try {
                WaitingListInvoice::create(
                    [
                        "market_id" => $applicant->id,
                        "applicant_id" => null,
                        "platform" => "Portal",
                        "type" => "Application",
                        "status" => "Pending",
                        "currency" => "RTGS",
                        "rate" => rate(),
                        "amount" => HousingFee::where("type_id", 14)->pluck("reg_fee")->first(),
                    ]
                );
            } catch (\Exception $e) {
                DB::rollBack();
                return $e->getMessage();
            }

            DB::commit();
            return redirect()->route('market-action', $applicant->id);
        } catch (\Exception $exception) {
            return back()->with('error', $exception->getMessage());
        }
    }

    public function trackMarket(Request $request)
    {
//        return $request;
        try {
            DB::beginTransaction();
            WaitingListTrackLocal::create(
                [
                    "user_id" => Auth::user()->id,
                    "waiting_list_number" => null,
                    "waiting_list_type" => "market",
                    "national_id" => $request->applicant_id,
                    "status" => "not linked",
                ]);
            DB::commit();
            return back()->with('success', "request successfully submitted");
        } catch (\Exception $e) {
            DB::rollBack();
            return back()->with('error', $e->getMessage());
        }
    }

    public function marketRenewalGenerate(Request $request, $id)
    {
        try {
            DB::beginTransaction();
            $inv = WaitingListInvoice::create(
                [
                    "market_id" => $id,
                    "applicant_id" => null,
                    "type" => "Renewal",
                    "status" => "Pending",
                    "currency" => "RTGS",
                    "rate" => rate(),
                    "amount" => $request->renewal_fee,
                    "platform" => "Portal"
                ]
            );
            DB::commit();
            return redirect()->route('market-action', $id)->with('success', 'Please Bear With While Verifying Your Application');
        } catch (\Exception $e) {
            DB::rollBack();
            return $e->getMessage();
        }
    }
}
