<?php

namespace Modules\UserManagement\Http\Livewire\BusinessLicence;

use App\Models\LicenceType;
use App\Traits\IsTable;
use Illuminate\Support\Facades\Auth;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;
use Livewire\WithPagination;
use Modules\UserManagement\Entities\MyBusiness;
use Modules\UserManagement\Entities\MyBusinessLicenceType;

class MyBusinesses extends Component
{
    use IsTable,WithPagination, LivewireAlert;
    public $licence_types;
    public $licence_id;
    public $table_id;
    protected $listeners = [
        'confirmed'
    ];
    public  function mount(){
        $this->columns = [
            'Trading Name' => 'trading_name',
            'Date' => 'created_at',
            'Last Updated' => 'updated_at'
        ];
        $this->licence_types=LicenceType::where('council_id',Auth::user()->council_id)->get();
    }

    public function render()
    {
        $results = MyBusiness::where('user_id', Auth::user()->id)
            ->where('council_id', Auth::user()->council_id)
//            ->orWhere('trading_name', 'like', '%' . $this->search . '%')
//            ->orWhere('status', 'like', '%' . $this->search . '%')
//            ->orWhere('address', 'like', '%' . $this->search . '%')
//            ->orWhere('mobile_number', 'like', '%' . $this->search . '%')
            ->orderBy($this->columns[$this->orderBy], $this->orderDirection)->paginate($this->paginationCount);
        return view('usermanagement::livewire.business-licence.my-businesses',[
            'results'=>$results
        ]);
    }

    public function removeLicence($id, $table_id)
    {
        $this->licence_id=$id;
        $this->table_id=$table_id;
        $name = LicenceType::where('id',$id)->value('title');
        $this->alert('question', 'Are you sure, you want to remove '.$name.' licence', [
            'showConfirmButton' => true,
            'showCancelButton' => true,
            'confirmButtonText' => 'Yes',
            'cancelButtonText' => 'No',
            'onConfirmed' => 'confirmed',
            'allowOutsideClick' => false,
            'timer' => null,
            'position'=>'center'
        ]);
    }

    public function removeBusiness($id)
    {
        $this->table_id=$id;
        $name = MyBusiness::where('id',$id)->value('trading_name');
        $this->alert('question', 'Are you sure, you want to remove '.$name.' from your list', [
            'showConfirmButton' => true,
            'showCancelButton' => true,
            'confirmButtonText' => 'Yes',
            'cancelButtonText' => 'No',
            'onConfirmed' => 'confirmed',
            'allowOutsideClick' => false,
            'timer' => null,
            'position'=>'center'
        ]);
    }

    public function confirmed()
    {
        try{
            MyBusinessLicenceType::where('id',$this->table_id)->delete();
            $this->alert('success', 'Licence Successfully Removed ', [
                'position' => 'top-end'
            ]);
        }catch (\Exception $e){
            $this->alert('warning', 'Failed to remove ', [
                'position' => 'top-end'
            ]);
        }
    }

    public function confirmedBusiness()
    {
        try{
            MyBusiness::where('id',$this->table_id)->delete();
            $this->alert('success', 'Licence Successfully Removed ', [
                'position' => 'top-end'
            ]);
        }catch (\Exception $e){
            $this->alert('warning', 'Failed to remove ', [
                'position' => 'top-end'
            ]);
        }
    }
}
