<?php

namespace Modules\UserManagement\Http\Livewire\BusinessLicence;

use App\BusinessLogic\CommitToLedger;
use App\Models\LicenceApplication;
use App\Models\LicenceClearance;
use App\Models\LicenceInvoice;
use App\Models\LicenceInvoiceLine;
use App\Models\LicenceTarriff;
use App\Models\LicenceType;
use App\Models\Payment;
use App\Traits\IsTable;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;
use Livewire\WithPagination;
use Modules\UserManagement\Entities\MyBusiness;

class NewBusinessLicence extends Component
{
    use IsTable, WithPagination, LivewireAlert;
    protected $listeners = [
        'action'=>'paymentAction',
        'pullPaymnetRecord'=>'usePollUrl'
    ];
    public function mount()
    {
        $this->columns = [
            'Date' => 'created_at'
        ];
    }

    public function render()
    {
        $results = MyBusiness::where('user_id', Auth::user()->id)
            ->where('council_id', Auth::user()->council_id)
//            ->orWhere('trading_name', 'like', '%' . $this->search . '%')
//            ->orWhere('address', 'like', '%' . $this->search . '%')
//            ->orWhere('mobile_number', 'like', '%' . $this->search . '%')
            ->orderBy($this->columns[$this->orderBy], $this->orderDirection)->paginate($this->paginationCount);
        return view('usermanagement::livewire.business-licence.new-business-licence', [
            'results' => $results
        ]);
    }

    public function applyLicenceForBusiness($request)
    {
        DB::beginTransaction();
        $uniq =uniqid();
        try {
            $array = array_filter($request, function ($value, $key) {
                return strpos($key, 'licenceBox') === 0;
            }, ARRAY_FILTER_USE_BOTH);

            $this->alert('info', 'Processing please wait...', [
                'position' => 'top-end',
                'timer' => 4000
            ]);
            foreach ($array as $licence) {
//                $licenceType = LicenceType::where('id', $licence)->first();
                $shop = new LicenceApplication();
                $shop->licence_type_id = $licence;
                $shop->paymentRef = $uniq;
                $shop->applicant_name = ucwords(strtolower(Auth::user()->first_names . ' ' . Auth::user()->surnames));
                $shop->applicant_number = Auth::user()->telephone;
                $shop->council_id = Auth::user()->council_id;
                $shop->user_id = Auth::user()->id;
                $shop->applicant_id = Auth::user()->id_number;
                $shop->applicant_address = ucwords(strtolower(Auth::user()->address));
//                $shop->location_id = request('locationId');
//                $shop->district_id = request('districtId');
                $shop->registrable_premise_id = $request['business'];
                $shop->status = "CLERK";
                $shop->paid =false;
                $shop->stage = "SET CYCLE";
                $shop->save();

                LicenceClearance::create([
                    'licence_application_id' => $shop->id,
                    'premise_detail_id' => $request['business'],
                    'cleared' => 'Pending'
                ]);

                $shop_tariff = LicenceType::where('id', $licence)->first();

                $invoice = LicenceInvoice::create([
                    'licence_type_id' => $licence,
                    'user_id' => Auth::user()->id,
                    'council_id' => Auth::user()->council_id,
                    'licence_application_id' => $shop->id,
                    'type' => "Application",
                    'status' => 'Pending',
//                        'currency' => $currency,
//                        'rate' => $rate,
                    'customer_name' => $shop->applicant_name,
                    'customer_address' => $shop->applicant_address,
                    'customer_id' => $shop->applicant_id,
                    'customer_phone' => $shop->applicant_number,
                    'ref' => "1-" . $shop->id . "-" . $shop->district_id
                ]);


                $main_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $shop->licence_type_id,
                    'licence_application_id' => $shop->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => $shop_tariff->title . ' Application fee',
                    'status' => 'Active',
                    'unit_price' => $shop_tariff->application_fee + $shop_tariff->inspection_fee,
                    'quantity' => 1,
                    'total' => $shop_tariff->application_fee + $shop_tariff->inspection_fee,
                ]);

                $vat_line = LicenceInvoiceLine::create([
                    'licence_type_id' => $shop->licence_type_id,
                    'licence_application_id' => $shop->id,
                    'licence_invoice_id' => $invoice->id,
                    'description' => "vat @ 14.5 %",
                    'status' => 'Active',
                    'unit_price' => $shop_tariff->tax * ( $shop_tariff->application_fee + $shop_tariff->inspection_fee),
                    'quantity' => 1,
                    'total' => $shop_tariff->tax * ( $shop_tariff->application_fee + $shop_tariff->inspection_fee),
                ]);
//                    if ($rate == 1)
//                        $discount_line = LicenceInvoiceLine::create([
//                            'licence_type_id' => $shop->licence_type_id,
//                            'licence_application_id' => $shop->id,
//                            'licence_invoice_id' => $invoice->id,
//                            'description' => "discount " . ($shop->licence->discount * 100) . "%",
//                            'status' => 'Active',
//                            'unit_price' => -($shop->licence->discount * (($shop->licence->tax * $shop_tariff->application_fee) + $shop_tariff->application_fee)),
//                            'quantity' => 1,
//                            'total' => -($shop->licence->discount * (($shop->licence->tax * $shop_tariff->application_fee) + $shop_tariff->application_fee)),
//                        ]);

//                if (!request('saloonRegistration') && !request('hawkersLicence') && !request('tradingLicence')
//                    && !request('cycleLicence') && !request('dogLicence') && !request('liquorLicence')) {
//                    return back();;
//                }

            }
            $this->alert('success', 'Successfully applied for business Licence');
            DB::commit();
            $this->dispatchBrowserEvent('initializepayment', [
                "wallet" => $request["wallet"],
                "amount" => $request["amount".$request["business"]],
                "mobile" => $request["mobil".$request["business"]],
                "applicant_id" => $uniq,
            ]);
            return $this->render();
        } catch (\Exception $e) {
            dd($e);
            DB::rollBack();
            $this->alert('warning', 'Failed to  save applyication');
            $this->dispatchBrowserEvent('refreshPage');
        }
    }

    public function paymentAction($type)
    {
        if($type =='warning'){
            $this->alert($type[0], $type[1], [
                'position' => 'center',
                'timer' => 10000,
                'showCancelButton',true
            ]);
        }elseif ($type=='success'){
            $this->alert($type[0], $type[1], [
                'position' => 'center',
                'timer' => 10000,
                'showConfirmButton'=>true
            ]);
        }else{
            $this->alert($type[0], $type[1], [
                'position' => 'center',
                'timer' => 10000,
            ]);
        }

    }

    public function usePollUrl ($url)
    {
        $url = $url;
        try {
            $response = Http::get($url);
            $data = $this->byAnd($response->body());
            $rspDt = array();
            foreach ($data as $dt) {
                $temp = $this->keyPair($dt);
                $rspDt[$temp[0]] = $temp[1];
            }

//
            $payment = $this->getPaymentThroughReference($rspDt["reference"]);
//
            if ($payment->status == 'Paid' || $payment->status == 'Cancelled') {
                $this->paymentAction(['warning','This payment has been processed already!']);

                $this->dispatchBrowserEvent('responseFromPaynow');
            }
//
            if ($rspDt['status'] == 'Paid') {
                try {
                    $licences = LicenceApplication::where('paymentRef',$payment->service_id)->get();
                    foreach ($licences as $licence){
                        $licence->paid = true;
                        $licence->save();
                    }
                    $payment->status = $rspDt['status'];
                    $payment->save();
                    // save to ledger
                    $transaction = new CommitToLedger($payment);
                    $transaction->commit();
                    $this->paymentAction(['success','Payment has been processed.']);
                    $this->dispatchBrowserEvent('responseFromPaynow');

                } catch (Exception $ex) {
                    $this->paymentAction(['warning','Failed to processed payment.']);
                    $this->dispatchBrowserEvent('responseFromPaynow');
                }
            }elseif ($rspDt['status'] == 'Sent'){
                $this->paymentAction(['info','Payment is being processed...']);
                $this->dispatchBrowserEvent('responseFromPaynow');
            } else {
                $payment->status = $rspDt['status'];
                $payment->save();
                //dd($payment);

                if ($rspDt['status'] == 'Cancelled') {

                    $this->paymentAction(['warning','Payment has been cancelled by user!.']);
                    $this->dispatchBrowserEvent('responseFromPaynow');
                }else{
                    $this->paymentAction(['warning','Payment has been cancelled by user!.']);
                    $this->dispatchBrowserEvent('responseFromPaynow');
                }

            }
        }catch (\Exception $e){
            $this->paymentAction(['warning','Please check your internet!.']);
            $this->dispatchBrowserEvent('responseFromPaynow');
        }

    }

    private function getPaymentThroughReference (string $reference) {
        return Payment::where('reference', $reference)->first();
    }

    private function byAnd (string $url) {
        return explode("&", $url);
    }

    private function keyPair (string $entries): array
    {
        $values = explode("=", $entries);
        return array($values[0], $values[1]);
    }
}
