<?php

namespace Modules\UserManagement\Http\Livewire\BusinessLicence;

use App\Models\FinancialCurrency;
use App\Models\Licence;
use App\Models\LicenceApplication;
use App\Models\LicenceApplicationSpecific;
use App\Models\LicenceInvoice;
use App\Models\LicencePayment;
use App\Models\LicenceStageTimeline;
use App\Models\LicenceTarriff;
use App\Models\PortalPayment;
use App\Models\ShopLicenceClass;
use App\Traits\PaynowPayment;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;
use Paynow\Payments\Paynow;

class PaymentCard extends Component
{
    use PaynowPayment, LivewireAlert;

    public $licType = 0;
    public $totalPortal = 0;
    public $total = 0;
    public $latest;
    public $uid;
    public $applicationOther; //licence application
    public $paymentsOther;
    public $payment, $tot;
    protected $status;
    private $createPayment;
    public $dog_apps;

    public function render()
    {
        $currencies = FinancialCurrency::where('code', 'ZWL')->first();
        $trans = PortalPayment::where('application_id', $this->applicationOther->id)->where('reference', 'Application-Payment')->get();
        $licencePay = PortalPayment::where('application_id', $this->applicationOther->id)->where('reference', 'Licence-Payment')->get();
        $latestLic = PortalPayment::where('application_id', $this->applicationOther->id)
            ->where('user_id', Auth::user()->id)
            ->where('reference', 'Licence-Payment')
            ->latest('created_at')
            ->first();
        $latestApp = PortalPayment::where('application_id', $this->applicationOther->id)
            ->where('user_id', Auth::user()->id)
            ->where('reference', 'Application-Payment')
            ->latest('created_at')->first();
        $data = ['id' => $this->uid, 'rate' => $currencies, 'licencePay' => $licencePay, 'trans' => $trans, 'latestLic' => $latestLic, 'latestApp' => $latestApp, 'payments' => $this->paymentsOther, 'application' => $this->applicationOther];
        return view('usermanagement::livewire.business-licence.payment-card', $data);
    }

    private function recieptNo($id)
    {
        $today = Carbon::now();
        $year = $today->format('y');
        $rec = 'pr-' . $year;
        $num = strlen($id);
        if ($num == 4) {
            $rec .= $id;
        } elseif ($num == 3) {
            $rec .= '0' . $id;
        } elseif ($num == 2) {
            $rec .= '00' . $id;
        } elseif ($num == 1) {
            $rec .= '000' . $id;
        } else {
            $rec .= $id;
        }
        return $rec;
    }

    public function hydrate()
    {
        $this->applicationOther = LicenceApplication::find($this->applicationOther->id);

        if ($this->applicationOther->pendingInvoice()->count() > 0 || $this->applicationOther->activeLicenceInvoice()->count() > 0) {

            if ($this->applicationOther->pendingInvoice()->count() > 0) {
                $this->tot = $this->applicationOther->pendingInvoice;
                $this->latest = $this->applicationOther->pendingInvoice->latest_pay;
                $this->total = $this->applicationOther->pendingInvoice->total;
            }
            if ($this->applicationOther->activeLicenceInvoice()->count() > 0) {
                $this->tot = $this->applicationOther->activeLicenceInvoice;
                $this->latest = $this->applicationOther->activeLicenceInvoice->latest_pay;
                $this->total = $this->applicationOther->activeLicenceInvoice->total;
            }
            if ($this->latest) {
                $this->createPayment = $this->payment();
                $this->status = $this->createPayment->pollTransaction($this->latest->poll_url);
//                dd($this->total);
                if ($this->status->paid()) {
                    try{
                        DB::beginTransaction();
                        $this->latest->update(['status' => 'paid']);
                        $this->totalPortal = $this->tot->paynowPayments->where('status', 'paid')
                            ->where('platform', 'portal')
                            ->sum('amount');
                        if (($this->totalPortal - $this->total) >= 0) {

                            if($this->applicationOther->licence_type_id == 5){
                                $invoice = LicenceInvoice::where('status', 'Pending')->where('licence_application_id', $this->applicationOther->ref)->first();
                            }else{
                                $invoice = LicenceInvoice::where('status', 'Pending')->where('licence_application_id', $this->applicationOther->id)->first();
                            }
                            $rec = $this->recieptNo($invoice->id);

                            if ($invoice->type == 'Change') {
                                $invoice->update([
                                    'receipt_no' => $rec,
//                'amount'=>request('amount_paid'),
                                    'date_paid' => Carbon::now(),
                                    'status' => 'Completed'
                                ]);

                                $this->applicationOther->update(['status' => 'LICENCING SUPERVISOR', 'stage' => 'CHANGE REQUEST', 'sync_status' => 'not synced']);

                                DB::commit();

                            }

                            if ($invoice->type == 'Old Licence') {

                                if (($invoice->balance - $this->applicationOther->portalPayments->sum('amount')) >= 1) {
                                    $payment = LicencePayment::create([
                                        'invoice_number' => $invoice->id,
                                        'council_id' => Auth::user()->council_id,
                                        'user_id' => Auth::user()->id,
                                        'receipt_number' => $rec,
                                        'amount' => $this->applicationOther->portalPayments->sum('amount'),
                                        'employee_id' => portalAssistant(),
                                        'date' => Carbon::now(),
                                        'path' => "payment"
                                    ]);

//                            return back()->with('success', 'Payment recorded successfully');
                                } else {
                                    $payment = LicencePayment::create([
                                        'invoice_number' => $invoice->id,
                                        'council_id' => Auth::user()->council_id,
                                        'user_id' => Auth::user()->id,
                                        'receipt_number' => $rec,
                                        'amount' => $this->applicationOther->portalPayments->sum('amount'),
                                        'employee_id' => portalAssistant(),
                                        'date' => Carbon::now(),
                                        'path' => "payment"
                                    ]);

                                    $invoice->update([
                                        'receipt_no' => $rec,
//                'amount'=>request('amount_paid'),
                                        'date_paid' => Carbon::now(),
                                        'status' => 'Completed'
                                    ]);
                                    $this->applicationOther->update(['stage' => "RENEWAL", 'sync_status' => 'not synced']);
                                    DB::commit();
//                            return back()->with('success', 'Old licence debt cleared successfully .... Create Invoice for Current Year');

                                }

                            }

                            if ($invoice->type == 'Licence') {

                                if (($invoice->balance - $this->totalPortal) >= 1) {
                                    $this->payment = LicencePayment::create([
                                        'invoice_number' => $invoice->id,
                                        'council_id' => Auth::user()->council_id,
                                        'user_id' => Auth::user()->id,
                                        'receipt_number' => $rec,
                                        'amount' => $this->totalPortal,
                                        'employee_id' => portalAssistant(),
                                        'date' => Carbon::now(),
                                        'path' => "payment"
                                    ]);

                                }

                                $this->payment = LicencePayment::create([
                                    'invoice_number' => $invoice->id,
                                    'council_id' => Auth::user()->council_id,
                                    'user_id' => Auth::user()->id,
                                    'receipt_number' => $rec,
                                    'amount' => $this->totalPortal,
                                    'employee_id' => portalAssistant(),
                                    'date' => Carbon::now(),
                                    'path' => "payment"
                                ]);

                            }
                            if ($invoice->type == 'Application') {
                                $this->payment = LicencePayment::create([
                                    'invoice_number' => $invoice->id,
                                    'council_id' => Auth::user()->council_id,
                                    'user_id' => Auth::user()->id,
                                    'receipt_number' => $rec,
                                    'amount' => $this->totalPortal,
                                    'employee_id' => portalAssistant(),
                                    'date' => Carbon::now(),
                                    'path' => "payment"
                                ]);
                            }

//                            dd($this->payment);
                            $invoice->update([
                                'receipt_no' => $rec,
//                'amount'=>request('amount_paid'),
                                'date_paid' => Carbon::now(),
                                'status' => 'Completed'
                            ]);

                            foreach ($invoice->paynowPayments as $pay) {
                                $pay->update(['licence_payments_id' => $this->payment->id]);
                            }

                            $stage_timeline = LicenceStageTimeline::query()
                                ->where('licence_application_id', $this->applicationOther->id)
                                ->whereNull('licence_id')
                                ->first();

//            return $stage_timeline;
                            if ($stage_timeline == null) {
                                $stage_timeline = new  LicenceStageTimeline();
                                $stage_timeline->licence_application_id = $this->applicationOther->id;
                                $stage_timeline->do = Carbon::now()->format('Y-m-d H:i:s');
                                $stage_timeline->save();
                            }

                            if ($this->applicationOther->licence_type_id == 5 || $this->applicationOther->licence_type_id == 6 || $this->applicationOther->licence_type_id == 4) {

//                $ss = $app->licence_type_id == 4 ? "Pending" : "Issued";
                                if ($this->applicationOther->licence_type_id == 4) {
                                    $ss = "Pending";
                                } else {
                                    $ss = "Issued";
                                }

//                $record = $app->licence_type_id == 4 ? array('status' => "LICENCING SUPERVISOR", 'stage' => 'APPROVAL') : array('status' => "CLERK", 'stage' => 'ISSUE LICENCE');

                                if ($this->applicationOther->licence_type_id == 4) {
                                    $record = array('status' => "LICENCING SUPERVISOR", 'sync_status' => 'not synced', 'stage' => 'APPROVAL');

                                    $stage_timeline->update(['lo' => Carbon::now()->format('Y-m-d H:i:s')]);


                                } else {
                                    $record = array('status' => "CLERK", 'stage' => 'ISSUE LICENCE', 'sync_status' => 'not synced');

                                    $stage_timeline->update([
                                        'ls' => Carbon::now()->format('Y-m-d H:i:s'),
                                        'lo' => Carbon::now()->format('Y-m-d H:i:s'),
                                        'ehm' => Carbon::now()->format('Y-m-d H:i:s'),
                                        'hd' => Carbon::now()->format('Y-m-d H:i:s'),
                                        'issue' => Carbon::now()->format('Y-m-d H:i:s')]);
                                }
                                if ($this->applicationOther->licence_type_id == 5){
                                    $this->dog_apps = LicenceApplication::where('ref', $this->applicationOther->ref)->get();
                                    foreach ($this->dog_apps as $dog_app){
                                        $lic = Licence::create([
                                            'licence_type_id' => $dog_app->licence_type_id,
                                            'licence_tariff_id' => $invoice->licence_tariff_id,
                                            'licence_application_id' => $dog_app->id,
                                            'licence_invoice_id' => $invoice->id,
                                            'ref' => mt_rand(1000000000, 9999999999),
                                            'type' => 'Temporary',
                                            'status' => $ss,
                                            'customer_name' => ucwords(strtolower($dog_app->applicant_name)),
                                            'customer_address' => ucwords(strtolower($dog_app->applicant_address)),
                                            'customer_phone' => $dog_app->applicant_number,
                                            'start_date' => Carbon::now()->startOfYear(),
                                            'end_date' => Carbon::now()->endOfYear(),
                                            'employee_id' => portalAssistant()
                                        ]);

                                        $total_this_year = Licence::whereYear('created_at', Carbon::now())->where('licence_type_id', $dog_app->licence_type_id)->count();
                                        $lic->update(['ref' => "P" . Carbon::now()->year . "/" . $dog_app->licence_type_id . "/" . $total_this_year]);
                                        $dog_app->update($record);
                                        $stage_timeline->update(['licence_id' => $lic->id]);
                                    }
                                }else{
                                    $lic = Licence::create([
                                        'licence_type_id' => $this->applicationOther->licence_type_id,
                                        'licence_tariff_id' => $invoice->licence_tariff_id,
                                        'licence_application_id' => $this->applicationOther->id,
                                        'licence_invoice_id' => $invoice->id,
                                        'ref' => mt_rand(1000000000, 9999999999),
                                        'type' => 'Temporary',
                                        'status' => $ss,
                                        'customer_name' => ucwords(strtolower($this->applicationOther->applicant_name)),
                                        'customer_address' => ucwords(strtolower($this->applicationOther->applicant_address)),
                                        'customer_phone' => $this->applicationOther->applicant_number,
                                        'start_date' => Carbon::now()->startOfYear(),
                                        'end_date' => Carbon::now()->endOfYear(),
                                        'employee_id' => portalAssistant()
                                    ]);

                                    $total_this_year = Licence::whereYear('created_at', Carbon::now())->where('licence_type_id', $this->applicationOther->licence_type_id)->count();
                                    $lic->update(['ref' => "P" . Carbon::now()->year . "/" . $this->applicationOther->licence_type_id . "/" . $total_this_year]);
                                    $this->applicationOther->update($record);
                                    $stage_timeline->update(['licence_id' => $lic->id]);
                                }

                            } else {
                                if ($invoice->type == 'Licence') {
                                    if ($this->applicationOther->licence_type_id == 7) {
                                        $record = array('status' => "CLERK", 'stage' => 'SUBMIT FOR SIGNING', 'sync_status' => 'not synced');
                                        $stage_timeline->update([
                                            'ls' => Carbon::now()->format('Y-m-d H:i:s'),
                                            'lp' => Carbon::now()->format('Y-m-d H:i:s'),
                                            'lo' => Carbon::now()->format('Y-m-d H:i:s'),
                                            'ehm' => Carbon::now()->format('Y-m-d H:i:s'),
                                            'hd' => Carbon::now()->format('Y-m-d H:i:s'),
                                            'issue' => Carbon::now()->format('Y-m-d H:i:s')]);

                                    } elseif ($this->applicationOther->stage == 'RENEWAL') {
                                        $record = array('status' => "DISTRICT OFFICE", 'stage' => 'RENEWAL INSPECTIONS', 'sync_status' => 'not synced');

                                        $stage_timeline->update(['do' => Carbon::now()->format('Y-m-d H:i:s')]);

                                    } else {
                                        $record = array('status' => "LICENCING SUPERVISOR", 'stage' => 'APPROVAL', 'sync_status' => 'not synced');

                                        $stage_timeline->update([
                                            'ls' => Carbon::now()->format('Y-m-d H:i:s')]);
                                    }

                                    $pp = LicenceApplicationSpecific::where('application_id', $this->applicationOther->id)->first();

                                    $lic = Licence::create([
                                        'licence_type_id' => $this->applicationOther->licence_type_id,
                                        'licence_tariff_id' => $invoice->licence_tariff_id,
                                        'licence_application_id' => $this->applicationOther->id,
                                        'licence_invoice_id' => $invoice->id,
                                        'premise_space_id' => $this->applicationOther->premise_space_id,
                                        'ref' => mt_rand(1000000000, 9999999999),
                                        'type' => 'Temporary',
                                        'status' => 'Pending',
                                        'customer_name' => ucwords(strtolower($this->applicationOther->business_owner_name)),
                                        'company_name' => ucwords(strtolower($this->applicationOther->business_name)),
                                        'customer_address' => ucwords(strtolower($this->applicationOther->business_address)),
                                        'customer_phone' => $this->applicationOther->business_number,
                                        'start_date' => Carbon::now()->startOfYear(),
                                        'end_date' => Carbon::now()->endOfYear(),
                                        'employee_id' => portalAssistant()
                                    ]);

                                    $total_this_year = Licence::whereYear('created_at', Carbon::now())->where('licence_type_id', $this->applicationOther->licence_type_id)->count();
                                    $lic->update(['ref' => "P" . Carbon::now()->year . "/" . $this->applicationOther->licence_type_id . "/" . $total_this_year]);
                                    $stage_timeline->update(['licence_id' => $lic->id]);
                                    $ccc = $invoice->lines()->whereNotNull('shop_licence_class_id')->pluck('shop_licence_class_id');

                                    $lic->classes()->sync($ccc);

                                    $rrr = $invoice->lines()->whereNotNull('registrable_premise_id')->pluck('registrable_premise_id');
                                    $lic->registrablePremises()->sync($rrr);

                                } else {
                                    $record = array('stage' => "PENDING INSPECTIONS", 'status' => 'DISTRICT OFFICE', 'sync_status' => 'not synced');

                                    $stage_timeline->update(['do' => Carbon::now()->format('Y-m-d H:i:s')]);

                                }
                                $this->applicationOther->update($record);
//                        dd($this->applicationOther);
                            }

                            $record = array('status' => 'PENDING');
                            LicenceApplicationSpecific::where('application_id', request('id'))->update($record);
                            DB::commit();
                            $this->success("Payment Successfully Recorded , Processing ...");
                        }
                        DB::commit();
                    }catch(\Exception $e){
                        DB::rollBack();
                        $this->failed($e->getMessage());
                    }
                } else {
                    $this->latest->update(['status' => 'Cancelled']);
                }

            }
            $this->emit('refreshLicencePayment');
            $this->emit('preview');
            $this->emit('preview_other');
        }
    }
}
