<?php

namespace Modules\UserManagement\Http\Livewire\Crm;

use App\Models\CrmClientType;
use App\Models\CrmQueryCategory;
use App\Models\Location;
use App\Models\LoggedQuery;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;

class AddQuery extends Component
{
    use LivewireAlert;

    public $location_id;
    public $client_type;
    public $stand_number;
    public $phone_number;
    public $first_name;
    public $last_name, $address;
    public $type;
    public $query_type;
    public $notes;

    protected $rules = [
        "first_name" => "required",
        "last_name" => "required",
        "address" => "required",
        "location_id" => "required|integer",
        "client_type" => "required|integer",
        "stand_number" => "required",
        "phone_number" => "required",
        "type" => "required",
        "query_type" => "required|integer",
        "notes" => "required"
    ];

    public function mount()
    {
        $this->first_name = Auth::user()->first_names;
        $this->last_name = Auth::user()->surnames;
        $this->address = Auth::user()->address;
        $this->phone_number = Auth::user()->telephone;
    }

    public function submit()
    {
        $this->validate();
//        dd("simz");
        try {
            DB::beginTransaction();
            LoggedQuery::create(
                [
                    "user_id" => Auth::user()->id,
                    "council_id" => Auth::user()->council_id,
                    "first_name" => $this->first_name,
                    "last_name" => $this->last_name,
                    "stand_number" => $this->stand_number,
                    "address" => $this->address,
                    "email" => Auth::user()->email,
                    "phone_number" => $this->phone_number,
                    "reporting_channel" => 'Portal',
                    "crm_query_category_id" => $this->query_type,
                    "crm_client_type_id" => $this->client_type,
                    "description" => $this->notes,
                    "status" => 'Pending',
                    "type" => $this->type,
                    "logged_by_id" => portalAssistant(),
                    "location_id" => $this->location_id,
                    "sync_status" => "awaiting sync",
                ]
            );
            DB::commit();
            $this->notes = "";
            $this->stand_number = "";
            $this->type = "";
            $this->location_id = "";
            $this->client_type = "";
            $this->query_type = "";
            $this->render();
            $this->alert('info', 'Query Successfully Logged');
            $this->dispatchBrowserEvent("hideAddQuery");
        } catch (\Exception $e) {
            DB::rollBack();
            $this->alert('info', $e->getMessage());
        }
    }

    public function render()
    {
        $type = [
            'locations' => Location::all(),
            'queryCategories' => CrmQueryCategory::where('status', 'active')->get(),
            'queryClientTypes' => CrmClientType::where('status', 'Active')->get(),
        ];
        return view('usermanagement::livewire.crm.add-query', $type);
    }

}
