<?php

namespace Modules\UserManagement\Http\Livewire\Crm;

use App\Models\CrmPregressUpload;
use App\Models\CrmSuggestion;
use Illuminate\Support\Facades\Auth;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;

class ViewQueryLogged extends Component
{
    use LivewireAlert;
    public $message, $department_id, $subject, $phone, $lastname, $firstname;
    public $sugg = [];
    protected $rules = [
        "message" => "required",
        "department_id" => "required|integer",
        "subject" => "required",
        "phone" => "required",
        "lastname" => "required",
        "firstname" => "required"
    ];

    public function mount()
    {
        $this->firstname = Auth::user()->first_names;
        $this->lastname = Auth::user()->surnames;
        $this->phone = Auth::user()->telephone;
    }

    public function save()
    {
        $this->sugg = $this->validate();
        CrmSuggestion::create(
            [
                "type" => 'Suggestion',
                "user_id" => Auth::user()->id,
                "council_id" => Auth::user()->council_id,
                "sync_status" => "awaiting sync",
                "first_name" => $this->sugg['firstname'],
                "last_name" => $this->sugg['lastname'],
                "phone_number" => $this->sugg['phone'],
                "subject" => $this->sugg['subject'],
                "description" => $this->sugg['message'],
                "department_id" => $this->sugg['department_id'],
                "reporting_channel" => 'Portal'
            ]
        );
        $this->message = '';
        $this->department_id = '';
        $this->subject = '';

        $this->alert('info', 'Suggestion Successfully Logged');
        $this->dispatchBrowserEvent("closeSuggestionModal");
        $this->emit("refreshSuggestionTable");
    }

    public function render()
    {
        return view('usermanagement::livewire.crm.view-query-logged');
    }
}
