<?php

namespace Modules\UserManagement\Http\Livewire\Payment;

use App\BusinessLogic\CommitToLedger;
use App\Models\Payment;
use App\Traits\IsTable;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;
use Livewire\WithPagination;
use function view;

class PaymentActivity extends Component
{
    use IsTable, WithPagination, LivewireAlert;
    public function mount(){
        $this->columns=[
            'Date'=>'created_at',
        ];
    }

    public function render()
    {
        $results = Auth::user()->getUserPayments();
        return view('usermanagement::livewire.payment.payment-activity',[
            'results'=>$results
        ]);
    }

    public function usePollUrl ($url)
    {
        $this->alert('info','Pulling payment record.Please wait....',[
            'position' => 'top-end',
            'timer' => 5000,
        ]);
        $url = $url;
        $response = Http::get($url);
        $data = $this->byAnd($response->body());
        $rspDt = array();
        foreach ($data as $dt) {
            $temp = $this->keyPair($dt);
            $rspDt[$temp[0]] = $temp[1];
        }
//
        $payment = $this->getPaymentThroughReference($rspDt["reference"]);
//
        if ($payment->status == 'Paid' || $payment->status == 'Cancelled') {
            $this->alert('warning','This payment has been processed already!',[
                'position' => 'top-end',
                'timer' => 5000,
            ]);
        }
//
        if ($rspDt['status'] == 'Paid') {
            try {
                $payment->status = $rspDt['status'];
                $payment->save();
                // save to ledger
                $transaction = new CommitToLedger($payment);
                $transaction->commit();
                $this->alert('success','Payment has been processed.',[
                    'position' => 'top-end',
                    'timer' => 5000,
                ]);
            } catch (Exception $ex) {
                $this->alert('warning','Failed to processed payment.',[
                    'position' => 'top-end',
                    'timer' => 5000,
                ]);
            }
        } else {
            // dont save to ledger
            // just update payment status
            $payment->status = $rspDt['status'];
            $payment->save();

            if ($rspDt['status'] == 'Cancelled') {
                $this->alert('warning','Payment has been cancelled by user!.',[
                    'position' => 'top-end',
                    'timer' => 5000,
                ]);
            }else{
                $this->alert('warning','Payment is still waiting for processing. Try checking again in a few minutes if payment has not been updated!',[
                    'position' => 'top-end',
                    'timer' => 5000,
                ]);
            }

        }
    }

    private function getPaymentThroughReference (string $reference) {
        return Payment::where('reference', $reference)->first();
    }

    private function byAnd (string $url) {
        return explode("&", $url);
    }

    private function keyPair (string $entries): array
    {
        $values = explode("=", $entries);
        return array($values[0], $values[1]);
    }

}
