<?php

namespace Modules\UserManagement\Http\Livewire\WaitingList;

use App\Models\AreaSetting;
use App\Models\WaitingListMarketRenewal;
use App\Traits\PaynowPayment;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;

class MarketAction extends Component
{
    use PaynowPayment, LivewireAlert;

    public $market;
    public $amount;
    public $invoice;
    protected $latestPayment, $status, $createPayment;
    protected $expiry;
    protected $listeners = ["payMarketWaitingList"];

    public function mount()
    {
        if ($this->market->applicationMarketInvoicePending()->count() > 0) {
            $this->amount = $this->market->applicationMarketInvoicePending->amount * $this->market->applicationMarketInvoicePending->rate;
            $this->invoice = $this->market->applicationMarketInvoicePending;
        } else if ($this->market->applicationMarketRenewal()->count() > 0) {
            $this->amount = $this->market->applicationMarketRenewal->amount * $this->market->applicationMarketRenewal->rate;
            $this->invoice = $this->market->applicationMarketRenewal;
        }
    }

    public function payMarketWaitingList()
    {
        $this->dispatchBrowserEvent("waitingListPaymentMarket",
            [
                'number' => $this->market->contact,
                'amount' => $this->amount,
                'id' => $this->market->id,
                'type' => "market",
            ]
        );
    }

    public function render()
    {
        return view('usermanagement::livewire.waiting-list.market-action', ["market" => $this->market]);
    }

    public function hydrate()
    {
        if ($this->market->applicationMarketInvoicePending()->count() > 0 || $this->market->applicationMarketRenewal()->count() > 0) {
            $this->latestPayment = $this->market->portalPaymentMarket()->orderBy('created_at', 'desc')->first();
//            dd($this->latestPayment);
            if ($this->latestPayment) {
                $this->createPayment = $this->payment();
                $this->status = $this->createPayment->pollTransaction($this->latestPayment->poll_url);
//                dd($this->status);
                if ($this->status->paid()) {
                    $this->latestPayment->update(['status' => 'paid']);
                    if ($this->invoice->balance == 0) {
                        try {
                            DB::beginTransaction();
                            if ($this->invoice->type == "Renewal") {
                                $settings = AreaSetting::find(1);
                                if ($settings->expiry == "After 12 Months") {
                                    $this->expiry = Carbon::now()->addMonths(12)->format('Y-m-d');
                                } else {
                                    $this->expiry = Carbon::parse('last day of December')->format('Y-m-d');
                                }
//                            dd($this->expiry);
                                $renewal = new WaitingListMarketRenewal();
                                $renewal->waiting_list_market_applicant_id = $this->market->id;
                                $renewal->payment_date = Carbon::now();
                                $renewal->expiry_date = $this->expiry;
                                $renewal->currency = "RTGS";
                                $renewal->usd_amount_paid = null;
                                $renewal->rtgs_amount_paid = $this->invoice->total_paid;
                                $renewal->usd_receipt_no = null;
                                $renewal->rtgs_receipt_no = null;
                                $renewal->save();

                                $renewal->update(["rtgs_receipt_no" => "LADS-PORTAL-RENEWAL-MARKET-" . $renewal->id]);
                                $this->market->update(
                                    [
                                        "sync_status" => "awaiting sync",
                                        "expiry_date" => $this->expiry,
                                        "status" => "Active",
                                    ]
                                );
                            }
                            if ($this->invoice->type == "Application") {
                                $this->market->update(
                                    [
                                        "rtgs_amount_paid" => $this->invoice->total_paid,
                                        "rtgs_receipt_no" => "LADS-PORTAL-MARKET-" . $this->market->id,
                                        "currency" => "RTGS",
                                        "sync_status" => "awaiting sync",
                                    ]);
                            }
                            $this->invoice->update(["status" => "Complete"]);
                            DB::commit();
                            $this->success("Payment Successfully , Processing Please Wait For WaitingList Number ...");
                        } catch (\Exception $e) {
                            DB::rollBack();
                            $this->success("Payment failed ...");
                        }
                    }
                } else {
                    $this->latestPayment->update(['status' => 'Cancelled']);
                }
            }
        }
    }
}
