<?php

namespace Modules\UserManagement\Http\Livewire\WaitingList;

use App\Models\WaitingListApplicantDetail;
use App\Models\WaitingListMarketApplicant;
use App\Models\WaitingListTrackLocal;
use App\Traits\IsTable;
use Illuminate\Support\Facades\Auth;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;
use Livewire\WithPagination;

class MyWaitingList extends Component
{
    use LivewireAlert, IsTable, WithPagination;

    protected $listeners = [
        'trackWaitingList' => "trackWaitingList",
        "saveNumber",
        "trackWaitingListMarket" => "trackWaitingListMarket"
    ];

    public function trackWaitingListMarket()
    {
        $this->dispatchBrowserEvent("trackModal");
    }

    public function trackWaitingList()
    {
        $this->alert('warning', 'Enter Your Waiting List Number', [
            'showConfirmButton' => true,
            'confirmButtonText' => 'Submit',
            'onConfirmed' => 'saveNumber',
            'showCancelButton' => true,
            'cancelButtonText' => 'Cancel',
            'input' => 'text',
            'allowOutsideClick' => false,
            'timer' => null,
            'position' => 'center',
            'toast' => false,
        ]);
    }

    public function saveNumber($data)
    {
//        dd($data);
        WaitingListTrackLocal::create(
            [
                "user_id" => Auth::user()->id,
                "waiting_list_number" => $data['value'],
                "waiting_list_type" => "resident",
                "national_id" => null,
                "status" => "not linked",
            ]);
        $this->alert('success', 'Please Wait While Verifying Your Request');
    }

    public function mount()
    {
        $this->columns = [
            'Firstname' => 'firstname',
            'Lastname' => 'lastname',
            'Date' => 'created_at',
            'National Id' => 'national_no',
            'Physical Address' => 'physical_address',
            'Waiting List' => 'waiting_list_number',
            'Phone No' => 'contact',
        ];
    }

    public function render()
    {
        $results = WaitingListApplicantDetail::where('user_id', Auth::user()->id)
            ->where(function ($q) {
                $q->orwhere('firstname', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('lastname', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('waiting_list_number', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('national_no', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('gender', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('region', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('city', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('physical_address', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('marital_status', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('email', 'LIKE', '%' . $this->search . '%');
            })
            ->orwhereHas('waitingList', function ($q) {
                $q->orwhere('sheet_no', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('status', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('serial_no', 'LIKE', '%' . $this->search . '%');
            })
//            ->orwhereHas('application_details', function ($q) {
//                $q->where('id', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('application_date', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('approved_by', 'LIKE', '%' . $this->search . '%');
//            })
//            ->orwhereHas('applicant_next_of_kin', function ($q) {
//                $q->where('full_name', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('national_id', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('dob', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('contact', 'LIKE', '%' . $this->search . '%');
//            })
//            ->orwhereHas('employment', function ($q) {
//                $q->where('occupation', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('company', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('sector', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('income', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('business_address', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('business_contact', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('date_engaged', 'LIKE', '%' . $this->search . '%');
//            })
//            ->orwhereHas('spouse', function ($q) {
//                $q->where('Marriage_certificate_number', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('Date_issued', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('firstname', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('dob', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('national_id', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('contact', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('doe', 'LIKE', '%' . $this->search . '%')
//                    ->orwhere('lastname', 'LIKE', '%' . $this->search . '%');
//            })
            ->orderBy($this->columns[$this->orderBy], $this->orderDirection)
            ->paginate($this->paginationCount);

        $markets = WaitingListMarketApplicant::where("user_id", Auth::user()->id)
            ->where(function ($q) {
                $q->orwhere('firstname', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('lastname', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('lastname', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('sex', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('national_id', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('region', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('city', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('physical_address', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('contact', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('email', 'LIKE', '%' . $this->search . '%')
                    ->orwhere('application_date', 'LIKE', '%' . $this->search . '%');
            })
            ->orderBy($this->columns[$this->orderBy], $this->orderDirection)
            ->paginate($this->paginationCount);

        return view('usermanagement::livewire.waiting-list.my-waiting-list',
            [
                'results' => $results,
                "markets" => $markets
            ]);
    }
}
