<?php

namespace Modules\UserManagement\Http\Livewire\WaitingList;

use App\Models\BillingAccountType;
use App\Models\Employee;
use App\Models\FinancialCurrency;
use App\Models\HousingFee;
use App\Models\WaitingListInvoice;
use App\Models\WaitingListPortalPayment;
use App\Models\WaitingListRenewal;
use App\Traits\PaynowPayment;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Component;

class WaitingListAction extends Component
{
    use PaynowPayment, LivewireAlert;

    public $waitinglistapplicant;
    public $totalfee, $rate, $type, $totalPaid, $latestPayment, $invoice_id;
    private $createPayment;
    public $process = false;
    public $phone_number = "";
    public $amount = 0;
    public $invoice;
    protected $listeners = ["payWaitingList"];

    public function mount()
    {
        $this->totalfee = BillingAccountType::where('name', $this->waitinglistapplicant->application_details->type)->first();
        $this->rate = FinancialCurrency::where('code', 'ZWL')->first();
        if ($this->waitinglistapplicant->applicationInvoicePending()->count() > 0) {
            $this->amount = $this->waitinglistapplicant->applicationInvoicePending->amount * $this->waitinglistapplicant->applicationInvoicePending->rate;
            $this->invoice = $this->waitinglistapplicant->applicationInvoicePending;
        } else if ($this->waitinglistapplicant->applicationRenewal()->count() > 0) {
            $this->amount = $this->waitinglistapplicant->applicationRenewal->amount * $this->waitinglistapplicant->applicationRenewal->rate;
            $this->invoice = $this->waitinglistapplicant->applicationRenewal;
        }
    }

    public function payWaitingList()
    {
//        dd($this->waitinglistapplicant->id);
        $this->dispatchBrowserEvent("waitingListPayment",
            [
                'number' => $this->waitinglistapplicant->contact,
                'amount' => $this->amount,
                'id' => $this->waitinglistapplicant->id,
                'type' => "residential",
            ]);
    }

    public function hydrate()
    {

        if (($this->waitinglistapplicant->applicationInvoicePending()->count() > 0) || ($this->waitinglistapplicant->applicationRenewal()->count() > 0)) {
            $this->latestPayment = $this->waitinglistapplicant->portalPayment()->orderBy('created_at', 'desc')->first();
            $this->totalPaid = $this->invoice->total_paid;
            if ($this->latestPayment) {
//            dd($this->amount);
                $this->createPayment = $this->payment();
                $status = $this->createPayment->pollTransaction($this->latestPayment->poll_url);
//                dd($status);
                if ($status->paid()) {
                    $this->latestPayment->update(['status' => 'paid']);
//                    if ($this->totalPaid >= $this->amount) {
                    if ($this->invoice->balance == 0) {
                        try {
                            if ($this->invoice->type == "Renewal") {
                                $expsetting = DB::table('area_settings')
                                    ->select('area_settings.expiry')
                                    ->get();
                                foreach ($expsetting as $set) {
                                    $exp = $set->expiry;
                                    if ($exp == "After 12 Months") {
                                        $expDate = Carbon::now()->addMonths(12);
                                    } elseif ($exp == "At Year End") {
                                        $expDate = Carbon::parse('last day of December');
                                    }
                                }
                                $this->waitinglistapplicant->application_details->update(['expiry_date' => Carbon::create($expDate)->format('Y-m-d')]);
                                $this->waitinglistapplicant->waitingList->update(['status' => "Active"]);
                            }
                            DB::beginTransaction();
                            $renewal = new WaitingListRenewal();
                            $renewal->applicant_id = $this->waitinglistapplicant->id;
                            $renewal->expiry_date = $this->waitinglistapplicant->application_details->expiry_date;
                            $renewal->usd_amount_paid = 0;
                            $renewal->payment_date = Carbon::now();
                            $renewal->rtgs_amount_paid = $this->totalPaid;
                            $renewal->usd_receipt_no = null;
                            $renewal->rtgs_receipt_no = null;
                            $renewal->currency = "RTGS";
                            $renewal->balance = 0.0;
                            $renewal->save();

                            $renewal->update(["rtgs_receipt_no" => "RTGS-PORTAL-" . $renewal->id]);
                            $this->invoice->update(["status" => "Complete"]);
                            $this->waitinglistapplicant->update(["sync_status" => "awaiting sync"]);
//                            dd('simz');
                            DB::commit();
                            $this->success("Payment Successfully , Processing Please Wait For WaitingList Number ...");
                        } catch (\Exception $e) {
                            DB::rollBack();
                            $this->failed($e->getMessage());
                        }
                    }
                } else {
                    $this->latestPayment->update(['status' => 'Cancelled']);
                }
            }
        }
    }

    public function render()
    {
        $data = [
            'applicant' => $this->waitinglistapplicant,
            "app_fee" => $this->totalfee->fee->reg_fee,
            "currencies" => $this->rate,
        ];
        return view('usermanagement::livewire.waiting-list.waiting-list-action', $data);
    }
}
