<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

use Modules\UserManagement\Http\Controllers\AccountsController;
use Modules\UserManagement\Http\Controllers\BuildingInpesctionController;
use Modules\UserManagement\Http\Controllers\BusinessLicenceController;
use Modules\UserManagement\Http\Controllers\PaymentsController;
use Modules\UserManagement\Http\Controllers\PollUrlController;
use Modules\UserManagement\Http\Controllers\QueryController;
use Modules\UserManagement\Http\Controllers\UserManagementController;
use Modules\UserManagement\Http\Controllers\WaitingListController;

Route::middleware(['auth','isUser'])->prefix('/user-dashboard')->group(function() {
    Route::get('/', [UserManagementController::class,'index'])->name('user-dashboard');
    //Views Controller
    Route::get('add-account', [UserManagementController::class, 'addAccount'])->name('user-add-account');
    Route::get('verified-accounts', [UserManagementController::class, 'verifiedAccounts'])->name('user-verified-accounts');
    Route::get('pending-approvals', [UserManagementController::class, 'pendingApprovals'])->name('user-pending-approvals');
    Route::get('payment-activity', [UserManagementController::class, 'paymentActivity'])->name('user-payment-activity');
    Route::get('make-payment', [UserManagementController::class, 'makePayment'])->name('user-make-payment');
    Route::get('attachment/single/download', [UserManagementController::class, 'downloadFile'])->name('user-download-single-file');
    Route::get('new-payment-plan', [UserManagementController::class, 'newPaymentPlans'])->name('user-new-payment-plan');
    Route::get('all-payment-plan', [UserManagementController::class, 'allPaymentPlans'])->name('user-all-payment-plan');
    Route::get('all-business-inspections', [UserManagementController::class, 'allBuildingInspections'])->name('user-all-building-inspections');
    Route::get('account-payment-history/{id}', [UserManagementController::class, 'accountPayment'])->name('account-payment-history');

    Route::prefix('payments/{council_id}')->group(function () {
        Route::get('', [PaymentsController::class, 'initialize'])->name('payment-process-payment');
        Route::get('/response/poll', [PollUrlController::class, 'usePollUrl'])->name('payment-process-via-poll-url');
    });

    ///Post
    Route::post('pay-bill', [UserManagementController::class, 'makePaymentFromDashboard'])->name('user-pay-bill');
//waitilist
    Route::prefix('waiting-list')->group(function () {
        Route::get('add-new', [UserManagementController::class, 'addNewWaitingList'])->name('user-waiting-list-add-new');
        Route::get('add-new-market',[UserManagementController::class, 'addNewMarket'])->name('user-market-add-new');
        Route::get('my-listings', [UserManagementController::class, 'myWaitingListings'])->name('user-waiting-list-my-listings');
        Route::get('view-waiting-list/{id}',[UserManagementController::class, 'viewWaitingList'])->name('view-waiting-list');
        Route::get('application-form/{id}',[UserManagementController::class, 'applicationForm'])->name('waiting-list-application-form');
        Route::get('renewal-form/{id}',[UserManagementController::class, 'renewApplicant'])->name('renewal-waiting-list');
        Route::get('market-actions/{id}',[UserManagementController::class, 'marketAction'])->name("market-action");
        Route::get("market-renewal-form/{id}",[UserManagementController::class, 'marketRenew'])->name("market-renewal-form");

        Route::post('add-new', [WaitingListController::class, 'addWaitingListMember'])->name('user-waiting-list-save-new');
        Route::post('create-payment', [WaitingListController::class, 'createPayment'])->name('user-waiting-list-create-payment');
        Route::post('renewal-waiting-list', [WaitingListController::class, 'renewalWaitingList'])->name('user-waiting-list-renew');
        Route::post('add-new-market', [WaitingListController::class, 'addMarketUser'])->name('user-waiting-list-market-save-new');
        Route::post("track-market",[WaitingListController::class, 'trackMarket'])->name('track-waiting-list-market');
        Route::post("market-renewal-generate/{id}",[WaitingListController::class, 'marketRenewalGenerate'])->name('market-renewal');
    });

    Route::prefix('plan-approval')->group(function () {
        Route::get('my-plans', [UserManagementController::class, 'myPlans'])->name('user-plan-approval-my-plans');
        Route::get('new-plan', [UserManagementController::class, 'newPlan'])->name('user-plan-approval-new-plan');
        Route::post('new-plan', [UserPlanApproval::class, 'store'])->name('user-plan-approval-submit-application');
    });

//    business licence
    Route::prefix('business-licence')->group(function () {
        Route::get('all-business-license', [UserManagementController::class, 'allBusinessLicence'])->name('user-my-business-licence');
        Route::get('user-new-business-licence', [UserManagementController::class, 'newBusinessLicence'])->name('user-new-business-licence');
        Route::get('user-licence-apply-for-someone', [UserManagementController::class, 'newBusinessLicenceForSomeOne'])->name('user-licence-apply-for-someone');
        Route::get('preview-application/{id}',[UserManagementController::class ,'previewApplication'])->name('application-preview');
        Route::get('generate-licence-application-invoices',[UserManagementController::class ,'generateInvoices'])->name('application-licence-invoices');
        Route::post('generate-payment',[BusinessLicenceController::class ,'CreatePayment'])->name('create-payment');
        Route::get('licence-preview',[BusinessLicenceController::class , 'previewLicence'])->name('licence-preview');
        Route::get('save-licence-fee',[BusinessLicenceController::class,'licenceFee'])->name('save-licence-fee');
        Route::post('add-premise',[BusinessLicenceController::class,'addPremise'])->name('add-premise');
        Route::get('download-licence',[BusinessLicenceController::class,'downloadLicence'])->name('download-licence');
        Route::post('track-application-local',[BusinessLicenceController::class,'trackApplicationLocal'])->name('track-application-local');

        Route::post('add-application',[BusinessLicenceController::class , 'addApplication'])->name('add-application');
        Route::post('user-add-new-business', [BusinessLicenceController::class, 'newBusiness'])->name('user-add-new-business');
        Route::post('user-add-licence/{business_id}', [BusinessLicenceController::class, 'addLicence'])->name('user-add-licence');
        Route::post('apply-cycle-selection',[BusinessLicenceController::class, 'applyCycleSelection'])->name('cycle-selection');

    });

    Route::prefix('building-inspection')->group(function () {
        Route::get('new-building-inspection', [UserManagementController::class, 'newBuildingInspection'])->name('new-building-inspection');
        Route::get('all-building-inspection', [UserManagementController::class, 'allBuildingInspection'])->name('all-building-inspection');

        Route::post('user-add-new-building-inspection', [BuildingInpesctionController::class, 'newBuildingInspection'])->name('user-add-new-building-inspection');
        Route::post('user-update-inspection', [BuildingInpesctionController::class, 'updateBuildingInspection'])->name('user-update-inspection');
    });

//    crm
    Route::prefix('crm-management')->group(function () {
        Route::get('my-queries', [UserManagementController::class, 'AllMyQueries'])->name('user-crm-my-queries');

        Route::post('user-add-new-query', [QueryController::class, 'newQuery'])->name('user-add-new-query');
        Route::get('view-query/{id}', [UserManagementController::class, 'viewQuery'])->name('view-query');
        Route::post('add-suggestion',[QueryController::class, 'addSuggestion'])->name('add-suggestion');
//        Route::post('user-update-inspection', [BuildingInpesctionController::class, 'updateBuildingInspection'])->name('user-update-inspection');
    });


    // Accounts Controller
    Route::post('user-account-payment',[AccountsController::class, "accountPayment"])->name('user-account-payment');
    Route::post('account/request', [AccountsController::class, 'accountOwnershipRequest'])->name('user-request-for-account-ownership');
    Route::get('accountinfo', [AccountsController::class, 'getAccountByAccountNo'])->name('user-account-info');
});
