<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\Account;
use App\Models\AccountPortalPayment;
use App\Models\BillingAccounts;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class AccountController extends Controller
{
    public function getAccountBalance($account_number, $council_id)
    {
        $check_account = BillingAccounts::where('account_no', $account_number)->where('council_id', $council_id)->first();
        if (!$check_account) {
            return response()->json(["code" => 204, "Message" => "Record not found"]);
        } else {
            if ($check_account->has_user) {
                return response()->json(['code' => 200, 'balance' => $check_account->balance]);
            } else {
                return response()->json(['code' => 200, 'balance' => $check_account->balance, 'notification' => 'Please login to our portal to manage your account.']);
            }

        }

    }

    public function receiveAccount(Request $request)
    {
        $data = $request->account;
        try {
            DB::beginTransaction();
            foreach ($data as $account) {
                $this->updateAccount($account);
            }
            DB::commit();
            return response()->json(["success" => "success"]);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json(["error" => $e->getMessage()]);
        }

    }

    public function sendAccountPayments()
    {
        $payments = AccountPortalPayment::where("pay_now_status", "Paid")
            ->where("sync_status", "awaiting sync")
            ->get();
        return response()->json(
            [
                'payments' => $payments,
            ]);
    }

    public function updateAccountPayment(Request $request)
    {
        $update = $request->all();
        try {
            DB::beginTransaction();
            foreach ($update as $payment) {
                $pay = AccountPortalPayment::find($payment['id']);
                $pay->update([
                    "sync_status" => "synced"
                ]);
            }
            DB::commit();
            return response()->json(["success" => "success"]);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json([$e->getMessage()]);
        }
    }

    public function singleAccountUpdate(Request $request)
    {
        $account = $request->acc;
       try{
           DB::beginTransaction();
           $this->updateAccount($account);
           DB::commit();
           return response()->json(["success" => "success"]);
       }catch (\Exception $e) {
           DB::rollback();
           return response()->json([$e->getMessage()]);
       }
    }


    private function updateAccount($account): void
    {
        Account::updateOrCreate(
            [
                "account_no" => $account['account_no'],
            ],
            [
                "council_id" => 1,
                "code" => $account['code'],
                "account_name" => $account['account_name'],
                "category_id" => $account['category_id'],
                "type_id" => $account['type_id'],
                "class_id" => $account['class_id'],
                "status" => $account['status'],
                "address" => $account['address'],
                "email" => $account['email'],
                "cell1" => $account['cell1'],
                "cell2" => $account['cell2'],
                "national_id" => $account['national_id'],
                "location_id" => $account['location_id'],
                "contact_name" => $account['contact_name'],
                "employee_id" => $account['employee_id'],
                "description" => $account['description'],
                "hasProperty" => $account['hasProperty'],
                "isStaff" => $account['isStaff'],
                "isTenant" => $account['isTenant'],
                "zone_id" => $account['zone_id'],
            ]
        );
    }
}
