<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\ApplicationInspection;
use App\Models\Employee;
use App\Models\FinancialCurrency;
use App\Models\Licence;
use App\Models\LicenceApplication;
use App\Models\LicenceApplicationInspection;
use App\Models\LicenceApplicationSpecific;
use App\Models\LicenceClearance;
use App\Models\LicenceDistrict;
use App\Models\LicenceInvoice;
use App\Models\LicenceInvoiceLine;
use App\Models\LicencePayment;
use App\Models\LicenceRequirement;
use App\Models\LicenceStageSetting;
use App\Models\LicenceStageTimeline;
use App\Models\LicenceTarriff;
use App\Models\LicenceType;
use App\Models\Location;
use App\Models\PortalPayment;
use App\Models\PremiseDetail;
use App\Models\RegistrablePremise;
use App\Models\ShopLicenceClass;
use App\Models\SystemUserSignature;
use App\Models\TrackLocalApp;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use Mosquitto\Exception;

class BusinessLicenceController extends Controller
{
    public function getApplications(): \Illuminate\Http\JsonResponse
    {
        $applications = LicenceApplication::invoicesToLocal()->get();
        foreach ($applications as $app) {
            foreach ($app->anyPendingInvoice as $invoice) {
                if ($invoice->status == "Pending")
                    $invoice->update(["currency" => "usd", "rate" => 1]);
            }
        }

        $licence_application = LicenceApplication::invoicesToLocal()
            ->with(['dogInvoices', 'invoices', 'licences.classes', 'licences.registrablePremises', 'cycle', 'timeline', 'clearance'])
            ->get();
        return response()->json(
            [
                'application' => $licence_application,
            ]);
    }

    public function getUpdate(Request $request): \Illuminate\Http\JsonResponse
    {
        $sync = $request->all();
        try {
            DB::beginTransaction();
            foreach ($sync as $application) {
                LicenceApplication::find($application['id'])->update(['sync_status' => 'synced']);
            }
            DB::commit();
            return response()->json(['success' => 'uploaded successfully']);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json([$e->getMessage()]);
        }
    }

    public function getLocalData(Request $request)
    {
        $data = $request->updates;
        $dataApplication = [];
        try {
            DB::beginTransaction();
            foreach ($data as $application) {
//           return $application;
                $app = LicenceApplication::updateOrCreate(
                    [
                        "id" => $application['portal_application_id']
                    ],
                    [
                        "user_id" => $application['user_id_portal'],
                        "local_data_id" => $application['id'],
                        "sync_status" => "synced",
                        "applicant_name" => $application['applicant_name'],
                        "applicant_number" => $application['applicant_number'],
                        "applicant_address" => $application['applicant_address'],
                        "applicant_id" => $application['applicant_id'],
                        "status" => $application['status'],
                        "stage" => $application['stage'],
                        "location_id" => $application['location_id'],
                        "district_id" => $application['district_id'],
                        "licence_type_id" => $application['licence_type_id'],
                        "licence_tariff_id" => $application['licence_tariff_id'],
                        "account_id" => $application['account_id'],
                        "account_no" => $application['account_no'],
                        "vat_number" => $application['vat_number'],
                        "bp_number" => $application['bp_number'],
                        "business_owner_name" => $application['business_owner_name'],
                        "business_owner_number" => $application['business_owner_number'],
                        "business_owner_email" => $application['business_owner_email'],
                        "business_owner_address" => $application['business_owner_address'],
                        "business_address" => $application['business_address'],
                        "business_number" => $application['business_number'],
                        "business_name" => $application['business_name'],
                        "trading_as" => $application['trading_as'],
                        "stand_number" => $application['stand_number'],
                        "street_address" => $application['street_address'],
                        "premise_space_id" => $application['premise_space_id'],
                        "owner_applicant" => $application['owner_applicant'],
                        "vehicle_type" => $application['vehicle_type'],
                        "previous_application" => $application['previous_application'],
                        "badge_number" => $application['badge_number'],
                        "bicycle" => $application['bicycle'],
                        "maker_number" => $application['maker_number'],
                        "breed" => $application['breed'],
                        "sex" => $application['sex'],
                        "dog_name" => $application['dog_name'],
                        "registrable_premise_id" => $application['registrable_premise_id'],
                        "employee_id" => $application['employee_id'],
                        "council_id" => 1,
                        "ref" => $application['ref'],
                        "goods_sold" => $application['goods_sold'],
                    ]);
                if (count($application['licences']) > 0) {
                    foreach ($application['licences'] as $licence) {
                        $pivot_id = [];
                        $pivot = [];
                        $lice = Licence::updateOrCreate(
                            [
                                "ref" => $licence['ref'],
                            ],
                            [
                                "licence_application_id" => $app->id,
                                "licence_type_id" => $licence['licence_type_id'],
                                "licence_tariff_id" => $licence['licence_tariff_id'],
                                "licence_invoice_id" => $licence['licence_invoice_id'],
                                "premise_space_id" => $licence['premise_space_id'],
                                "employee_id" => $licence['employee_id'],
                                "lo_id" => $licence['lo_id'],
                                "ehm_id" => $licence['ehm_id'],
                                "qr_code" => $licence['qr_code'],
                                "account_no" => $licence['account_no'],
                                "type" => $licence['type'],
                                "status" => $licence['status'],
                                "lo" => $licence['lo'],
                                "ehm" => $licence['ehm'],
                                "hd" => $licence['hd'],
                                "customer_name" => $licence['customer_name'],
                                "company_name" => $licence['company_name'],
                                "customer_address" => $licence['customer_address'],
                                "customer_id" => $licence['customer_id'],
                                "customer_phone" => $licence['customer_phone'],
                                "start_date" => $licence['start_date'],
                                "end_date" => $licence['end_date'],
                            ]);

                        if (count($licence['classes']) > 0) {
                            foreach ($licence['classes'] as $cl) {
                                $pivot_id[] = $cl['pivot']['shop_licence_class_id'];
                            }
                            try {
                                $lice->classes()->sync($pivot_id);
                            } catch (\Exception $e) {
                                return response()->json(['error' => $e->getMessage()]);
                            }
                        }

                        if (count($licence['registrable_premises']) > 0) {
                            foreach ($licence['registrable_premises'] as $reg) {
                                $pivot[] = $reg['pivot']['registrable_premise_id'];
                            }
                            try {
                                $lice->registrablePremises()->sync($pivot);
                            } catch (\Exception $e) {
                                return response()->json(['error reg' => $e->getMessage()]);
                            }
                        }

                    }
                }
                if (count($application['timeline']) > 0) {
                    foreach ($application['timeline'] as $timeline) {
                        $time = LicenceStageTimeline::updateOrCreate(
                            [
                                "licence_application_id" => $app->id,
                                "do" => $timeline['do'],
                            ],
                            [
                                "licence_id" => $timeline['licence_id'],
                                "doa" => $timeline['doa'],
                                "ls" => $timeline['ls'],
                                "lp" => $timeline['lp'],
                                "lo" => $timeline['lo'],
                                "ehm" => $timeline['ehm'],
                                "hd" => $timeline['hd'],
                                "issue" => $timeline['issue'],
                            ]);
                    }
                }
                if ($application['clearance'] != null) {
                    LicenceClearance::updateOrCreate(
                        [
                            "licence_application_id" => $app->id,
                        ],
                        [
                            "finance" => $application['clearance']['finance'],
                            "engineering" => $application['clearance']['engineering'],
                            "finance_comments" => $application['clearance']['finance_comments'],
                            "engineering_comments" => $application['clearance']['engineering_comments'],
                            "status" => $application['clearance']['status'],
                            "stage" => $application['clearance']['stage'],
                            "premise_detail_id" => $application['clearance']['premise_detail_id'],
                            "finance_rep" => $application['clearance']['finance_rep'],
                            "engineering_rep" => $application['clearance']['engineering_rep'],
                            "cleared" => $application['clearance']['cleared'],
                        ]);
                }
                if ($application['cycle'] != null) {
                    LicenceApplicationSpecific::updateOrCreate(
                        [
                            "application_id" => $app->id,
                        ],
                        [
                            "licence_id" => $application['cycle']['licence_id'],
                            "validity" => $application['cycle']['validity'],
                            "term" => $application['cycle']['term'],
                            "start_date" => $application['cycle']['start_date'],
                            "end_date" => $application['cycle']['end_date'],
                            "status" => $application['cycle']['status'],
                            "notes" => $application['cycle']['notes'],
                        ]);
                }
                if (count($application['inspections']) > 0) {
                    foreach ($application['inspections'] as $inspection) {
                        $ins = ApplicationInspection::updateOrCreate(
                            [
                                "licence_application_id" => $app->id,
                            ],
                            [
                                "eho" => $inspection['eho'],
                                "deo" => $inspection['deo'],
                                "notes" => $inspection['notes'],
                                "comments" => $inspection['comments'],
                                "conditions" => $inspection['conditions'],
                                "classes" => $inspection['classes'],
                                "result" => $inspection['result'],
                                "expiry" => $inspection['expiry'],
                                "status" => $inspection['status'],
                            ]);

                        foreach ($inspection['lines'] as $lines) {
                            try {
                                LicenceApplicationInspection::updateOrCreate(
                                    [
                                        "application_inspection_id" => $ins->id,
                                        "licence_requirement_id" => $lines['licence_requirement_id'],
                                    ],
                                    [
                                        "licence_application_id" => $app->id,
                                        "shop_licence_class_id" => $lines['shop_licence_class_id'],
                                        "registrable_premise_id" => $lines['registrable_premise_id'],
                                        "comments" => $lines['comments'],
                                        "result" => $lines['result'],
                                        "status" => $lines['status'],
                                    ]);
                            } catch (\Exception $e) {
                                return response()->json(['error' => $e->getMessage()]);
                            }
                        }
                    }
                }
                foreach ($application['invoices'] as $invoice) {
                    $inv = LicenceInvoice::updateOrCreate([
                        "ref" => $invoice['ref'],
                    ], [
                        "licence_application_id" => $app->licence_type_id === 5 ? $invoice['licence_application_id'] : $app->id,
                        "type" => $invoice['type'],
                        "user_id" => $app->user_id,
                        "council_id" => $app->council_id,
                        "licence_tariff_id" => $invoice['licence_tariff_id'],
                        "licence_id" => $invoice['licence_id'],
                        "employee_id" => $invoice['employee_id'],
                        "status" => $invoice['status'],
                        "customer_name" => $invoice['customer_name'],
                        "customer_address" => $invoice['customer_address'],
                        "customer_id" => $invoice['customer_id'],
                        "customer_phone" => $invoice['customer_phone'],
                        "currency" => $invoice['currency'],
                        "rate" => $invoice['rate'],
                        "amount" => $invoice['amount'],
                        "date_paid" => $invoice['date_paid'],
                        "receipt_no" => $invoice['receipt_no'],
                        "total" => $invoice['total'],
                        "balance" => $invoice['balance'],
                        "paid" => $invoice['paid'],
                    ]);

                    LicenceInvoiceLine::where('licence_invoice_id', $inv->id)->delete();

                    foreach ($invoice['lines'] as $line) {
                        $new_line = LicenceInvoiceLine::create(
                            [
                                'licence_application_id' => $app->id,
                                'description' => $line['description'],
                                'status' => $line['status'],
                                'licence_type_id' => $line['licence_type_id'],
                                'licence_tariff_id' => $line['licence_tariff_id'],
                                'licence_id' => $line['licence_id'],
                                'shop_licence_class_id' => $line['shop_licence_class_id'],
                                'registrable_premise_id' => $line['registrable_premise_id'],
                                'licence_invoice_id' => $inv->id,
                                'unit_price' => $line['unit_price'],
                                'quantity' => $line['quantity'],
                                'total' => $line['total'],
                                'is_vat' => $line['is_vat'],
                                'is_discount' => $line['is_discount'],
                            ]
                        );
                    }
                    if (count($invoice['payments']) > 0) {
                        foreach ($invoice['payments'] as $payment) {
                            $pay = LicencePayment::updateOrCreate(
                                [
                                    "receipt_number" => $payment['receipt_number'],
                                ],
                                [
                                    "invoice_number" => $inv->id,
                                    "amount" => $payment['amount'],
                                    "employee_id" => $payment['employee_id'],
                                    'council_id' => 1,
                                    'user_id' => $app->user_id,
                                    "date" => $payment['date'],
                                    "path" => $payment['path'],
                                ]);

                            if ($pay->portalLicencePayments()->count() == 0) {
                                $port = PortalPayment::create(
                                    [
                                        'pay_now_reference' => $payment['receipt_number'],
                                        'application_id' => $app->id,
                                        'invoice_id' => $inv->id,
                                        'amount' => $payment['amount'],
                                        'status' => 'paid',
                                        'reference' => $invoice['type'] . '-Payment',
                                        'poll_url' => 'N/A',
                                        'hash' => 'N/A',
                                        'user_id' => $app->user_id,
                                        'council_id' => 1,
                                        'platform' => 'local',
                                        "employee_id" => $payment['employee_id'],
                                        "rate" => $invoice['rate'],
                                        "licence_payments_id" => $pay->id,
                                    ]
                                );
                            }
                        }
                    }
                }
                $dataApplication[] = [
                    "local_id" => $app->local_data_id,
                    "portal_id" => $app->id
                ];
            }
            DB::commit();
            return response()->json(
                [
                    'success' => 'uploaded successfully',
                    "data" => $dataApplication
                ]
            );
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json(["error" => $e->getMessage()]);
        }
    }

//    update a single application
    public function updateRate(Request $request): \Illuminate\Http\JsonResponse
    {
        $syncRate = $request->rate;
        try {
            DB::beginTransaction();
            $rate = FinancialCurrency::updateOrCreate(
                [
                    "id" => $syncRate['id']
                ],
                [
                    'title' => $syncRate['title'],
                    'code' => $syncRate['code'],
                    'isDefault' => $syncRate['isDefault'],
                    'status' => $syncRate['status'],
                    'rate' => $syncRate['rate'],
                ]
            );
            DB::commit();
            return response()->json(['rate' => 'done rate']);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json(['error' => $e->getMessage()]);
        }

    }

//    configurations tables setup
    public function configuration(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = $request->data;
        $tariffs = $data['licenceTariffs'];
        try {
            DB::beginTransaction();
            foreach ($tariffs as $tariff) {
                $t = LicenceTarriff::updateOrCreate(
                    [
                        'id' => $tariff['id'],
                    ],
                    [
                        'licence_type_id' => $tariff['licence_type_id'],
                        'title' => $tariff['title'],
                        'notes' => $tariff['notes'],
                        'description' => $tariff['description'],
                        'cycle' => $tariff['cycle'],
                        'price' => $tariff['price'],
                        'application_fee' => $tariff['application_fee'],
                        'health_fee' => $tariff['health_fee'],
                    ]
                );
            }
            foreach ($data['licenceTypes'] as $type) {
                $ty = LicenceType::updateOrCreate(
                    [
                        "id" => $type['id'],
                    ],
                    [
                        "title" => $type['title'],
                        "status" => $type['status'],
                        "discount" => $type['discount'],
                        "tax" => $type['tax'],
                        "application_fee" => $type['application_fee'],
                        "inspection_fee" => $type['inspection_fee'],
                        "type" => $type['type'],
                        "vote_code" => $type['vote_code'],
                        "change_fee" => $type['change_fee'],
                        "penalty_fee" => $type['penalty_fee'],
                        "vote_line_description" => $type['vote_line_description'],
                        "application_vote_line" => $type['application_vote_line'],
                        "application_vote_description" => $type['application_vote_description'],
                        "permanent_description" => $type['permanent_description'],
                    ]);
            }
            foreach ($data['locations'] as $location) {
                $l = Location::updateOrCreate(
                    [
                        'id' => $location['id'],
                    ],
                    [
                        'name' => $location['name'],
                        'council_id' => 1,
                        'code' => $location['code'],
                        'prefix' => $location['prefix'],
                        'location_type_id' => $location['location_type_id'],
                        'location_class_id' => $location['location_class_id'],
                        'waiting_list_counter' => $location['waiting_list_counter'],
                        'lease_tracking_counter' => $location['lease_tracking_counter'],
                    ]);
            }
            foreach ($data['premiseDetails'] as $premise) {
                $p = PremiseDetail::updateOrCreate(
                    [
                        "id" => $premise['id'],
                    ],
                    [
                        "premise_owner" => $premise['premise_owner'],
                        "account_no" => $premise['account_no'],
                        "stand" => $premise['stand'],
                        "physical_address" => $premise['physical_address'],
                        "location" => $premise['location'],
                        "contact" => $premise['contact'],
                        "email" => $premise['email'],
                    ]);
            }
            foreach ($data['districts'] as $district) {
                $dis = LicenceDistrict::updateOrCreate(
                    [
                        "id" => $district['id'],
                    ],
                    [
                        "name" => $district['name'],
                        'council_id' => 1,
                        "head_id" => $district['head_id'],
                    ]
                );
            }
            foreach ($data['registrablePremises'] as $reg) {
                $r = RegistrablePremise::updateOrCreate(
                    [
                        "id" => $reg['id'],
                    ],
                    [
                        "title" => $reg['title'],
                        "price" => $reg['price'],
                        "status" => $reg['status'],
                    ]
                );
            }
            foreach ($data['classes'] as $class) {
                $cl = ShopLicenceClass::updateOrCreate(
                    [
                        "id" => $class['id'],
                    ],
                    [
                        "title" => $class['title'],
                        'council_id' => 1,
                        "description" => $class['description'],
                        "price" => $class['price'],
                        "status" => $class['status'],
                    ]
                );
            }
            foreach ($data['stages'] as $stage) {
                $st = LicenceStageSetting::updateOrCreate(
                    [
                        "id" => $stage['id'],
                    ],
                    [
                        "stage" => $stage['stage'],
                        "stage_approver" => $stage['stage_approver'],
                        "turnaround_time" => $stage['turnaround_time'],
                        "status" => $stage['status'],
                    ]);
            }
            foreach ($data['currency'] as $currency) {
                $cur = FinancialCurrency::updateOrCreate(
                    [
                        "id" => $currency['id'],
                    ],
                    [
                        "title" => $currency['title'],
                        "code" => $currency['code'],
                        "rate" => $currency['rate'],
                        "status" => $currency['status'],
                        "isDefault" => $currency['isDefault'],
                    ]);
            }
            foreach ($data['employees'] as $employee) {
                $em = Employee::updateOrCreate(
                    [
                        "id" => $employee['id'],
                    ],
                    [
                        "firstnames" => $employee['firstnames'],
                        "surname" => $employee['surname'],
                        "department_id" => $employee['department_id'],
                        "section_id" => $employee['section_id'],
                        "employee_number" => $employee['employee_number'],
                        "email" => $employee['email'],
                        "phone_number" => $employee['phone_number'],
                        "position" => $employee['position'] ?? 'N/A',
                        "grade" => $employee['grade'],
                        "notch" => $employee['notch'],
                        "gender" => $employee['gender'],
                    ]
                );
//                    if($employee['user_signature'] != null){
//                        $path = Storage::disk('uploads')->putFileAs('signatures/'.$employee['user_signature']['path'] , $employee['user_signature']['path'] , $em->id. '.'. $employee['user_signature']['path']->getClientOriginalExtension());
//                        SystemUserSignature::updateOrCreate(
//                            ['employee_id' => $em->id],
//                            ['path' => $path]
//                        );
//                    }
            }
            foreach ($data['requirements'] as $requirements) {
                LicenceRequirement::updateOrCreate(
                    [
                        "id" => $requirements['id'],
                    ],
                    [
                        "licence_type_id" => $requirements['licence_type_id'],
                        "licence_tariff_id" => $requirements['licence_tariff_id'],
                        "shop_licence_class_id" => $requirements['shop_licence_class_id'],
                        "registrable_premise_id" => $requirements['registrable_premise_id'],
                        "title" => $requirements['title'],
                        "requirements" => $requirements['requirements'],
                        "status" => $requirements['status'],
                        "type" => $requirements['type'],
                    ]
                );
            }
            DB::commit();
            return response()->json(['success' => 'uploaded successfully']);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json(
                [
                    'success' => "error",
                    "err" => $e->getMessage()
                ]);
        }

    }

//    get applications to be linked
    public function linkLocalApplications(): \Illuminate\Http\JsonResponse
    {
        $unlinked = TrackLocalApp::where('status', 'not linked')->get();
        return response()->json($unlinked);
    }

//    update on applications to be linked
    public function updateLinked(Request $request): \Illuminate\Http\JsonResponse
    {
        $update = $request->all();

        try {
            DB::beginTransaction();
            if ($update['found_id'] != null) {
                foreach ($update['found_id'] as $found) {
                    $tr = TrackLocalApp::find($found['id']);
                    $tr->update(['status' => 'linked']);
                }
            }
            if ($update['not_found_id'] != null) {
                foreach ($update['not_found_id'] as $found) {
                    $tr = TrackLocalApp::find($found['id']);
                    $tr->update(['status' => 'linked']);
                }
            }
            DB::commit();
            return response()->json(['success' => 'synced']);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json(['error' => $e->getMessage()]);
        }

    }

    public function editEmployee(Request $request)
    {
        $employee = $request->empl;
        try {
            DB::beginTransaction();
            $em = Employee::updateOrCreate(
                [
                    "employee_number" => $employee['employee_number'],
                ],
                [
                    "firstnames" => $employee['firstnames'],
                    "surname" => $employee['surname'],
                    "department_id" => $employee['department_id'],
                    "section_id" => $employee['section_id'],
                    "email" => $employee['email'],
                    "phone_number" => $employee['phone_number'],
                    "position" => $employee['position'] ?? 'N/A',
                    "grade" => $employee['grade'],
                    "notch" => $employee['notch'],
                    "gender" => $employee['gender'],
                ]
            );
//                    if($employee['user_signature'] != null){
//                        $path = Storage::disk('uploads')->putFileAs('signatures/'.$employee['user_signature']['path'] , $employee['user_signature']['path'] , $em->id. '.'. $employee['user_signature']['path']->getClientOriginalExtension());
//                        SystemUserSignature::updateOrCreate(
//                            ['employee_id' => $em->id],
//                            ['path' => $path]
//                        );
//                    }
            DB::commit();
            return response()->json(['success' => 'success']);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json(['error' => $e->getMessage()]);
        }
    }

    public function updateLicencing(Request $request)
    {
        $data = $request->all();
        $request_type = $data['request'];
        try {
            DB::beginTransaction();
            if ($request_type == "tariff") {
                LicenceTarriff::updateOrCreate(
                    [
                        'id' => $data['tariff']['id'],
                    ],
                    [
                        'licence_type_id' => $data['tariff']['licence_type_id'],
                        'title' => $data['tariff']['title'],
                        'notes' => $data['tariff']['notes'],
                        'description' => $data['tariff']['description'],
                        'cycle' => $data['tariff']['cycle'],
                        'price' => $data['tariff']['price'],
                        'application_fee' => $data['tariff']['application_fee'],
                        'health_fee' => $data['tariff']['health_fee'],
                    ]
                );
            }
            if ($request_type == "type") {
                LicenceType::updateOrCreate(
                    [
                        "id" => $data['type']['id'],
                    ],
                    [
                        "title" => $data['type']['title'],
                        "status" => $data['type']['status'],
                        "discount" => $data['type']['discount'],
                        "tax" => $data['type']['tax'],
                        "application_fee" => $data['type']['application_fee'],
                        "inspection_fee" => $data['type']['inspection_fee'],
                        "type" => $data['type']['type'],
                        "vote_code" => $data['type']['vote_code'],
                        "change_fee" => $data['type']['change_fee'],
                        "penalty_fee" => $data['type']['penalty_fee'],
                        "vote_line_description" => $data['type']['vote_line_description'],
                        "application_vote_line" => $data['type']['application_vote_line'],
                        "application_vote_description" => $data['type']['application_vote_description'],
                        "permanent_description" => $data['type']['permanent_description'],
                    ]);
            }

            DB::commit();
            return response()->json(["success" => "success"]);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json(["error" => $e->getMessage()]);
        }

    }
}
