<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\CrmClientType;
use App\Models\CrmProgressUpload;
use App\Models\CrmQueryAttendant;
use App\Models\CrmQueryCategory;
use App\Models\CrmSuggestion;
use App\Models\CrmTaskForce;
use App\Models\Department;
use App\Models\LoggedQuery;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Mosquitto\Exception;

class CrmController extends Controller
{
    //configuration
    public function crmConfig(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = $request->all();
        try {
            DB::beginTransaction();
            foreach ($data['crm_category'] as $category) {
                try {
                    CrmQueryCategory::updateOrCreate(
                        [
                            'id' => $category['id'],
                        ],
                        [
                            'status' => $category['status'],
                            'category' => $category['category'],
                            'council_id' => 1,
                            'name' => $category['name'],
                        ]);
                } catch (\Exception $e) {
                    return response()->json(["error" => $e->getMessage()]);
                }
            }

            foreach ($data['crm_client_type'] as $type) {
                try {
                    CrmClientType::updateOrCreate(
                        [
                            'id' => $type['id'],
                        ],
                        [
                            'name' => $type['name'],
                            'status' => $type['status'],
                            'council_id' => 1
                        ]);
                } catch (\Exception $e) {
                    return response()->json(["error" => $e->getMessage()]);
                }
            }

            foreach ($data['department'] as $department) {
                Department::updateOrCreate(
                    [
                        "id" => $department['id']
                    ],
                    [
                        "name" => $department['name'],
                        "department_head_id" => $department['department_head_id'] == null ? 0 : $department['department_head_id'],
                        "department_code" => $department['department_code'],
                        "order_counter" => $department['orders_counter'],
                        "notes" => $department['notes'],
                    ]
                );
            }
            foreach ($data['task_force'] as $task) {
                CrmTaskForce::updateOrCreate(
                    [
                        "id" => $task['id'],
                    ],
                    [
                        "crm_query_category_id" => $task['crm_query_category_id'],
                        "department_id" => $task['department_id'],
                        "phone_number" => $task['phone_number'],
                        "is_supervisor" => $task['is_supervisor'],
                        "council_id" => 1,
                        "name" => $task['name'],
                    ]
                );
            }
            DB::commit();
            return response()->json(['success' => 'uploaded successfully']);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                'success' => "error",
                "err" => $e->getMessage()
            ]);
        }
    }

//   send queries to local
    public function sendQueriesToLocal(): \Illuminate\Http\JsonResponse
    {
        $data = [
            'query' => LoggedQuery::where('sync_status', 'awaiting sync')->get(),
            'suggestion' => CrmSuggestion::where('sync_status', 'awaiting sync')->get()
        ];
        return response()->json($data);
    }

//    update sent queries
    public function updateQuery(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = $request->all();
        try {
            DB::beginTransaction();
            if (count($data['synced']) > 0) {
                foreach ($data['synced'] as $id) {
                    $update = LoggedQuery::find($id['id']);
                    $update->update(["sync_status" => "synced", "query_id" => $id['query_id'], "local_crm_id" => $id['local_id']]);
                }
            }
            if (count($data['su']) > 0) {
                foreach ($data['su'] as $su) {
                    $up = CrmSuggestion::find($su['id']);
                    $up->update(["sync_status" => "synced", "sc_id" => $su['sc_id'], "local_suggestion_id" => $su['local_id']]);
                }
            }
            DB::commit();
            return response()->json(['success' => 'successfully']);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json(["error" => $e->getMessage()]);
        }
    }

//     get local data
    public function localUpdate(Request $request)
    {
        $data = $request->data;
        foreach ($data as $query) {
            DB::beginTransaction();
            try {
                $qu = LoggedQuery::updateOrCreate(
                    [
                        'id' => $query['portal_crm_id'],
                    ],
                    [
                        "local_crm_id" => $query['id'],
                        "query_id" => $query['query_id'],
                        "first_name" => $query['first_name'],
                        "last_name" => $query['last_name'],
                        "address" => $query['address'],
                        "email" => $query['email'],
                        "phone_number" => $query['phone_number'],
                        "reporting_channel" => $query['reporting_channel'],
                        "crm_query_category_id" => $query['crm_query_category_id'],
                        "department_id" => $query['department_id'],
                        "crm_client_type_id" => $query['crm_client_type_id'],
                        "logged_by_id" => $query['logged_by_id'],
                        "location_id" => $query['location_id'],
                        "viewed_at" => $query['viewed_at'],
                        "description" => $query['description'],
                        "status" => $query['status'],
                        "state" => $query['state'],
                        "type" => $query['type'],
                        "has_been_escalated" => $query['has_been_escalated'],
                        "logged_at" => $query['logged_at'],
                        "assigned_at" => $query['assigned_at'],
                        "resolved_at" => $query['resolved_at'],
                        "stand_number" => $query['stand_number'],
                        "user_id" => $query['user_id_portal'],
                        "sync_status" => "synced",
                    ]
                );
                foreach ($query['progress'] as $progress) {
                    $progress = CrmProgressUpload::updateOrCreate(
                        [
                            "title" => $progress['title'],
                        ],
                        [
                            "progress_percentage" => $progress['progress_percentage'],
                            "description" => $progress['description'],
                            "status" => $progress['status'],
                            "logged_query_id" => $qu->id,
                            "employee_id" => $progress['employee_id'],
                            "image_path" => $progress['image_path'],
                        ]
                    );
                }
                if ($query['attendant'] != null) {
                    CrmQueryAttendant::updateOrCreate(
                        [
                            "logged_query_id" => $qu->id,
                        ],
                        [
                            "employee_id" => $query['attendant']['employee_id'],
                        ]
                    );
                }
                DB::commit();
                return response()->json(['success' => 'successfully']);
            } catch (\Exception $e) {
                DB::rollback();
                return response()->json(["error" => $e->getMessage()]);
            }
        }
    }

}
