<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\BillingAccountCategory;
use App\Models\BillingAccounts;
use App\Models\BillingAccountType;
use App\Models\User;
use App\Models\UserRole;
use App\Models\WaitingListApplicantDependants;
use App\Models\WaitingListApplicantDetail;
use App\Models\WaitingListApplicantEmployment;
use App\Models\WaitingListApplicantNextOfKin;
use App\Models\WaitingListApplicantSpouse;
use App\Models\WaitingListApplicationDetail;
use App\Models\WaitingListAreaSetting;
use App\Models\WaitingListMarketApplicant;
use App\Models\WaitingListMarketRenewal;
use App\Models\WaitingListQ;
use App\Models\WaitingListRenewal;
use App\Models\WaitingListTrackLocal;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use mysql_xdevapi\Exception;

class WaitingList extends Controller
{
    public function searchApplicants(): \Illuminate\Http\JsonResponse
    {
        $data = [
            "track" => WaitingListTrackLocal::where('status', 'not linked')->get(),
            "search" => WaitingListApplicantDetail::where("verify", "awaiting verification")->get(),
            "markets" => WaitingListMarketApplicant::where("verify", "awaiting verification")->get(),
            "markets_applicants" => WaitingListMarketApplicant::where("sync_status", "awaiting sync")
                ->where("verify", "verified")
                ->with("marketRenewals")
                ->get(),
            "applicants" => WaitingListApplicantDetail::where("sync_status", "awaiting sync")
                ->where("verify", "verified")
                ->with(['spouse', 'employment', 'application_details', 'applicant_next_of_kin', 'dependants', 'renewal', 'waitingList'])->get()
        ];
        return response()->json($data);
    }

    public function verifyApplicants(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = $request->all();
//        return response()->json([$data]);
        try {
            DB::beginTransaction();
            if (count($data['verified']) > 0) {
                foreach ($data['verified'] as $app) {
                    $applicant = WaitingListApplicantDetail::find($app['id']);
                    $applicant->update(["verify" => "verified", "sync_status" => "synced"]);
                }
            }
            if (count($data['not_verified']) > 0) {
                foreach ($data['not_verified'] as $app) {
                    $applicant = WaitingListApplicantDetail::find($app['id']);
                    $applicant->update(["verify" => "not_verified", "sync_status" => "synced"]);
                }
            }
            if (count($data['market_verified']) > 0) {
                foreach ($data['market_verified'] as $app) {
                    $applicantMarket = WaitingListMarketApplicant::find($app['id']);
                    $applicantMarket->update(["verify" => "verified", "sync_status" => "synced"]);
                }
            }
            if (count($data['market_not_verified']) > 0) {
                foreach ($data['market_not_verified'] as $app) {
                    $applicantMarket = WaitingListMarketApplicant::find($app['id']);
                    $applicantMarket->update(["verify" => "not_verified", "sync_status" => "synced"]);
                }
            }
            DB::commit();
            return response()->json(['success' => 'successfully']);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json([
                "error" => $e->getMessage()
            ]);
        }
    }

    public function updateApplicant(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = $request->all();
//        return response()->json($data);
        try {
            DB::beginTransaction();
            foreach ($data['residential'] as $applicant) {
                $app = WaitingListApplicantDetail::find($applicant['id']);
                $app->update(["sync_status" => "synced"]);
            }
            foreach ($data['market'] as $market) {
                $applicantMarket = WaitingListMarketApplicant::find($market['id']);
                $applicantMarket->update(["sync_status" => "synced"]);
            }
            DB::commit();
            return response()->json(["success" => "successfully"]);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json([
                "error" => $e->getMessage()
            ]);
        }
    }

    public function linkApplicants(Request $request): \Illuminate\Http\JsonResponse
    {
        $data = $request->all();
        try {
            DB::beginTransaction();
            if (count($data['link']) > 0) {
                foreach ($data['link'] as $tracking) {
                    WaitingListTrackLocal::find($tracking['id'])->update(["status" => "linked"]);
                }
            }
            if (count($data['d_not_link']) > 0) {
                foreach ($data['d_not_link'] as $failed) {
                    WaitingListTrackLocal::find($failed['id'])->update(["status" => "failed"]);
                }
            }
            DB::commit();
            return response()->json(["success" => true]);
        } catch (\Exception $e) {
            DB::rollback();
            return response()->json([
                "error" => $e->getMessage()
            ]);
        }

    }

    public function receiveLocalData(Request $request): \Illuminate\Http\JsonResponse
    {
        $dataRecieved = $request->sendToPortal;
        $marketsRecieved = $request->marketApplications;
        try {
            DB::beginTransaction();
            $updated = [];
            $updatedMarket = [];
            foreach ($dataRecieved as $tracking) {
                $localApp = WaitingListApplicantDetail::updateOrCreate(
                    [
                        "id" => $tracking["portal_id"],
                    ],
                    [
                        "local_wait_list_id" => $tracking['id'],
                        "user_id" => $tracking['user_id_portal'],
                        "council_id" => 1,
                        "sync_status" => "synced",
                        "firstname" => $tracking['firstname'],
                        "lastname" => $tracking['lastname'],
                        "gender" => $tracking['gender'],
                        "national_no" => $tracking['national_no'],
                        "dob" => $tracking['dob'] == "0000-00-00" ? null : $tracking['dob'],
                        "nationality" => $tracking['nationality'],
                        "region" => $tracking['region'],
                        "city" => $tracking['city'],
                        "physical_address" => $tracking['physical_address'],
                        "marital_status" => $tracking['marital_status'],
                        "contact" => $tracking['contact'],
                        "email" => $tracking['email'],
                        "disability" => $tracking['disability'],
                        "yor" => $tracking['yor'] = "0000-00-00" ? null : $tracking['yor'],
                        "waiting_list_number" => $tracking['waiting_list_number'],
                        "resident" => $tracking['resident'],
                        "verify" => "verified",
                        "residential_address" => $tracking['residential_address'],
                    ]
                );
                if (count($tracking['renewal']) > 0) {
                    foreach ($tracking['renewal'] as $renewal) {
                        WaitingListRenewal::updateOrCreate(
                            [
                                "payment_date" => $renewal['payment_date'],
                                "applicant_id" => $localApp->id,
                            ],
                            [
                                "rtgs_receipt_no" => $renewal['usd_receipt_no'],
                                "usd_receipt_no" => $renewal['rtgs_receipt_no'],
                                "currency" => $renewal['currency'],
                                "expiry_date" => $renewal['expiry_date'],
                                "usd_amount_paid" => $renewal['usd_amount_paid'],
                                "rtgs_amount_paid" => $renewal['rtgs_amount_paid'],
                                "balance" => 0,
                            ]
                        );
                    }
                }
                if ($tracking['spouse']) {
                    WaitingListApplicantSpouse::updateOrCreate(
                        [
                            "applicant_id" => $localApp->id,
                        ],
                        [
                            "Marriage_certificate_number" => $tracking['spouse']['Marriage_certificate_number'],
                            "Date_issued" => $tracking['spouse']['Date_issued'],
                            "firstname" => $tracking['spouse']['firstname'],
                            "lastname" => $tracking['spouse']['lastname'],
                            "dob" => $tracking['spouse']['dob'],
                            "national_id" => $tracking['spouse']['national_id'],
                            "nationality" => $tracking['spouse']['nationality'],
                            "occupation" => $tracking['spouse']['occupation'],
                            "doe" => $tracking['spouse']['doe'],
                            "business_address" => $tracking['spouse']['business_address'],
                            "income" => $tracking['spouse']['income'],
                            "contact" => $tracking['spouse']['contact'],
                        ]
                    );
                }
                if ($tracking['employment']) {
                    WaitingListApplicantEmployment::updateOrCreate(
                        [
                            "applicant_id" => $localApp->id,
                        ],
                        [
                            "occupation" => $tracking['employment']['occupation'],
                            "company" => $tracking['employment']['company'],
                            "date_engaged" => $tracking['employment']['date_engaged'],
                            "business_address" => $tracking['employment']['business_address'],
                            "sector" => $tracking['employment']['sector'],
                            "income" => $tracking['employment']['income'],
                            "income_type" => "USD",
                            "business_contact" => "NULL",
                        ]);
                }
                if ($tracking['application_details']) {
                    $app_details = WaitingListApplicationDetail::updateOrCreate(
                        [
                            "applicant_id" => $localApp->id,
                        ],
                        [
                            "category" => $tracking['application_details']['category'],
                            "type" => $tracking['application_details']['type'],
                            "development" => $tracking['application_details']['development'],
                            "application_date" => $tracking['application_details']['application_date'] == "0000-00-00" ? null : $tracking['application_details']['application_date'],
                            "expiry_date" => $tracking['application_details']['expiry_date'],
                            "capital" => $tracking['application_details']['capital'],
                            "usd_receipt_no" => $tracking['application_details']['usd_receipt_no'] ?? "RTGS-PORTAL-" . $localApp->id,
                            "rtgs_receipt_no" => $tracking['application_details']['rtgs_receipt_no'] ?? "USD-PORTAL-" . $localApp->id,
                            "approved_by" => $tracking['application_details']['approved_by'],
                        ]
                    );
                }
                if (count($tracking['dependants']) > 0) {
                    foreach ($tracking['dependants'] as $dependant) {
                        WaitingListApplicantDependants::updateOrCreate(
                            [
                                "waiting_list_applicant_detail_id" => $localApp->id,
                            ],
                            [
                                "full_name" => $dependant['full_name'],
                                "national_id" => $dependant['national_id'],
                                "date_of_birth" => $dependant['dob'],
                                "gender" => $dependant['gender'],
                                "relationship" => $dependant['relationship'],
                            ]
                        );
                    }
                }
                if ($tracking['applicant_next_of_kin']) {
                    WaitingListApplicantNextOfKin::updateOrCreate(
                        [
                            "applicant_id" => $localApp->id,
                        ],
                        [
                            "full_name" => $tracking['applicant_next_of_kin']['full_name'],
                            "gender" => $tracking['applicant_next_of_kin']['gender'],
                            "relationship" => $tracking['applicant_next_of_kin']['relationship'],
                            "contact" => $tracking['applicant_next_of_kin']['contact'],
                            "national_id" => $tracking['applicant_next_of_kin']['national_id'],
                            "dob" => $tracking['applicant_next_of_kin']['dob'],
                            "physical_address" => $tracking['applicant_next_of_kin']['physical_address'],
                        ]
                    );
                }
                if ($tracking['waiting_list']) {
                    WaitingListQ::updateOrCreate(
                        [
                            "applicant_id" => $localApp->id,
                        ],
                        [
                            "sheet_no" => $tracking['waiting_list']['sheet_no'],
                            "serial_no" => $tracking['waiting_list']['serial_no'],
                            "Position" => $tracking['waiting_list']['Position'],
                            "details" => $tracking['waiting_list']['details'],
                            "status" => $tracking['waiting_list']['status'],
                        ]
                    );
                }
                $updated[] = [
                    "portal_id" => $localApp->id,
                    "local_id" => $localApp->local_wait_list_id
                ];
            }
            foreach ($marketsRecieved as $market) {
//                return response()->json([$market]);
                $ma = WaitingListMarketApplicant::updateOrCreate(
                    [
                        "id" => $market['portal_id'],
                    ],
                    [
                        "user_id" => $market['user_id_portal'],
                        "council_id" => 1,
                        "sync_status" => "synced",
                        "firstname" => $market['firstname'],
                        "lastname" => $market['lastname'],
                        "sex" => $market['sex'],
                        "national_id" => $market['national_id'],
                        "dob" => $market['dob'],
                        "nationality" => $market['nationality'],
                        "region" => $market['region'],
                        "city" => $market['city'],
                        "physical_address" => $market['physical_address'],
                        "contact" => $market['contact'],
                        "email" => $market['email'],
                        "application_date" => $market['application_date'],
                        "expiry_date" => $market['expiry_date'],
                        "rtgs_amount_paid" => $market['rtgs_amount_paid'],
                        "usd_amount_paid" => $market['usd_amount_paid'],
                        "currency" => $market['currency'],
                        "rtgs_receipt_no" => $market['rtgs_receipt_no'],
                        "usd_receipt_no" => $market['usd_receipt_no'],
                        "waiting_list_number" => $market['waiting_list_number'],
                        "status" => $market['status'],
                        "verify" => "verified",
                        "market_type_id" => $market['market_type_id'],
                        "market_id" => $market['market_id'],
                        "synced" => $market['synced'],
                        "account_id" => $market['account_id'],
                        "local_wait_list_id" => $market['id']
                    ]
                );
                if (count($market['renewal']) > 0) {
                    foreach ($market['renewal'] as $renewal) {
                        WaitingListMarketRenewal::updateOrCreate(
                            [
                                "payment_date" => $renewal['payment_date'],
                                "waiting_list_market_applicant_id" => $ma->id,
                            ],
                            [
                                "expiry_date" => $renewal['expiry_date'],
                                "rtgs_amount_paid" => $renewal['rtgs_amount_paid'],
                                "usd_amount_paid" => $renewal['usd_amount_paid'],
                                "currency" => $renewal['currency'],
                                "rtgs_receipt_no" => $renewal['rtgs_receipt_no'],
                                "usd_receipt_no" => $renewal['usd_receipt_no'],
                            ]
                        );
                    }
                }
                $updatedMarket[] = [
                    "portal_id" => $ma->id,
                    "local_id" => $ma->local_wait_list_id
                ];
            }
            DB::commit();
            return response()->json(["success" => true, "update" => $updated, "market" => $updatedMarket]);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                "error" => $e->getMessage()
            ]);
        }
    }
}
