<?php

namespace App\Models;

use App\BusinessLogic\AccountVerificationApplications;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Support\Facades\DB;

class BillingAccounts extends Model
{
    use HasFactory;

    public function type():BelongsTo{
        return $this->belongsTo(BillingAccountType::class,'type_id');
    }

    public function verification():BelongsTo{
        return $this->belongsTo(AccountVerificationApplication::class,'account_no','account_no');
    }

    public function accountClass():BelongsTo{
        return $this->belongsTo(BillingAccountClass::class,'class_id');
    }

    public function payments():HasMany{
        return $this->hasMany(Payment::class,'account_no','account_no');
    }

    public function location():BelongsTo{
        return $this->belongsTo(LocationClass::class,'location_id');
    }

    public function category():BelongsTo{
        return $this->belongsTo(BillingAccountCategory::class,'category_id');
    }



    public function getDebtsAttribute() {

        $debts = BillingChartBalance::where('account_id',$this->id)->where('billing_chart_balances.status','Open')
            ->select([DB::raw('(sum(debit) - sum(credit)) as debts'),'rate_tariff_id'])
            ->join('billing_rate_tariffs' , 'billing_chart_balances.rate_tariff_id' ,'=' , 'billing_rate_tariffs.id' )
            ->with('rateTariff.service')
            ->groupBy('rate_tariff_id')
            ->get()->sortByDesc(function ($product, $key) {
                return $product->rateTariff->service->weight;
            });

        foreach ($debts as $item){
            $acc = BillingChartBalance::where('rate_tariff_id',$item->rate_tariff_id)->where('account_id',$this->id)->where('status','Open')->wherehas('period',function ($q){
                return $q->whereDate('start','>=',Carbon::now()->subDays(30));
            })
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'),'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();
            if($acc){
                $item->current = $acc->current;
                $item->arrears = $item->debts  - $item->current;
            }
            else{
                $item->current = 0;
                $item->arrears = $item->debts;
            }

        }


        return $debts;
    }
    public function getAllTariffsAttribute(){
        $id = $this->id;
        $t = BillingRateTariff::with('service')->wherehas('accounts',function ($q)use ($id){
            return $q->where('billing_account_billing_rate_tariff.billing_account_id',$id)->where('billing_account_billing_rate_tariff.status','Billed');
        })->get();
        $new = BillingRateTariff::with('service')->wherehas('service',function ($q){return $q->where('billable','No');})->get();
        return $t->merge($new);
    }
    public function getTotalDebtAttribute() {
        $debts = $this->getDebtsAttribute();

        $total_c = 0;
        $total_d = 0;
        $total_a = 0;

        foreach ($debts as $item){
            $total_d = $total_d + $item->debts;
            $total_a = $total_a + $item->arrears;
            $total_c = $total_c + $item->current;
        }
        $extra = BillingChartBalance::where('account_id',$this->id)
            ->where('status','Extra')
            ->where('billing_period_id',0)
            ->sum('credit');
        $age_balance_total = 0;
        $age_180_total = 0;
        $age_150_total = 0;
        $age_120_total = 0;
        $age_90_total = 0;
        $age_60_total = 0;
        $age_30_total = 0;
        $age_current_total = 0;

        foreach ($this->rateTariffsActive as $tariff) {

            $age_balance = BillingChartBalance::where('rate_tariff_id', $tariff->id)->where('account_id', $this->id)->where('status', 'Open')->wherehas('period')
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'), 'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();

            $age_180 = BillingChartBalance::where('rate_tariff_id', $tariff->id)->where('account_id', $this->id)->where('status', 'Open')->wherehas('period', function ($q) {
                return $q->whereDate('start', '<=', Carbon::now()->subDays(180)->toDateString());
            })
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'), 'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();

            $age_150 = BillingChartBalance::where('rate_tariff_id', $tariff->id)->where('account_id', $this->id)->where('status', 'Open')->wherehas('period', function ($q) {
                return $q->whereDate('start', '<=', Carbon::now()->subDays(150)->toDateString())->whereDate('end', '>=', Carbon::now()->subDays(150)->toDateString());

            })
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'), 'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();
            $age_120 = BillingChartBalance::where('rate_tariff_id', $tariff->id)->where('account_id', $this->id)->where('status', 'Open')->wherehas('period', function ($q) {
                return $q->whereDate('start', '<=', Carbon::now()->subDays(120)->toDateString())->whereDate('end', '>=', Carbon::now()->subDays(120)->toDateString());
            })
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'), 'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();
            $age_90 = BillingChartBalance::where('rate_tariff_id', $tariff->id)->where('account_id', $this->id)->where('status', 'Open')->wherehas('period', function ($q) {
                return $q->whereDate('start', '<=', Carbon::now()->subDays(90)->toDateString())->whereDate('end', '>=', Carbon::now()->subDays(90)->toDateString());
            })
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'), 'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();
            $age_60 = BillingChartBalance::where('rate_tariff_id', $tariff->id)->where('account_id', $this->id)->where('status', 'Open')->wherehas('period', function ($q) {
                return $q->whereDate('start', '<=', Carbon::now()->subDays(60)->toDateString())->whereDate('end', '>=', Carbon::now()->subDays(60)->toDateString());
            })
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'), 'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();
            $age_30 = BillingChartBalance::where('rate_tariff_id', $tariff->id)->where('account_id', $this->id)->where('status', 'Open')->wherehas('period', function ($q) {
                return $q->whereDate('start', '<=', Carbon::now()->subDays(30)->toDateString())->whereDate('end', '>=', Carbon::now()->subDays(30)->toDateString());
            })
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'), 'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();
            $age_current = BillingChartBalance::where('rate_tariff_id', $tariff->id)->where('account_id', $this->id)->where('status', 'Open')->wherehas('period', function ($q) {
//
                return $q->whereDate('start', '<=', Carbon::now()->toDateString())->whereDate('end', '>=', Carbon::now()->toDateString());

            })
                ->select([DB::raw('(sum(debit) - sum(credit)) as current'), 'rate_tariff_id'])
                ->groupBy('rate_tariff_id')
                ->first();

            $age_current_total += $age_current->current??0;
            $age_balance_total += $age_balance->current??0;
            $age_30_total += $age_30->current??0;
            $age_60_total += $age_60->current??0;
            $age_90_total += $age_90->current??0;
            $age_120_total += $age_120->current??0;
            $age_150_total += $age_150->current??0;
            $age_180_total += $age_180->current??0;
        }

        return [
            'current'=>$total_c,
            'arrears'=>$total_a,
            'debts'=>$total_d-$extra,
            '180' => $age_180_total ?? 0,
            '150' => $age_150_total ?? 0,
            '120' => $age_120_total ?? 0,
            '90' => $age_90_total ?? 0,
            '60' => $age_60_total ?? 0,
            '30' => $age_30_total ?? 0,
        ];
    }
}
