<?php

namespace Modules\BuildingInspections\Entities;

use App\Models\Employee;
use Illuminate\Database\Eloquent\Casts\ArrayObject;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Support\Facades\Auth;
use Modules\Artisans\Entities\Artisan;
use Modules\Billing\Entities\BillingAccount;

class BuildingInspectionBooking extends Model
{
    use HasFactory;

    protected $fillable = [];
    protected $guarded = ['id', 'created_at', 'updated_at'];

    protected static function newFactory()
    {
        return \Modules\BuildingInspections\Database\factories\BuildingInspectionBookingFactory::new();
    }

    public function account(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(BillingAccount::class, 'account_id');
    }

    public function inspectionStage(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(BuildingInspectionStage::class, "stage_id");
    }

    public function approvalstage(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(BuildingInspectionApprovalStage::class, "approval_stage_id");
    }

    public function inspector(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(Employee::class, "employee_id");
    }

    public function history(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(BuildingInspectionHistory::class, "book_id");
    }

    public function historyPerStructure()
    {
        return $this->hasMany(BuildingInspectionHistory::class, "structure_id");
    }
    public function artisan(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(Artisan::class, "artisan_id");
    }

    public function bookApproval($ins_stage, $history, $book)
    {
        try {
            $ids = [];
            $struct_ids = [];
            $inspection_stage = BuildingInspectionStage::find($ins_stage);
            foreach ($inspection_stage->approvalStages as $stage) {
                $ids[] = $stage->pivot->inspection_id;
            }

            $structure = BuildingInspectionStructure::find($this->nature_of_building);
            foreach ($structure->inspectionStages as $structure_stage) {
                $struct_ids[] = $structure_stage->id;
            }

            $outcome = $history['action'];
            switch ($outcome) {
                case "Pass" :
                    $next_struct_stage_id = $this->nextStage($this->stage_id, $struct_ids);
                    $next_approval_stage_id = $this->nextStage($this->approval_stage_id, $ids);

                    $ap_stage = is_null($next_approval_stage_id) ? ["status" => "Signed"]
                        : ["status" => "Pending", "approval_stage_id" => $next_approval_stage_id];

                    $history_stage_app = is_null($next_approval_stage_id) ? $this->approval_stage_id : $next_approval_stage_id;

                    $this->history()->create(array_merge($history, ["next_stage_id" => $next_struct_stage_id, "structure_id" => $this->stage_id, "next_approval_stage_id" => $history_stage_app]));
                    return self::update(array_merge($book, $ap_stage));
                    break;

                case "Fail" :
                    $data = ["status" => "Failed"];
                    $this->history()->create(array_merge($history, ["next_stage_id" => $this->stage_id, "structure_id" => $this->stage_id, "next_approval_stage_id" => $this->approval_stage_id]));
                    return self::update(array_merge($book, $data));
                    break;

                default:
                    return self::update($book);
            }
        } catch (\Exception $e) {
            return $e;
        }
    }

    private function nextStage($stage, $array)
    {
        $current_stage_pos = array_search($stage, $array);
        $array_struct_stages = new ArrayObject($array);
        $iterating = $array_struct_stages->getIterator();
        $iterating->seek($current_stage_pos);
        $iterating->next();
        return $iterating->current();
    }
}
