<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Modules\UserManagement\Entities\MyBusiness;

class LicenceApplication extends Model
{
    use HasFactory;

//    protected $appends = ['last_invoice'];
    protected $guarded = ['id', 'created_at', 'updated_at'];

    public function setApplicantIdAttribute($value)
    {
        $str = preg_replace('/[\s-]+/', '', $value);
        $formatted = substr_replace(strtoupper($str), '-', 2, 0);
        $this->attributes['applicant_id'] = $formatted;
    }

    public function licenceType()
    {
        return $this->belongsTo(LicenceType::class, 'licence_type_id');
    }


    public function business(): BelongsTo
    {
        return $this->belongsTo(MyBusiness::class, 'registrable_premise_id');
    }

    public function licences(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(Licence::class, 'licence_application_id');
    }

    public function activeLicence(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(Licence::class, 'licence_application_id')->where('status', 'Issued');
    }

    public function tariff()
    {
        return $this->belongsTo(LicenceTarriff::class, 'licence_tariff_id');
    }
//    public function tariff(): BelongsTo
//    {
//        return $this->belongsTo(LicenceType::class , 'licence_tariff_id');
//    }
    public function space(): BelongsTo
    {
        return $this->belongsTo(PremiseSpace::class, 'premise_space_id');
    }

    public function timeline(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(LicenceStageTimeline::class, 'licence_application_id');
    }

    public function location(): BelongsTo
    {
        return $this->belongsTo(Location::class, 'location_id');
    }

    public function district(): BelongsTo
    {
        return $this->belongsTo(LicenceDistrict::class, 'district_id');
    }

    public function attachments(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(LicenceAttachments::class, 'licence_application_id', 'id');
    }

    public function cycle()
    {
        return $this->hasOne(LicenceApplicationSpecific::class, 'application_id');
    }

    public function dogInvoices(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(LicenceInvoice::class, 'licence_application_id', 'ref');
    }

    public function invoices(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(LicenceInvoice::class, 'licence_application_id');
//        if ($this->licence_type_id == 5) {
//            return $this->hasMany(LicenceInvoice::class, 'licence_application_id', 'ref');
//        } else {
//            return $this->hasMany(LicenceInvoice::class, 'licence_application_id');
//        }
    }

    protected function getLastInvoiceAttribute()
    {
        return $this->invoices()->orderBy('created_at')->first();
    }

    /**
     * Define a applicationInvoiceRelation relationship.
     * @param string $relationship
     * @param string|null $status
     * @param null|array|string $type
     * @param string|null $latest
     * @return mixed
     */
    private function applicationInvoiceRelation(string $relationship, string $status = null, $type = null, string $latest = null)
    {
        if ($this->licence_type_id == 5) {
            $relation = $this->$relationship(LicenceInvoice::class, 'licence_application_id', 'ref');
            if ($status != null) {
                $relation->where('status', $status);
            }
            if ($status != null && $type != null) {
                is_array($type) ? $relation->where('status', $status)->whereIn('type', $type) : $relation->where('status', $status)->where('type', $type);
            }
            return $relation;
        }

        $relation = $this->$relationship(LicenceInvoice::class, 'licence_application_id');
        if ($status != null) {
            $relation->where('status', $status);
        }
        if ($status != null && $type != null) {
            $relation->where('status', $status)->where('type', $type);
            if (!$latest) {
                $relation->latest();
            }
        }
        return $relation;
    }

    public function anyPendingInvoice()
    {
        return $this->applicationInvoiceRelation("hasMany", "Pending");
    }

    public function activeInvoice()
    {
        return $this->applicationInvoiceRelation("hasOne", "Completed", "Application");
    }

    public function activeChangeInvoice()
    {
        return $this->applicationInvoiceRelation("hasOne", "Pending", "Change");
    }

    public function activeOldInvoice()
    {
        return $this->applicationInvoiceRelation("hasOne", "Pending", "Old Licence");
    }

    public function completedOldInvoice()
    {
        return $this->applicationInvoiceRelation("hasMany", "Completed", "Old Licence");
    }

    public function completedChangeInvoice(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(LicenceInvoice::class, 'licence_application_id')
            ->where('status', 'Completed')
            ->where('type', 'Change');
    }

    public function activeLicenceInvoice()
    {
        return $this->applicationInvoiceRelation("hasOne", "Pending", "Licence");
    }

    public function completedLicenceInvoice()
    {
        return $this->applicationInvoiceRelation("hasMany", "Completed", "Licence");
    }

    public function completedLastLicenceInvoice()
    {
        return $this->applicationInvoiceRelation("hasOne", "Completed", "Licence", "latest");
    }

    public function pendingLicenceInvoice()
    {
        return $this->applicationInvoiceRelation("hasOne", "Pending", "Licence");
    }

    public function licenceInvoices()
    {
        return $this->applicationInvoiceRelation("hasMany", "Completed", ['Licence', 'Old licence']);
    }

    public function pendingInvoice(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(LicenceInvoice::class, 'licence_application_id')
            ->where('status', 'Pending')
            ->where('type', 'Application');
    }

    public function inspection(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(ApplicationInspection::class, 'licence_application_id')->latest();
    }

    public function inspections(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(ApplicationInspection::class, 'licence_application_id');
    }

    public function issuedLicence()
    {
        return $this->hasOne(Licence::class, 'licence_application_id')->where('status', 'Issued');
    }

    public function pendingLicence()
    {
        return $this->hasOne(Licence::class, 'licence_application_id')->where('status', 'Pending');
    }

    public function clearance()
    {
        return $this->hasOne(LicenceClearance::class, 'licence_application_id');
    }

    public function clerk()
    {
        return $this->belongsTo(Employee::class, 'employee_id');
    }

    public function payments()
    {
        return $this->hasMany(Payment::class, 'service_id', 'paymentRef');
    }

    public function portalPaymentsLicence()
    {
        return $this->hasMany(PortalPayment::class, 'application_id')
            ->where('reference', 'Licence-Payment')
            ->where('status', 'paid');
    }

    public function portalPaymentsApplication(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(PortalPayment::class, 'application_id')
            ->where('reference', 'Application-Payment')
            ->where('status', 'paid');
    }

    public function portalPayments(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(PortalPayment::class, 'application_id');
    }

    public function ownerInitials(): string
    {
        $ownerNames = explode(" ", $this->business_owner_name);
        return $ownerNames[0][0] . end($ownerNames);
    }

    public static function scopeInvoicesToLocal($query)
    {
        return $query->where("sync_status", "not synced");
    }
}
