<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class LicenceInvoice extends Model
{
    use HasFactory;

    protected $guarded = ['id', 'created_at', 'updated_at'];

    protected $appends = ['total', 'balance', 'paid', 'total_exc_vat', 'latest_pay', 'total_inc_vat', 'vat', 'discount'];

    protected $mappedOnly = false;

    protected $map = [
        'total' => 'total',
        'balance' => 'balance',
        'paid' => 'paid',
        'total_exc_vat' => 'total_exc_vat',
        'total_inc_vat' => 'total_inc_vat',
        'vat' => 'vat',
        'discount' => 'discount',
        'latest_pay' => 'latest_pay'
    ];

    public function licence()
    {
        return $this->belongsTo(Licence::class, 'licence_id');
    }

    public function licenceType()
    {
        return $this->belongsTo(LicenceType::class, 'licence_type_id');
    }

    public function tariff()
    {
        return $this->belongsTo(LicenceTariff::class, 'licence_tariff_id');
    }

    public function application(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        if ($this->licence_type_id == 5) {
            return $this->belongsTo(LicenceApplication::class, 'licence_application_id', 'ref');
        }
        return $this->belongsTo(LicenceApplication::class, 'licence_application_id');
    }

    public function clerk()
    {
        return $this->belongsTo(Employee::class, 'employee_id');
    }

    public function vatLine(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(LicenceInvoiceLine::class)->where('is_vat', 'yes');
    }

    public function disLine()
    {
        if ($this->currency == "usd") {
            return $this->hasOne(LicenceInvoiceLine::class)->where('is_discount', 'yes');
        }
        return $this->hasOne(LicenceInvoiceLine::class)->whereNull('id');
    }

    public function mainLines()
    {
        return $this->hasMany(LicenceInvoiceLine::class)->where('is_discount', 'no')->where('is_vat', 'no');
    }

    public function getTotalAttribute()
    {
        $lines = $this->lines;
        $total = 0;

        foreach ($lines as $line) {
            $total += $line->total;
        }
        return $total;
    }

    public function getTotalExcVatAttribute()
    {
        $lines = $this->mainLines;
        $total = 0;

        foreach ($lines as $line) {
            $total += $line->total;
        }
        return $total;
    }

    public function getTotalIncVatAttribute()
    {
        $lines = $this->mainLines;
        $vats = $this->vatLine;
        $total = 0;

        foreach ($lines as $line) {
            $total += $line->total;
        }
        if (!$vats) {
            return $total;
        }

        $total += $vats->total;


        return $total;
    }

    public function getVatAttribute()
    {
        $lines = $this->vatLine;

        if (!$lines) {
            return 0;
        }
        return $lines->total;
    }

    public function getDiscountAttribute()
    {
        $lines = $this->disLine;
        if ($lines) {
            return $lines->total;
        }
        return 0;

    }

    public function getPaidAttribute()
    {
        $lines = $this->payments;
        $total = 0;

        foreach ($lines as $line) {
            $total += $line->amount;
        }
        return $total;
    }

    public function getBalanceAttribute()
    {

        $balance = $this->total - $this->paid;
        if (round($balance, 3) <= 0) {
            $balance = 0;
        }
        return $balance;
        //return $this->getTotalAttribute() - $this->getPaidAttribute();
    }

    public function lines(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        if ($this->currency == "rtgs") {
            return $this->hasMany(LicenceInvoiceLine::class)
                ->where('is_discount', 'no');
        } else {
            return $this->hasMany(LicenceInvoiceLine::class);
        }
    }

//    public function rtgsLines(): \Illuminate\Database\Eloquent\Relations\HasMany
//    {
//        if ($this->currency == "rtgs") {
//            return $this->hasMany(LicenceInvoiceLine::class)
//                ->where('is_discount', 'no');
//        } else {
//            return $this->hasMany(LicenceInvoiceLine::class);
//        }
//    }

    public function payments(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(LicencePayment::class, 'invoice_number');
    }

    public function paynowPayments(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(PortalPayment::class, 'invoice_id');
    }

    public function getLatestPayAttribute()
    {
        if($this->paynowPayments()->count() > 0){
            return $this->paynowPayments()->where('platform', 'portal')->orderBy('created_at', 'desc')->first();
        }
    }
}
