<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Modules\CustomerRelationshipManagement\Entities\CrmQueryAttendant;

class LoggedQuery extends Model
{
    use HasFactory;
    protected $guarded =['id','created_at','updated_at'];

    public function getFullNameAttribute(): string
    {
        return $this->first_name.' '.$this->last_name;
    }
    public function location():BelongsTo{
        return $this->belongsTo(Location::class, 'location_id');
    }

    public function category():BelongsTo{
        return $this->belongsTo(CrmQueryCategory::class, 'crm_query_category_id');
    }

    public function clientType():BelongsTo{
        return $this->belongsTo(CrmClientType::class, 'type_of_client');
    }
    public function employee(): BelongsTo
    {
        return $this->belongsTo(Employee::class, 'logged_by_id');
    }
    public function progress(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(CrmProgressUpload::class, 'logged_query_id');
    }
    public function department(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(Department::class,"department_id");
    }
    public function attendant(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(\App\Models\CrmQueryAttendant::class, 'logged_query_id');
    }

}
