<?php

namespace App\Models;

use Eloquent;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Support\Carbon;

/**
 * App\UserRole
 *
 * @property int $id
 * @property string $name
 * @property Carbon|null $created_at
 * @property Carbon|null $updated_at
 * @property-read Collection|AccessRight[] $accessRights
 * @property-read int|null $access_rights_count
 * @property-read Collection|User[] $users
 * @property-read int|null $users_count
 * @method static \Illuminate\Database\Eloquent\Builder|UserRole newModelQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|UserRole newQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|UserRole query()
 * @method static \Illuminate\Database\Eloquent\Builder|UserRole whereCreatedAt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|UserRole whereId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|UserRole whereName($value)
 * @method static \Illuminate\Database\Eloquent\Builder|UserRole whereUpdatedAt($value)
 * @mixin Eloquent
 */
class UserRole extends Model
{
    protected $guarded = [];

    protected $fillable = [
        'is_admin',
        'is_user',
        'is_council',
    ];

    public static $admin = [
        'is_admin' => true,
        'is_user' => false,
        'is_council'=> false,

    ];

    public static $user = [
        'is_admin' => false,
        'is_user' => true,
        'is_council'=> false,

    ];

    public static $council = [
        'is_admin' => false,
        'is_user' => false,
        'is_council'=> true,

    ];

    public function users(): BelongsTo
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function accessRights(): HasMany
    {
        return $this->hasMany(AccessRight::class, 'user_role_id');
    }

    public function addAccessRight($access_right): Model
    {
        return $this->accessRights()->create($access_right);
    }
}
