<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Modules\SystemSettings\Entities\Council;

class WaitingListApplicantDetail extends Model
{
    use HasFactory;
    protected $guarded =['id','created_at','updated_at'];
    protected $appends = ['full_name'];

    public function getFullNameAttribute(): string
    {
        return $this->firstname.' '.$this->lastname;
    }

    public function setNationalNoAttribute($value)
    {
        $str = preg_replace('/[\s-]+/','', $value);
        $formatted = substr_replace(strtoupper($str) ,'-',2 ,0);
        $this->attributes['national_no'] = $formatted;
    }

    public function waitingList(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListQ::class , 'applicant_id');
    }

    public function applicant_next_of_kin(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListApplicantNextOfKin::class , 'applicant_id');
    }

    public function application_details(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListApplicationDetail::class , 'applicant_id');
    }

    public function employment(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListApplicantEmployment::class , 'applicant_id');
    }

    public function spouse(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->HasOne(WaitingListApplicantSpouse::class , 'applicant_id');
    }

    public function active(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->waitingList()->where('status' , 'Active');
    }

    public function renewal(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(WaitingListRenewal::class , 'applicant_id');
    }

    public function portalPayment(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(WaitingListPortalPayment::class,'application_id');
    }
    public function latestRenewal(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListRenewal::class, 'applicant_id')->latest();
    }

    public function renewal_count(){
        return $this->hasMany(WaitingListRenewal::class , 'applicant_id')->count();
    }

    public function dependants(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(WaitingListApplicantDependants::class ,'waiting_list_applicant_detail_id');
    }
    public function applicationInvoicePending(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListInvoice::class ,'applicant_id')
            ->whereNotNull("applicant_id")
            ->where('type', 'Application')
            ->where('status', 'Pending');
    }
    public function applicationInvoiceComplete(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListInvoice::class ,'applicant_id')
            ->whereNotNull("applicant_id")
            ->where('type', 'Application')
            ->where('status', 'Complete')
            ->where("platform", "Portal");
    }

    public function applicationRenewal(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListInvoice::class ,"applicant_id")
            ->whereNotNull("applicant_id")
            ->where('type', 'Renewal')
            ->where('status', 'Pending')
            ->where("platform", "Portal");
    }
    public function waitingListInvoices(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(WaitingListInvoice::class,'applicant_id');
    }
    protected function getLastInvoiceAttribute()
    {
        return $this->waitingListInvoices()->orderBy('created_at')->first();
    }
    public function council(){
        return $this->belongsTo(Council::class ,'council_id');
    }
}
