<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class WaitingListMarketApplicant extends Model
{
    use HasFactory;
    protected $guarded =['id','created_at','updated_at'];

    public function getFullNameAttribute(): string
    {
        return $this->firstname.' '.$this->lastname;
    }
    public function setNationalIdAttribute($value)
    {
        $str = preg_replace('/[\s-]+/','', $value);
        $formatted = substr_replace(strtoupper($str) ,'-',2 ,0);
        $this->attributes['national_id'] = $formatted;
    }
    public function type(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(MarketType::class , 'market_type_id');
    }

    public function market(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(Market::class , 'market_id');
    }
    public function applicationMarketInvoicePending(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListInvoice::class ,'market_id')
            ->whereNotNull("market_id")
            ->where('type', 'Application')
            ->where('status', 'Pending')
            ->where("platform", "Portal");
    }
    public function applicationMarketInvoiceComplete(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListInvoice::class ,'market_id')
            ->whereNotNull("market_id")
            ->where('type', 'Application')
            ->where('status', 'Complete')
            ->where("platform", "Portal");
    }
    public function applicationMarketRenewal(): \Illuminate\Database\Eloquent\Relations\HasOne
    {
        return $this->hasOne(WaitingListInvoice::class ,"market_id")
            ->whereNotNull("market_id")
            ->where('type', 'Renewal')
            ->where('status', 'Pending')
            ->where("platform", "Portal");
    }
    public function portalPaymentMarket(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(WaitingListPortalPayment::class,'market_applicant')->whereNotNull("market_applicant");
    }
    public function marketRenewals()
    {
        return $this->hasMany(WaitingListMarketRenewal::class ,"waiting_list_market_applicant_id");
    }
}
